
/*******************************************************************************
	Download and clean data for PPPR 24

	- Part 1: Projections
	- Part 2: GSAP
	- Part 3: MPM  
	- Part 4: Nowcasts from previous PSPRs

	Written by: Henry Stemmler
	Last date modified: 12 July 2024     
*******************************************************************************/


********************************************************************************
*	Part 1: Projections
********************************************************************************

********************************************************************************
*	Global projections

use "$ch1_data_raw/forecasts/FGTglobal_1990_2050_3pr24.dta", clear
keep year povertyline fgt0 scenario poorpop
rename (fgt0 poorpop) (headcount pop_in_poverty)
save "$ch1_data_processed/projections_global_2050.dta", replace

********************************************************************************
*	Regional projections

use "$ch1_data_raw/forecasts/FGTregion_1990_2050_3pr24.dta", clear
drop if inlist(region_pip, "AFE", "AFW", "WLD") 
keep 	if year > 2024 & year < 2031
keep 	if scenario == "current_forecast"
keep	year fgt0 region_pip povertyline
rename 	(fgt0 region_pip) (headcount region_code)
save "$ch1_data_processed/projections_region_2030.dta", replace

********************************************************************************
*	Country projections

use "$ch1_data_raw/forecasts/FGTcountry_1990_2050_3pr24.dta", clear
keep 	if scenario == "current_forecast" | scenario == "historical"
keep 	if year > 2021 & year < 2031
keep	code year fgt0 poorpop region_pip fcvFY24 pop povertyline
rename 	(fgt0 poorpop pop) (poverty_rate pop_in_poverty population)
save "$ch1_data_processed/projections_country_2030.dta", replace


********************************************************************************
*	Part 2: GSAP
********************************************************************************

* Call subnational data
use "$ch1_data_raw/other/GSAP_lineup2021_external.dta", clear
* Merge country classifications
merge 	m:1 code using "$ch1_data_processed/countrycodes_current.dta", 								///
			keepusing(region_pip incgroup_current) keep (3) nogen
* Renaming and labels
gen 	incg = 1 if incgroup_current == "Low-income" 											// Numeric for order
replace incg = 2 if incgroup_current == "Lower-middle-income" 
replace incg = 3 if incgroup_current == "Upper-middle-income" 
replace incg = 4 if incgroup_current == "High-income"
label 	define incg 1 "Low-income" 2 "Lower-middle-income" 						  ///
					3 "Upper-middle-income" 4 "High-income" 
label 	values incg incg
keep  incg poor215_ln
order incg poor215_ln
sort  incg poor215_ln
replace poor215_ln = poor215_ln * 100
save "$ch1_data_processed/gsap_processed.dta", replace


********************************************************************************
*	Part 3: MPM
********************************************************************************

use "$ch1_data_raw/other/mpm_country_level_estimates.dta", clear
keep code dep_poor1 dep_educ_com dep_educ_enr dep_infra_elec dep_infra_imps ///
	dep_infra_impw2 dep_all_inds dep_1_dims dep_2_dims dep_3_dims mdpoor_i1 datayear
rename mdpoor_i1 mpm
rename dep_poor1 dep_monetarypoor
save "$ch1_data_processed/mpm_3pr24.dta", replace

********************************************************************************
*	Part 4: Nowcasts from previous PSPRs
********************************************************************************
use "$ch1_data_raw/other/combinedprojecteddata_globalchanges.dta", clear
keep if inlist(nowcast,"Oct 2020","Oct 2022")
gen type = "PSPR2020" if nowcast=="Oct 2020"
replace type = "PSPR2022" if nowcast=="Oct 2022"
keep region year type FGT0_lic 
rename FGT0_lic headcount 
rename region region_code 
save "$ch1_data_processed/previous_nowcasts.dta", replace


