

/*******************************************************************************
	Estimate poverty rate by education status by region

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 10 August 2024     
*******************************************************************************/

/////////// Estimate poverty rate by education status ///////////
use "$ch1_data_processed/countrylist", clear
keep pcn_region_code country_code
tempfile ctylist 
save `ctylist'

// Population data
use "$ch1_data_processed/pop_reportinglevel", clear
keep if year==2022
keep if reporting_level=="national" | country_code=="ARG"
drop if country_code=="ARG" & inlist(reporting_level,"rural","national")
isid country_code
count 

tempfile pop 
save `pop' 

// Load global distribution
use "$ch1_data_raw/other/global_profile_lineup_2022.dta", clear
keep country_code gallT_ppp _newweight educat4 educy age
rename gallT_ppp welf_ppp 
rename _newweight weight

gen double poor215 = (welf_ppp<=2.15)
gen double poor685 = (welf_ppp<=6.85)

// Combine data sets
merge m:1 country_code using `pop', nogen keep(match)
merge m:1 country_code using `ctylist', nogen

drop if age==.  // Drop if age is unknown
drop if age<15  // Keep only population aged 15 or above
keep if inrange(educat4,1,4) 
rename pcn_region_code region_code
tab educat4

egen double wgt_tot = sum(weight),by(country_code)
gen double weight_pop = pop*weight/wgt_tot

// World
preserve 
bysort educat4:egen sch_hc215 = wtmean(poor215), weight(weight_pop)
bysort educat4: egen sch_hc685 = wtmean(poor685), weight(weight_pop)
keep educat4 sch_hc215 sch_hc685
rename educat4 edu  
duplicates drop 
gen region_code = "WLD"

tempfile wld 
save `wld'
restore 

// Regions
bysort region_code educat4: egen sch_hc215 = wtmean(poor215), weight(weight_pop)
bysort region_code educat4: egen sch_hc685 = wtmean(poor685), weight(weight_pop)
rename educat4 edu
keep edu sch_hc215 sch_hc685 region_code 
duplicates drop 
append using `wld'

save "$ch1_data_processed/global_poor_schooling.dta", replace 
