
/*******************************************************************************
	Estimate regional poverty rate by age

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 11 Sept 2024     
*******************************************************************************/

/////////// Estimate poverty rate by education status ///////////
use "$ch1_data_processed/countrylist", clear
keep pcn_region_code country_code
tempfile ctylist 
save `ctylist'

// Population data
use "$ch1_data_processed/pop_reportinglevel", clear
keep if year==2022
keep if reporting_level=="national" | country_code=="ARG"
drop if country_code=="ARG" & inlist(reporting_level,"rural","national")
isid country_code
count 

tempfile pop 
save `pop' 


// Load global distribution
use "$ch1_data_raw/other/global_profile_lineup_2022.dta", clear
keep country_code gallT_ppp _newweight age
rename gallT_ppp welf_ppp 
rename _newweight weight

gen double poor215 = (welf_ppp<=2.15)
gen double poor685 = (welf_ppp<=6.85)

merge m:1 country_code using `pop', nogen keep(match)
merge m:1 country_code using `ctylist', nogen
drop if age==.  
drop if missing(age) & !missing(welf_ppp)
rename pcn_region region_code

egen double wgt_tot = sum(weight),by(country_code)
gen double weight_pop = pop*weight/wgt_tot
egen pop_check = sum(weight_pop),by(country_code)
sum pop_check pop 
egen pop_wld = sum(weight_pop) 
drop pop 

// Classify population into groups
capture drop age_type
gen age_type = "child" if age<18
gen age_type_ = "youth" if age>=15 & age<25  
// create a different variable, since child and youth overlap
replace age_type = "adult" if age>=25

preserve
keep if age_type_=="youth"
drop age_type
rename age_type_ age_type
tempfile df 
save `df' 
restore 

keep if inlist(age_type,"child","adult")
append using `df' 
drop age_type_

preserve 
bysort age_type: egen hc215 = wtmean(poor215), weight(weight_pop)
bysort age_type: egen hc685 = wtmean(poor685), weight(weight_pop)
egen pop = sum(weight_pop),by(age_type)
keep age_type hc215 hc685  pop
duplicates drop 
gen region_code = "WLD"

tempfile wld 
save `wld'
restore 

bysort region_code age_type: egen hc215 = wtmean(poor215), weight(weight_pop)
bysort region_code age_type: egen hc685 = wtmean(poor685), weight(weight_pop)
egen pop = sum(weight_pop),by(region age_type)
keep age_type hc215 hc685  pop  region

duplicates drop 
append using `wld'
save "$ch1_data_processed/global_poor_age.dta", replace

////////////////////////////////////////////////////////////////////////////////////
/* Use distinct age categories */
use "$ch1_data_processed/countrylist", clear
keep pcn_region_code country_code
tempfile ctylist 
save `ctylist'

// Population data
use "$ch1_data_processed/pop_reportinglevel", clear
keep if year==2022
keep if reporting_level=="national" | country_code=="ARG"
drop if country_code=="ARG" & inlist(reporting_level,"rural","national")
isid country_code 

tempfile pop 
save `pop' 


// Load global distribution
use "$ch1_data_raw/other/global_profile_lineup_2022.dta", clear
keep country_code gallT_ppp _newweight age
rename gallT_ppp welf_ppp 
rename _newweight weight

gen double poor215 = (welf_ppp<=2.15)
gen double poor685 = (welf_ppp<=6.85)

merge m:1 country_code using `pop', nogen keep(match)
merge m:1 country_code using `ctylist', nogen
drop if age==.  
drop if missing(age) & !missing(welf_ppp)
rename pcn_region region_code

egen double wgt_tot = sum(weight),by(country_code)
gen double weight_pop = pop*weight/wgt_tot
egen pop_check = sum(weight_pop),by(country_code)
egen pop_wld = sum(weight_pop)
drop pop 

// Classify population into groups
gen age_type = "child & youth" if age<25
replace age_type = "adult" if age>=25

preserve 
bysort age_type: egen hc215 = wtmean(poor215), weight(weight_pop)
bysort age_type: egen hc685 = wtmean(poor685), weight(weight_pop)
egen pop = sum(weight_pop),by(age_type)
keep age_type hc215 hc685  pop
duplicates drop 
gen region_code = "WLD"

tempfile wld 
save `wld'
restore 

bysort region_code age_type: egen hc215 = wtmean(poor215), weight(weight_pop)
bysort region_code age_type: egen hc685 = wtmean(poor685), weight(weight_pop)
egen pop = sum(weight_pop),by(region age_type)
keep age_type hc215 hc685  pop  region

duplicates drop 
append using `wld'
save "$ch1_data_processed/global_poor_age_distinct.dta", replace

