
/*******************************************************************************
	Figure 10. Poverty is higher in rural than urban areas, 2022 
	/* a. Share of global poor at $2.15  */
	/* b. Share of global poor at $6.85  */
	/* c. Poverty rate at $2.15 		*/
	/* d. Poverty rate at $6.85			 */

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 6 August 2024     
*******************************************************************************/

// Program set-up
clear all
set more off

foreach var in a b{
// Load data
use "$ch1_data_processed/global_poor_location.dta", clear
keep if inlist(urban,0,1)
keep urban region_code hc_`var' pop 
rename hc_`var' hc 
gen double poor = hc * pop/1000000 
keep urban region_code poor 
egen poor_avg = sum(poor) if region_code!="WLD",by(urban)
egen poor_avg_wld_ = sum(poor) if region_code=="WLD"
egen poor_avg_wld = mean(poor_avg_wld_) 
drop poor_avg_wld_ poor_avg 
drop if region_code=="WLD"
gen double shr = 100*poor/poor_avg_wld
egen double shr_check = sum(shr)
drop poor shr_check poor_avg_wld
replace region_code = "TOHI" if region_code=="OHI"

// Label region names
gen region_name = "East Asia & Pacific" if region_code=="EAP"
replace region_name = "Europe & Central Asia" if region_code=="ECA"
replace region_name = "Latin America & Caribbean" if region_code=="LAC"
replace region_name = "Middle East & North Africa" if region_code=="MNA"
replace region_name = "South Asia" if region_code=="SAS"
replace region_name = "TRest of the World" if region_code=="TOHI"
replace region_name = "Sub-Saharan Africa" if region_code=="SSA"
rename urban type
rename shr share_global_poor 
sort type region_name

// Organize data
replace region_name = "Rest of the World" if region_code=="TOHI"
drop region_code 
replace type = . if region_name!="East Asia & Pacific"
order type region_name
lab var share_global_poor "Share of global poor (%)"
lab var type "Location"
lab var region_name "Region"

// Stor results
export excel "$ch1_output/chapter1.xlsx", sheet("fig10`var'") firstrow(varl) sheetreplace
}



/* c. Poverty rate at $2.15  */

// Load data 
use "$ch1_data_processed/global_poor_location.dta", clear
keep urban region_code hc_a
rename hc_a hc  
bysort region (urban): gen j = _n
// Remove multiply imputed setting
gen _mi_miss=0
gen _mi_id=0
mi extract 0, clear
reshape wide hc, i(region_code urban) j(j)
collapse hc*,by(region)
rename hc1 hc_rur 
rename hc2 hc_urb
rename hc3 hc_tot 
drop if region_code=="OHI"
gen region_name = "East Asia & Pacific" if region_code=="EAP"
replace region_name = "Europe & Central Asia" if region_code=="ECA"
replace region_name = "Latin America & Caribbean" if region_code=="LAC"
replace region_name = "South Asia" if region_code=="SAS"
replace region_name = "Sub-Saharan Africa" if region_code=="SSA"
replace region_name = "World" if region_code=="WLD"
replace region_name = "Middle East & North Africa" if region_code=="MNA"
encode region_code, gen(regionnum) label(region_lbl)
sort regionnum 
lab var regionnum "Region"

replace hc_rur = 100*hc_rur
replace hc_urb = 100*hc_urb
replace hc_tot = 100*hc_tot

graph set window fontface "Open Sans"

// Make chart
twoway (rcap hc_rur hc_urb regionnum, sort(regionnum) lwidth(medium) lwidth(thick) msymbol(o) lcolor(gs6) msize(medium)) ///
scatter hc_tot regionnum, mcolor(gs6) msymbol(O) msize(large) mcolor("71 71 72") ///
|| scatter hc_rur regionnum, mcolor(gs6) msize(large) msymbol(D) mcolor("255 129 51") ///
|| scatter hc_urb regionnum, mcolor(gs6) msize(large) msymbol(D)  mcolor("255 213 137")  ///
 title("")  subtitle("") ///
	legend(order(2 "Total" 3 "Rural" 4 "Urban") row(1) pos(6) size(medium)) ///
 ysize(6) xsize(9) graphregion(color(white)) ///
 xlabel(1 `" "East Asia &" "Pacific" "' ///
 2 `" "Europe &" "Central Asia" "' ///
 3 `" "Latin America" " & Caribbean" "' ///
 4 `" "Middle East &" " North Africa*" "' ///
 5 `" "South Asia" "" "' ///
 6 `" "Sub-Saharan" "Africa*" "' ///
 7 `" "World" "" "', ///
 labs(small)) ///
	ylabel(0(20)100, format(%9.0f) angle(h) labsize(medium)) ///
	xtitle("", size(medium)) ///
	ytitle("Poverty rate (%)") ///
	name(regionnum, replace) legend(row(1))  
	
// Export graph 
graph export "$ch1_output/ch1_fig10c.eps", as(eps) replace
graph export "$ch1_output/ch1_fig10c.png", as(png) replace 

export excel "$ch1_output/chapter1.xlsx", sheet("fig10c") firstrow(varl) sheetreplace


/* d. Poverty rate at $6.85  */

// Load data 
use "$ch1_data_processed/global_poor_location.dta", clear
keep urban region_code hc_b
rename hc_b hc  
bysort region (urban): gen j = _n
// Remove multiply imputed setting
gen _mi_miss=0
gen _mi_id=0
mi extract 0, clear
reshape wide hc, i(region_code urban) j(j)
collapse hc*,by(region)
rename hc1 hc_rur 
rename hc2 hc_urb
rename hc3 hc_tot 
drop if region_code=="OHI"
gen region_name = "East Asia & Pacific" if region_code=="EAP"
replace region_name = "Europe & Central Asia" if region_code=="ECA"
replace region_name = "Latin America & Caribbean" if region_code=="LAC"
replace region_name = "South Asia" if region_code=="SAS"
replace region_name = "Sub-Saharan Africa" if region_code=="SSA"
replace region_name = "World" if region_code=="WLD"
replace region_name = "Middle East & North Africa" if region_code=="MNA"
encode region_code, gen(regionnum) label(region_lbl)
sort regionnum 
lab var regionnum "Region"

replace hc_rur = 100*hc_rur
replace hc_urb = 100*hc_urb
replace hc_tot = 100*hc_tot

graph set window fontface "Open Sans"

// Make chart
twoway (rcap hc_rur hc_urb regionnum, sort(regionnum) lwidth(medium) lwidth(thick) msymbol(o) lcolor(gs6) msize(medium)) ///
scatter hc_tot regionnum, mcolor(gs6) msymbol(O) msize(large) mcolor("71 71 72") ///
|| scatter hc_rur regionnum, mcolor(gs6) msize(large) msymbol(D) mcolor("255 129 51") ///
|| scatter hc_urb regionnum, mcolor(gs6) msize(large) msymbol(D)  mcolor("255 213 137")  ///
 title("")  subtitle("") ///
	legend(order(2 "Total" 3 "Rural" 4 "Urban") row(1) pos(6) size(medium)) ///
 ysize(6) xsize(9) graphregion(color(white)) ///
 xlabel(1 `" "East Asia &" "Pacific" "' ///
 2 `" "Europe &" "Central Asia" "' ///
 3 `" "Latin America" " & Caribbean" "' ///
 4 `" "Middle East &" " North Africa*" "' ///
 5 `" "South Asia" "" "' ///
 6 `" "Sub-Saharan" "Africa*" "' ///
 7 `" "World" "" "', ///
 labs(small)) ///
	ylabel(0(20)100, format(%9.0f) angle(h) labsize(medium)) ///
	xtitle("", size(medium)) ///
	ytitle("Poverty rate (%)") ///
	name(regionnum, replace) legend(row(1))  
	
// Export graph 
graph export "$ch1_output/ch1_fig10d.eps", as(eps) replace
graph export "$ch1_output/ch1_fig10d.png", as(png) replace 

export excel "$ch1_output/chapter1.xlsx", sheet("fig10d") firstrow(varl) sheetreplace
