
/*******************************************************************************
	Figure 12. Percent of population living in poverty by educational attainment, 2022 
	/* a. $2.15  */
	/* b. $6.85  */

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 6 August 2024     
*******************************************************************************/

// Program set-up
clear all
set more off


// Load results data 
use "$ch1_data_processed/global_poor_schooling.dta", clear 
keep region_code edu sch_hc215 
replace sch_hc215 = 100*sch_hc215
rename sch_hc215 y 
drop if region_code=="OHI"
bysort region_code (edu): gen j = _n
// Remove multiply imputed setting
gen _mi_miss=0
gen _mi_id=0
mi extract 0, clear
reshape wide y, i(region_code edu) j(j)
collapse y*,by(region)
gen region_name = `" "East Asia &" "Pacific" "' if region_code=="EAP"
replace region_name = `" "Europe &" "Central Asia" "' if region_code=="ECA"
replace region_name = `" "Latin America" " & Caribbean" "' if region_code=="LAC"
replace region_name = `" "Middle East &" " North Africa*" "' if region_code=="MNA"
replace region_name = `" "South Asia" "" "' if region_code=="SAS"
replace region_name = `" "Sub-Saharan" "Africa*" "' if region_code=="SSA"
replace region_name = `" "World" "" "' if region_code=="WLD"

encode region_code, gen(regionnum) label(region_lbl)
sort regionnum 
graph bar y*,over(region_name, sort(regionnum) label(labsize(small))) ///
legend(order(1 "No schooling" 2 "Primary" 3 "Secondary" 4 "Tertiary") row(1) pos(6) size(medium)) ///
 ysize(6) xsize(10) graphregion(color(white)) ///
 bar(1, lwidth(medium) lpattern(solid) lcolor(rgb("237 52 46"))  fcolor(rgb("237 52 46"))) ///
	bar(2, lwidth(medium) lpattern(solid) lcolor(rgb("71 71 72"))  fcolor(rgb("71 71 72"))) ///
	bar(3, lwidth(medium) lpattern(solid) lcolor(rgb("255 213 137"))  fcolor(rgb("255 213 137"))) ///
	bar(4, lwidth(medium) lpattern(solid) lcolor(rgb("81 229 255"))  fcolor(rgb("81 229 255"))) ///
	ytitle("Poverty rate (%)") ylab(0(20)100)
	
// Export graph 
graph export "$ch1_output/ch1_fig12a.eps", as(eps) replace
graph export "$ch1_output/ch1_fig12a.png", as(png) replace 
export excel "$ch1_output/chapter1.xlsx", sheet("fig12a") firstrow(varl) sheetreplace

/* $6.85  */

// Load results data 
use "$ch1_data_processed/global_poor_schooling.dta", clear 
keep region_code edu sch_hc685 
replace sch_hc685 = 100*sch_hc685
rename sch_hc685 y 
drop if region_code=="OHI"
bysort region_code (edu): gen j = _n
// Remove multiply imputed setting
gen _mi_miss=0
gen _mi_id=0
mi extract 0, clear
reshape wide y, i(region_code edu) j(j)
collapse y*,by(region)
gen region_name = `" "East Asia &" "Pacific" "' if region_code=="EAP"
replace region_name = `" "Europe &" "Central Asia" "' if region_code=="ECA"
replace region_name = `" "Latin America" " & Caribbean" "' if region_code=="LAC"
replace region_name = `" "Middle East &" " North Africa*" "' if region_code=="MNA"
replace region_name = `" "South Asia" "" "' if region_code=="SAS"
replace region_name = `" "Sub-Saharan" "Africa*" "' if region_code=="SSA"
replace region_name = `" "World" "" "' if region_code=="WLD"

encode region_code, gen(regionnum) label(region_lbl)
sort regionnum 
graph bar y*,over(region_name, sort(regionnum) label(labsize(small))) ///
legend(order(1 "No schooling" 2 "Primary" 3 "Secondary" 4 "Tertiary") row(1) pos(6) size(medium)) ///
 ysize(6) xsize(10) graphregion(color(white)) ///
 bar(1, lwidth(medium) lpattern(solid) lcolor(rgb("237 52 46"))  fcolor(rgb("237 52 46"))) ///
	bar(2, lwidth(medium) lpattern(solid) lcolor(rgb("71 71 72"))  fcolor(rgb("71 71 72"))) ///
	bar(3, lwidth(medium) lpattern(solid) lcolor(rgb("255 213 137"))  fcolor(rgb("255 213 137"))) ///
	bar(4, lwidth(medium) lpattern(solid) lcolor(rgb("81 229 255"))  fcolor(rgb("81 229 255"))) ///
	ytitle("Poverty rate (%)") ylab(0(20)100)
	
// Export graph 
graph export "$ch1_output/ch1_fig12b.eps", as(eps) replace
graph export "$ch1_output/ch1_fig12b.png", as(png) replace 
export excel "$ch1_output/chapter1.xlsx", sheet("fig12b") firstrow(varl) sheetreplace
