
/*******************************************************************************
	Figure 13. Age profile of the poor, 2022 
	/* a. $2.15  */
	/* b. $6.85  */

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 11 August 2024     
*******************************************************************************/


/* $2.15   */

// Load data
use "$ch1_data_processed/global_poor_age.dta", clear
drop if region_code=="OHI"
gen region_name = `" "East Asia &" "Pacific" "' if region_code=="EAP"
replace region_name = `" "Europe &" "Central Asia" "' if region_code=="ECA"
replace region_name = `" "Latin America" " & Caribbean" "' if region_code=="LAC"
replace region_name = `" "South Asia" "" "' if region_code=="SAS"
replace region_name = `" "Sub-Saharan" "Africa*" "' if region_code=="SSA"
replace region_name = `" "World" "" "' if region_code=="WLD"
replace region_name = `" "Middle East &" " North Africa*" "' if region_code=="MNA"
drop if region_name == ""
egen sorting_var = group(region_code)
replace hc215 = 100*hc215 
keep region_name age_type hc215 sorting_var
rename hc215 hc 
encode age_type, gen(age_type_)
recode age_type_ (1 = 3) (2 = 1) (3 =2), gen(new_age_type_)
drop age_type_
label define age_type_lbl 1 "Child" 2 "Youth" 3 "Adult"
label values new_age_type_ age_type_lbl
drop age_type 
rename new_age_type_ age_type
// Remove multiply imputed setting
gen _mi_miss=0
gen _mi_id=0
mi extract 0, clear
reshape wide hc*, i(region_name sorting_var) j(age_type)
graph bar hc*, over(region_name, label(labsize(small)) sort(sorting_var)) ///
	legend(order(1 "Child" 2 "Youth" 3 "Adult")  ///
	position(6)) xsize(8) legend(position(6) row(1)) ytitle("Poverty rate (%)")  ///
	bar(1, lwidth(medium) lpattern(solid) lcolor(rgb("237 52 46"))  fcolor(rgb("237 52 46"))) ///
	bar(2, lwidth(medium) lpattern(solid) lcolor(rgb("71 71 72"))  fcolor(rgb("71 71 72"))) ///
	bar(3, lwidth(medium) lpattern(solid) lcolor(rgb("255 213 137"))  fcolor(rgb("255 213 137"))) ///
	ylab(0(20)100)

// Save graph	
graph export "$ch1_output/ch1_fig13a.eps", as(eps) replace
graph export "$ch1_output/ch1_fig13a.png", as(png) replace 
export excel "$ch1_output/chapter1.xlsx", sheet("fig13a") firstrow(varl) sheetreplace


/* $6.85   */

// Load data
use "$ch1_data_processed/global_poor_age.dta", clear
drop if region_code=="OHI"
gen region_name = `" "East Asia &" "Pacific" "' if region_code=="EAP"
replace region_name = `" "Europe &" "Central Asia" "' if region_code=="ECA"
replace region_name = `" "Latin America" " & Caribbean" "' if region_code=="LAC"
replace region_name = `" "South Asia" "" "' if region_code=="SAS"
replace region_name = `" "Sub-Saharan" "Africa*" "' if region_code=="SSA"
replace region_name = `" "World" "" "' if region_code=="WLD"
replace region_name = `" "Middle East &" " North Africa*" "' if region_code=="MNA"
drop if region_name == ""
egen sorting_var = group(region_code)
replace hc685 = 100*hc685 
keep region_name age_type hc685 sorting_var
rename hc685 hc 
encode age_type, gen(age_type_)
recode age_type_ (1 = 3) (2 = 1) (3 =2), gen(new_age_type_)
drop age_type_
label define age_type_lbl 1 "Child" 2 "Youth" 3 "Adult"
label values new_age_type_ age_type_lbl
drop age_type 
rename new_age_type_ age_type
// Remove multiply imputed setting
gen _mi_miss=0
gen _mi_id=0
mi extract 0, clear
reshape wide hc*, i(region_name sorting_var) j(age_type)
graph bar hc*, over(region_name, label(labsize(small)) sort(sorting_var)) ///
	legend(order(1 "Child" 2 "Youth" 3 "Adult")  ///
	position(6)) xsize(8) legend(position(6) row(1)) ytitle("Poverty rate (%)")  ///
	bar(1, lwidth(medium) lpattern(solid) lcolor(rgb("237 52 46"))  fcolor(rgb("237 52 46"))) ///
	bar(2, lwidth(medium) lpattern(solid) lcolor(rgb("71 71 72"))  fcolor(rgb("71 71 72"))) ///
	bar(3, lwidth(medium) lpattern(solid) lcolor(rgb("255 213 137"))  fcolor(rgb("255 213 137"))) ///
	ylab(0(20)100)

// Save graph	
graph export "$ch1_output/ch1_fig13b.eps", as(eps) replace
graph export "$ch1_output/ch1_fig13b.png", as(png) replace 
export excel "$ch1_output/chapter1.xlsx", sheet("fig13b") firstrow(varl) sheetreplace
