
/*******************************************************************************
	Figure 15: Create scatter plot of monetary and multidimensional poverty

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 7 August 2024     
*******************************************************************************/

// Country list
use "$ch1_data_processed/countrycodes_yearly.dta", clear
keep region_pip region_pip_name code economy 
rename region_pip region_code 
rename region_pip_name region_name
rename code country_code 
rename economy country_name
duplicates drop 
isid country_code 
tempfile countrylist 
save `countrylist'

// Load MPM data 
use "$ch1_data_processed/mpm_3pr24.dta", clear
keep code dep_monetarypoor mpm
rename code  country_code
isid country_code
merge 1:1 country_code using `countrylist', nogen keep(match)
 
replace mpm = 100*mpm
replace dep_monetarypoor = 100*dep_monetarypoor

// Make chart
replace country_name = "" if mpm<40
replace country_name = "" if dep_monetarypoor<30 & dep_monetarypoor>23

gen pos = 3 
replace pos = 12 if country_name=="Guinea"
replace pos = 11 if country_code=="COD"
replace pos = 1 if country_name=="Burundi"
replace pos = 9 if country_name=="Zambia" | country_name=="Mozambique" 
replace country_name = "" if inlist(country_name,"Cameroon")
scatter mpm dep_monetarypoor if region_code=="EAP", ///
	mcolor("237 52 46") msymbol(D) mlab(country_name) mlabcolor("237 52 46") ///
	|| scatter mpm dep_monetarypoor if region_code=="ECA", ///
	mcolor("163 163 163") msymbol(D) mlab(country_name) mlabcolor("163 163 163") ///
	|| scatter mpm dep_monetarypoor if region_code=="LAC", mcolor("58 190 203") msymbol(D)  ///
	|| scatter mpm dep_monetarypoor if region_code=="MNA", mcolor("14 100 169") msymbol(D)   ///
	|| scatter mpm dep_monetarypoor if region_code=="SAS", mcolor("255 129 51") msymbol(D)   ///
	|| scatter mpm dep_monetarypoor if region_code=="SSA", mlabvposition(pos) ///
	mcolor("255 213 137")  msymbol(D) mlab(country_name) mlabcolor("255 213 137") ///
	|| scatter mpm dep_monetarypoor if region_code=="OHI", mcolor("153 245 255") msymbol(D)  ///
	|| function y = x, ra(dep_monetarypoor) lcolor(black)  ///
	legend(order(1 "East Asia & Pacific" ///  
2 "Europe & Central Asia" ///
3 "Latin America & Caribbean" /// 
4 "Middle East & North Africa" /// 
5 "South Asia" /// 
6 "Sub-Saharan Africa"   /// 
7 "Rest of the World") /// 
position(6) row(4) symxsize(*.5) symysize(*.8) size(small)) ///
ytitle("Multidimensional poverty (%)") ///
xtitle("Extreme poverty (%)") ///
xsize(8) ysize(8)


graph export "$ch1_output/ch1_fig15_mpm_scatterplot.eps", as(eps) replace
graph export "$ch1_output/ch1_fig15_mpm_scatterplot.png", as(png) replace 

export excel "$ch1_output/chapter1.xlsx", sheet("fig15", modify) firstrow(varlabels)

