
********************************************************************************
*	Figure 2. Extreme poverty has not returned to pre-pandemic levels in low-income countries 
********************************************************************************
foreach pl in 215 685 {				// Loop through 2.15 and 6.85 poverty lines
	local line = `pl' / 100
	use "$ch1_data_processed/poverty_country_lineup.dta", clear
	keep if poverty_line == `line'
	keep country_code reporting_level headcount year population
	* Merge in missing countries and population
	merge 1:1 country_code reporting_level year using "$ch1_data_processed/pop_reportinglevel", nogen
	rename 	country_code code
	* Merge country classifications
	merge 	m:1 code using "$ch1_data_processed/countrycodes_current.dta", 			///	
					 keepusing(region_pip incgroup_current) 
	keep if year > 2018
	* Clean up 
	keep if reporting_level=="national" | inlist(code,"ARG") 										// Drop urban and rural for all but Argentina
	drop if inlist(code,"ARG") & reporting_level=="national" 										// Drop national for Argentina	* Calculate regional poverty to fill in missing numbers
	* Calculate regional poverty to fill in missing numbers
	bysort region_pip year: egen avg_pov = wtmean(headcount),weight(population)
	* Fill in missing values
	replace population = pop if population == . 													// Get population
	replace headcount  = avg_pov if headcount == . 	
	* Generate poverty rates on income group level
	encode 	incgroup_current, gen(incgroup) label(inc_l) 
	* Keep labels of income groups
	levelsof incgroup, local(l) 
	foreach i of local l {
		local d`i'  `: label inc_l `i''
	}
	collapse (mean) headcount [w=population], by(incgroup year)
	* Growth rates
	gen h19 = headcount if year == 2019
	bys incgroup: egen headcount19 = mean(h19)
	gen headcount_growth = headcount / headcount19
	drop h19 headcount19 headcount
	* Excel format
	reshape wide headcount*, i(year) j(incgroup)
	foreach i of local l {
		label var headcount_growth`i' "`d`i''"
	}
	* Generate separate forecast variable for Excel 
	foreach var of varlist headcount_growth*  {
		gen `var'_forecast = `var' if year > 2021
		replace `var'	   = .	   if year > 2022
	}
	* Replace LIC line to dotted because of coverage
	replace headcount_growth2_forecast = headcount_growth2 if headcount_growth2_forecast == . 
	replace headcount_growth2 = .
	order year headcount_growth2 headcount_growth3 headcount_growth4 headcount_growth1 headcount_growth2_forecast headcount_growth3_forecast headcount_growth4_forecast headcount_growth1_forecast
	export excel "$ch1_output/chapter1.xlsx", sheet("fig2 `line'", modify) firstrow(varlabels)
}
