
********************************************************************************
*	Figure 4. The regional distribution of poverty changes depending on the standard, but overall, most poor people are concentrated in SSA and South Asia
********************************************************************************
foreach pl in 215 365 685 {				// Loop through 2.15 and 6.85 poverty lines
	local line = `pl' / 100
	use "$ch1_data_processed/poverty_country_lineup.dta", clear
	keep if poverty_line == `line'
	keep if year		 == 2024
	keep country_code reporting_level headcount year population
	* Merge in missing countries and population
	merge 1:1 country_code reporting_level year using "$ch1_data_processed/pop_reportinglevel", nogen
	rename 	country_code code
	* Merge country classifications
	merge 	m:1 code using "$ch1_data_processed/countrycodes_current.dta",		///
					 keepusing(region_pip_name incgroup_current economy) 
	keep if year == 2024
	* Clean up 
	keep if reporting_level=="national" | inlist(code,"ARG") 										// Drop urban and rural for all but Argentina
	drop if inlist(code,"ARG") & reporting_level=="national" 										// Drop nationall for Argentina	* Calculate regional poverty to fill in missing numbers
	* Calculate regional poverty to fill in missing numbers
	bysort region_pip_name year: egen avg_pov = wtmean(headcount),weight(population)
	* Fill in missing values
	replace population = pop if population == . 													// Get population
	replace headcount  = avg_pov if headcount == . 	
	* Generate relevant variables
	gen pop_in_poverty = headcount*population / 1000000
	keep region_pip_name economy pop_in_poverty
	* For excel figure
	sort region_pip_name economy pop_in_poverty
	order region_pip_name economy pop_in_poverty
	bys region_pip_name: replace region_pip_name = "" if _n!=1
	label var pop_in_poverty "Millions of poor at $`pl'"
	export excel "$ch1_output/chapter1.xlsx", sheet("fig4 `line'", modify) firstrow(varlabels)
}
