
********************************************************************************
*	Figure 5. Poverty forecasts through 2030 by region
********************************************************************************
foreach pl in 215 685 {				// Loop through 2.15 and 6.85 poverty lines
	use "$ch1_data_processed/projections_region_2030.dta", clear
	local line = `pl' / 100
	keep	if povertyline == `line'
	drop	povertyline
	replace headcount = headcount / 100
	tempfile proj`pl'
	save `proj`pl''
}

foreach pl in 215 685 {				// Loop through 2.15 and 6.85 poverty lines
	local line = `pl' / 100
	use "$ch1_data_processed/poverty_aggregates.dta", clear
	keep if poverty_line == `line'
	keep if year>2009
	drop if inlist(region_code, "AFE", "AFW", "WLD") 
	keep region_code year headcount
	* Add forecasts
	append using `proj`pl''
	reshape wide headcount, i(year) j(region_code) string
	label var headcountEAP "East Asia and Pacific"
	label var headcountECA "Europe and Central Asia"
	label var headcountLAC "Latin America and the Caribbean"
	label var headcountMNA "Middle East and North Africa"
	label var headcountOHI "Rest of the world"
	label var headcountSAS "South Asia"
	label var headcountSSA "Sub-Saharan Africa"
* Generate separate forecast variable for Excel
foreach var of varlist headcount* {
	gen `var'_forecast = `var' if year > 2021
	replace `var'	   = .	   if year > 2022
}
replace headcountMNA_forecast = headcountMNA if year > 2017 					/// // Change MENA line to dotted after 2018, as data does not meet coverage rule
												& headcountMNA_forecast == .	
replace headcountMNA		  = . 			 if year > 2018 			
replace headcountSSA_forecast = headcountSSA if year > 2018 					/// // Change SSA line to dotted after 2018, as data does not meet coverage rule
												& headcountSSA_forecast == .	
replace headcountSSA		  = . 			 if year > 2019 	
order year headcount*
export excel "$ch1_output/chapter1.xlsx", sheet("fig5 `line'", modify) firstrow(varlabels)
}
