
********************************************************************************
*	Figure 7. Regional disparities in poverty reduction
********************************************************************************
*************************
* a) and b) Poverty rates
*************************
foreach pl in 215 685 {				// Loop through 2.15 and 6.85 poverty lines
	local line = `pl' / 100
	use "$ch1_data_processed/poverty_aggregates.dta", clear
	keep if poverty_line == `line'
	keep if year > 1989
	drop if inlist(region_code, "AFE", "AFW", "WLD") 
	keep region_name year headcount
	replace region_name = "Rest of the world" ///
		if region_name == "Other High Income Countries"
	* Generate relevant variables
	encode 	region_name, gen(region) label(reg_l) 								// region_name to show names
	keep 	region year headcount
	* Keep labels of regions
	levelsof region, local(l) 
	foreach i of local l {
		local d`i'  `: label reg_l `i''
	}
	* Get in Excel format
	reshape wide headcount, i(year) j(region)
	foreach i of local l {
		label var headcount`i' "`d`i''"
	}
	* Create breaks for regions without coverage
	replace headcount4 = . if year > 2001 & year < 2003
	replace headcount6 = . if year > 1996 & year < 2002
	* Generate separate forecast variable for Excel 
	foreach var of varlist headcount*  {
		gen 	`var'_forecast = `var' if year > 2021
		replace `var'	   = .	   	   if year > 2022
	}
	replace headcount4_forecast = headcount4 if year > 2017 					/// // Change MENA line to dotted after 2018, as data does not meet coverage rule
												& headcount4_forecast == .	
	replace headcount4	 		= . 		 if year > 2018 															
	replace headcount7_forecast = headcount7 if year > 2018 					/// // Change SSA line to dotted after 2019, as data does not meet coverage rule
												& headcount7_forecast == .	
	replace headcount7	 		= . 		 if year > 2019	
	keep if year>1989
	export excel "$ch1_output/chapter1.xlsx", sheet("fig7ab `line'", modify) firstrow(varlabels)
}	

*************************
* c) and d) Poverty numbers (separating China and India)
*************************

foreach pl in 215 685 {				// Loop through 2.15 and 6.85 poverty lines
	local line = `pl' / 100
	use "$ch1_data_processed/poverty_country_lineup.dta", clear
	keep if poverty_line == `line'
	keep if year>1989
	* Merge in missing countries and population
	merge 1:1 country_code reporting_level year using "$ch1_data_processed/pop_reportinglevel"
	drop 	_merge
	rename 	country_code code
	rename	year year_data
	* Merge country classifications
	merge 	m:1 code year_data using "$ch1_data_processed/countrycodes_yearly.dta", ///
							   keepusing(region_pip_name) 
	rename	year_data year
	keep if year > 1989
	* Clean up 
	keep if reporting_level=="national" | inlist(code,"ARG") 										// Drop urban and rural for all but Argentina
	drop if inlist(code,"ARG") & reporting_level=="national" 										// Drop nationall for Argentina	* Calculate regional poverty to fill in missing numbers
	* Calculate regional poverty to fill in missing numbers
	bysort region_pip_name year: egen avg_pov = wtmean(headcount),weight(population)
	* Fill in missing values
	replace population = pop if population == . 													// Get population
	replace headcount  = avg_pov if headcount == . 	
	gen 	pop_in_poverty = headcount * population
	* Generate relevant variables and groups
	replace region_pip_name = "East Asia and Pacific excl. China" if region_pip_name == "East Asia and Pacific"
	replace region_pip_name = "South Asia excl. India" 			  if region_pip_name == "South Asia"
	replace region_pip_name = "China" if code == "CHN"
	replace region_pip_name = "India" if code == "IND"
	encode 	region_pip_name, gen(region) label(reg_l) 
	* Keep labels of region
	levelsof region, local(l) 
	foreach i of local l {
		local d`i'  `: label reg_l `i''
	}
	collapse (sum) pop_in_poverty, by(year region)
	replace pop_in_poverty = round(pop_in_poverty / 1000000, 0.1)
	* Excel format
	reshape wide pop_in_poverty, i(year) j(region)
	foreach i of local l {
		label var pop_in_poverty`i' "`d`i''"
	}
	export excel "$ch1_output/chapter1.xlsx", sheet("fig7cd `line'", modify) firstrow(varlabels)
}

