
********************************************************************************
*	Figure B1.1.1 The composition of the global population has changed since 1990 
********************************************************************************
use "$ch1_data_processed/poverty_country_lineup.dta", clear
drop if poverty_line == 3.65
keep if year == 1990 | year == 2024
keep country_code poverty_line headcount year population reporting_level
* Merge in missing countries and population
merge m:1 country_code reporting_level year using "$ch1_data_processed/pop_reportinglevel", nogen
rename 	country_code code
rename 	year year_data
* Merge country classifications
merge 	m:1 code year_data using "$ch1_data_processed/countrycodes_yearly.dta", ///
						   keepusing(region region_pip incgroup_historical) nogen
rename  year_data year
keep	if year == 1990 | year == 2024
* Clean up 
keep if reporting_level=="national" | inlist(code,"ARG") 										// Drop urban and rural for all but Argentina
drop if inlist(code,"ARG") & reporting_level=="national" 										// Drop nationall for Argentina
* Create one observation in missing data for each poverty line
expand 2 if headcount==.
bysort code year reporting_level: gen poverty_line_id = _n
replace poverty_line = 2.15 if poverty_line_id==1 & headcount==.
replace poverty_line = 6.85 if poverty_line_id==2 & headcount==.
* Calculate regional poverty to fill in missing numbers
bysort region_pip year poverty_line: egen avg_pov = wtmean(headcount),weight(population)
* Fill in missing values
replace population = pop if population == . 													// Get population
replace headcount  = avg_pov if headcount == . 	
gen 	pop_in_poverty = headcount * population
* Produce output
collapse (sum) pop_in_poverty population, by(year incgroup_historical poverty_line)					// Data on income group level
replace poverty_line = poverty_line * 100
reshape wide pop_in_poverty, i(year incgroup_historical) j(poverty_line)
gen 	pop_in_povertyrest =  population - pop_in_poverty685										// Population above 6.85
replace pop_in_poverty685  =  pop_in_poverty685 - pop_in_poverty215									// Population between 6.85 and 2.15
rename  population pop_in_povertytotal

foreach var in pop_in_poverty215 pop_in_poverty685 pop_in_povertyrest pop_in_povertytotal {			// Population in millions
		replace `var' = `var' / 1000000
}
gen 	incg = 1 if incgroup_historical == "Low-income" 											// Numeric for order
replace incg = 2 if incgroup_historical == "Lower-middle-income" 
replace incg = 3 if incgroup_historical == "Upper-middle-income" 
replace incg = 4 if incgroup_historical == "High-income"

* Population by income groups
preserve
keep incgroup_historical year pop_in_povertytotal
bys year: egen tot_pop = sum(pop_in_povertytotal)
reshape wide pop_in_povertytotal tot_pop, i(incgroup_historical) j(year)
label var pop_in_povertytotal1990 "1990"
label var pop_in_povertytotal2024 "2024"
gen share90 = string(pop_in_povertytotal1990 / tot_pop1990 * 100, "%8.0f") + "%"
gen share24 = string(pop_in_povertytotal2024 / tot_pop2024 * 100, "%8.0f") + "%"
drop tot_pop*
export excel "$ch1_output/chapter1.xlsx", sheet("figB1.1.1", modify) firstrow(varlabels) cell(A6)
restore

* Population by poverty lines
collapse (sum) pop_in_poverty215 pop_in_poverty685 pop_in_povertyrest pop_in_povertytotal, by(year)
gen share_215  = string(pop_in_poverty215 / pop_in_povertytotal * 100, "%8.0f") + "%"
gen share_685  = string(pop_in_poverty685 / pop_in_povertytotal * 100, "%8.0f") + "%"
gen share_rest = string(pop_in_povertyrest / pop_in_povertytotal * 100, "%8.0f") + "%"
drop pop_in_povertytotal
label var pop_in_poverty215 "Less than $2.15"
label var pop_in_poverty685 "Between $2.15 and $6.85"
label var pop_in_povertyrest "More than $6.85"
export excel "$ch1_output/chapter1.xlsx", sheet("figB1.1.1", modify) firstrow(varlabels) cell(A1)
