

/*******************************************************************************
	Figure B1.2.1: Share of population with survey data in 2020 or later 

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 6 August 2024     
*******************************************************************************/

// Program set-up
clear all
set more off

/* a: Across regional groups */
use "$ch1_data_processed/data_coverage_pspr_pppr.dta", clear 
drop year
drop if (inlist(group,"IDA","FCV") | inlist(group,"LIC","UMIC","HIC","LMIC"))
gen group_code = group
replace group= "East Asia and Pacific" if group=="EAP"	
replace group= "Europe and Central Asia" if group=="ECA"			
replace group= "Latin America and the Caribbean" if group=="LAC"	
replace group= "Middle East and North Africa" if group=="MNA"	
replace group= "Rest of the World" if group=="OHI"
replace group= "South Asia" if group=="SAS"
replace group= "Sub-Saharan Africa" if group=="SSA"
replace group = "World" if group=="WLD"

* Prepare sorting variable
replace group_code = "TOHI" if group_code=="OHI" 
gsort group_code -type 
gen j = _n
rename coverage y

// Export results to Excel
preserve 
	rename group region_name  
	drop group_code j 
	rename y coverage 
	export excel "$ch1_output/chapter1.xlsx", sheet("figB1.2.1a") firstrow(var) sheetreplace
restore 

// Make chart
reshape wide y, i(group group_code type) j(j)
egen sorting_var = group(group_code)
graph hbar y1-y16, over(group, sort(sorting_var)) ytitle("Population coverage (%)") ylab(0(10)100) nofill yline(50, lpattern(solid) lcolor(red)) ///
 bar(1, lwidth(medium) lpattern(solid) lcolor(rgb("237 52 46"))  fcolor(rgb("255 255 255"))) ///
	bar(2, lwidth(medium) lpattern(solid) lcolor(rgb("237 52 46"))  fcolor(rgb("237 52 46"))) ///
	bar(3, lwidth(medium) lpattern(solid) lcolor(rgb("163 163 163"))  fcolor(rgb("255 255 255"))) ///
	bar(4, lwidth(medium) lpattern(solid) lcolor(rgb("163 163 163"))  fcolor(rgb("163 163 163"))) ///
	bar(5, lwidth(medium) lpattern(solid) lcolor(rgb("58 190 203"))  fcolor(rgb("255 255 255"))) ///
	bar(6, lwidth(medium) lpattern(solid) lcolor(rgb("58 190 203"))  fcolor(rgb("58 190 203"))) ///
	bar(7, lwidth(medium) lpattern(solid) lcolor(rgb("14 100 169"))  fcolor(rgb("255 255 255"))) ///
	bar(8, lwidth(medium) lpattern(solid) lcolor(rgb("14 100 169"))  fcolor(rgb("14 100 169"))) ///
	bar(9, lwidth(medium) lpattern(solid) lcolor(rgb("255 129 51"))  fcolor(rgb("255 255 255"))) ///
	bar(10, lwidth(medium) lpattern(solid) lcolor(rgb("255 129 51"))  fcolor(rgb("255 129 51"))) ///
	bar(11, lwidth(medium) lpattern(solid) lcolor(rgb("255 213 137"))  fcolor(rgb("255 255 255"))) ///
	bar(12, lwidth(medium) lpattern(solid) lcolor(rgb("255 213 137"))  fcolor(rgb("255 213 137"))) ///
	bar(13, lwidth(medium) lpattern(solid) lcolor(rgb("153 245 255"))  fcolor(rgb("255 255 255"))) ///
	bar(14, lwidth(medium) lpattern(solid) lcolor(rgb("153 245 255"))  fcolor(rgb("153 245 255"))) ///
	bar(15, lwidth(medium) lpattern(solid) lcolor(rgb("71 71 72"))  fcolor(rgb("255 255 255"))) ///
	bar(16, lwidth(medium) lpattern(solid) lcolor(rgb("71 71 72"))  fcolor(rgb("71 71 72")))  ///
	ylab(0(25)100) legend(position(6)) ///
	legend(order(15 "PSPR 2022" 16 "PPPR 2024") ///
		row(1) symxsize(*.5) symysize(*.8) size(medsmall)) ysize(8) xsize(10)

// Save chart
graph export "$ch1_output/ch1_figB1.2.1a.eps", as(eps) replace
graph export "$ch1_output/ch1_figB1.2.1a.png", as(png) replace 



/* b: Across income and other groups */
use "$ch1_data_processed/data_coverage_pspr_pppr.dta", clear 
drop year
keep if (inlist(group,"IDA","FCV") | inlist(group,"LIC","UMIC","HIC","LMIC"))
br 
gen group_code = group
replace group= "Low-income countries" if group=="LIC"	
replace group= "Lower-middle-income countries" if group=="LMIC"			
replace group= "Upper-middle-income countries" if group=="UMIC"	
replace group= "High-income countries" if group=="HIC"	
replace group= "Fragile and conflict-affected countries" if group=="FCV"
replace group= "IDA countries" if group=="IDA"

* Prepare sorting variable
replace group_code = "ALIC" if group_code=="LIC"
replace group_code = "BLMIC" if group_code=="LMIC"
replace group_code = "CUMIC" if group_code=="UMIC"
replace group_code = "DHIC" if group_code=="HIC"
replace group_code = "EFCV" if group_code=="FCV"
replace group_code = "FIDA" if group_code=="IDA"
gsort group_code -type 
gen j = _n
rename coverage y

// Export results to Excel
preserve 
	rename group group_name  
	drop group_code j 
	rename y coverage 
	export excel "$ch1_output/chapter1.xlsx", sheet("figB1.2.1b") firstrow(var) sheetreplace
restore 

// Make chart
reshape wide y, i(group group_code type) j(j)
egen sorting_var = group(group_code)
graph hbar y1-y12, over(group, sort(sorting_var)) ytitle("Population coverage (%)") ylab(0(10)100) nofill yline(50, lpattern(solid) lcolor(red)) ///
	bar(1, lwidth(medium) lpattern(solid) lcolor(rgb("255 213 137"))  fcolor(rgb("255 255 255"))) ///
	bar(2, lwidth(medium) lpattern(solid) lcolor(rgb("255 213 137"))  fcolor(rgb("255 213 137"))) ///
	bar(3, lwidth(medium) lpattern(solid) lcolor(rgb("255 129 51"))  fcolor(rgb("255 255 255"))) ///
	bar(4, lwidth(medium) lpattern(solid) lcolor(rgb("255 129 51"))  fcolor(rgb("255 129 51"))) ///
	bar(5, lwidth(medium) lpattern(solid) lcolor(rgb("153 245 255"))  fcolor(rgb("255 255 255"))) ///
	bar(6, lwidth(medium) lpattern(solid) lcolor(rgb("153 245 255"))  fcolor(rgb("153 245 255"))) ///
	bar(7, lwidth(medium) lpattern(solid) lcolor(rgb("14 100 169"))  fcolor(rgb("255 255 255"))) ///
	bar(8, lwidth(medium) lpattern(solid) lcolor(rgb("14 100 169"))  fcolor(rgb("14 100 169"))) ///
	bar(9, lwidth(medium) lpattern(solid) lcolor(rgb("71 71 72"))  fcolor(rgb("255 255 255"))) ///
	bar(10, lwidth(medium) lpattern(solid) lcolor(rgb("71 71 72"))  fcolor(rgb("71 71 72"))) ///
	 bar(11, lwidth(medium) lpattern(solid) lcolor(rgb("237 52 46"))  fcolor(rgb("255 255 255"))) ///
	bar(12, lwidth(medium) lpattern(solid) lcolor(rgb("237 52 46"))  fcolor(rgb("237 52 46"))) ///
	ylab(0(25)100) legend(position(6)) ///
	legend(order(9 "PSPR 2022" 10 "PPPR 2024") ///
		row(1) symxsize(*.5) symysize(*.8) size(medsmall)) ysize(8) xsize(10)

// Save chart
graph export "$ch1_output/ch1_figB1.2.1b.eps", as(eps) replace
graph export "$ch1_output/ch1_figB1.2.1b.png", as(png) replace 


