
/*******************************************************************************
	Figure B1.4.1: Global poverty trends - absolute versus societal poverty

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 6 August 2024     
*******************************************************************************/


// Load aggregate data 
use "$ch1_data_processed/poverty_aggregates.dta", clear
keep region_code region_name poverty_line headcount spr year 
keep if inrange(year,1990,2022) 
replace headcount = 100*headcount 
replace spr = 100*spr

keep if region_code=="WLD"
drop if poverty_line>24
bysort region_code year (poverty_line): gen j = _n
reshape wide headcount, i(region_code poverty_line year) j(j)

collapse headcount* spr,by(region_code region_name year)
format headcount* %12.0gc

// Make chart
line headcount* spr year, sort xtitle("") ytitle("Poverty rate (%)") ///
 legend(order(1 "$2.15" 2 "$3.65" 3 "$6.85" 4 "Societal poverty line") ///
	row(1) pos(6) symxsize(*.4) symysize(*.7) size(small)) ///
 ysize(8) xsize(8) lcolor("237 52 46" "163 163 163" "58 190 203" "255 129 51") ///
 lwidth(medthick medthick medthick thick)
 
// Save and export chart
graph export "$ch1_output/ch1_figB1.4.1_poverty_trends.eps", as(eps) replace
graph export "$ch1_output/ch1_figB1.4.1_poverty_trends.png", as(png) replace 

lab var headcount1 "Poverty rate at $2.15 (%)"
lab var headcount2 "Poverty rate at $3.65 (%)"
lab var headcount3 "Poverty rate at $6.85 (%)"
lab var spr "Poverty rate at the societal poverty line (%)"
lab var region_code "Region code"
lab var region_name "Region name"
lab var year "Year"
export excel "$ch1_output/chapter1.xlsx", sheet("figB1.4.1") firstrow(varlabels) sheetreplace
