/*
Save input data
*/
/* Commands to retrieve data from PIP, uncomment to get raw data

pip cleanup 

*** save data from pip ***

// population data 
pip tables, table(pop) clear $pipoptions
keep if data_level=="national" | country_code=="ARG"
drop if data_level!="urban" & country_code=="ARG"
save "${ch2_input_processed}sp_pop_totl.dta", replace

// population data with reporting level
pip tables, clear table(pop) ${pipoptions}
rename data_level reporting_level
rename value pop
keep country_code year pop reporting_level
save "$ch2_input_processed/pop_reportinglevel", replace


// Prosperity Gap data
pip, $pipoptions nowcasts clear
* Merge in missing countries and population
merge 1:1 country_code reporting_level year using "$ch2_input_processed/pop_reportinglevel", nogen
* Merge country classifications
rename 	country_code code
rename  year year_data
keep code year welfare_type population pg i pop reporting_level region_name
merge 	m:1 code year_data using "$ch2_input_processed/ClASS_FY24.dta", 			///	
				 keepusing(region_pip economy) nogen
* Correct country name
replace economy = "Czechia" if economy == "Czech Republic"
keep if reporting_level=="national" | inlist(code,"ARG") 										// Drop urban and rural for all but Argentina
drop if inlist(code,"ARG") & reporting_level=="national" 										// Drop national for Argentina	* Calculate regional 
drop if year < 1990
* Add region codes for 23/24 
bys code (year): carryforward region_pip, replace												// Add regions to latest years (not in CLASS_FY24)
bys region_pip (year): carryforward region_name, replace										// Add regions names to all countries
* Calculate regional poverty to fill in missing numbers
bysort region_pip year: egen avg_pg = wtmean(pg),weight(population)
* Fill in missing values
replace population = pop if population == . 													// Get population
replace pg  	   = avg_pg if pg == . 	
drop avg*
rename (year_data code) (year country_code)
merge 	1:1 country_code year reporting_level using "$ch2_input_raw/mean_bottomcode.dta", nogen
gen i 			   = mean * pg/25																// mean ratio deviation (inequality)
save "${ch2_input_processed}PG_1981_2024_3pr24.dta", replace


// Prosperity Gap survey data

pip, $pipoptions clear
drop if reporting_level!="national" & inlist(country_code,"IND","CHN")
ren reporting_level area
ren welfare_time survey_year
gen wt = cond(welfare_type==1,"CON","INC")
drop welfare_type
ren wt welfare_type
keep country_code survey_year pg welfare_type year area
save "${ch2_input_processed}PG_surveyestimates_20240802.dta", replace



// PIP survey data for all the ginis
pip, $pipoptions  clear povline(2.15 3.65 6.85 25)
save "${ch2_input_processed}pip_3pr2024_v20240802", replace


// PIP country list
pip tables, table(country_list) clear $pipoptions
save "${ch2_input_processed}piptables_country_list.dta", replace


// Source for frameworks data: https://github.com/PIP-Technical-Team/aux_pfw/blob/DEV/pfw.dta
pip tables, table(framework) $pipoptions clear
save "$ch2_input_raw/pfw_v11.dta", replace

/*