
/*
figure 11: Sankey chart for change in the number of countries with inequality
*/

use "${ch2_input_processed}gini_intermediate_all.dta", clear

drop if year<2000

//drop if gini == .

gen 	layer = 1 if inlist(year,2000)
replace layer = 2 if inlist(year,2005)
replace layer = 3 if inlist(year,2010)
replace layer = 4 if inlist(year,2015)
replace layer = 5 if inlist(year,2020)
drop if missing(layer)

collapse (mean)giniever, by(country_code layer)


gen 	destination = 1 if giniever<30
replace destination = 2 if inrange(giniever,30,40)
replace destination = 3 if giniever>40

egen c = group(country_code)
sort c layer

xtset c layer

bys country_code (layer): gen 		source = destination[_n-1]

drop if source==.

gen num = 1
collapse (count) num, by(layer destination source)

lab def a 1 "(a) Low" 2 "(b) Moderate" 3 "(c) High"
lab val destination source a

sankey num, from(source) to(destination) by(layer) sort1(name, label(valuelable)) valsize(3) labsize(3)  ///
	ctitles("2000" "2005" "2010" "2015" "2020") ctg(-10) cts(3) 

graph export "${ch2_figure}Fig11_sankey.png", replace	
graph export "${ch2_figure}Fig11_sankey.eps", replace		  


// save data 
reshape wide num , i(layer source) j(destination)
foreach v of varlist num* {
	replace `v' = 0 if missing(`v')
}
decode source, gen(start_year)

gen 	year = "2000-2005" if layer==2
replace year = "2005-2010" if layer==3
replace year = "2010-2015" if layer==4
replace year = "2015-2020" if layer==5

label var start_year "Start year inequality"
label var num1 "End year low inequality"
label var num2 "End year moderate inequality"
label var num3 "End year high inequality"

keep year start_year num*
order year start_year num*

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig11") sheetreplace firstrow(varlabel)