/*
figure 12: Gini change over time compared to initial gini level
*/

use "$ch2_input_processed/gini_intermediate_all.dta", clear									// add welfare type
keep if !missing(welfare_type)
keep country_code welfare_type 
duplicates drop country_code, force 											
tempfile type 
save 	`type'

use "$ch2_input_processed/gini_intermediate_all.dta", clear
keep if inlist(year,2000,2022)
merge m:1 country_code using `type', nogen update

drop if country_code=="HTI"														// Haiti compares income and consumption surveys, so drop

bys country_code (year): gen 	 change = ( (giniever/giniever[_n-1])^(1/(year-year[_n-1])) - 1 ) * 100
bys country_code (year): replace change = change[_n+1] if missing(change)
drop if change == 0 																// countries using same survey 

tw 	scatter change giniever if year==2000 & welfare_type=="consumption", ms(Oh) mc("$color1") || ///
	scatter change giniever if year==2000 & welfare_type=="income", ms(Oh) mc("$color6") || ///
	lfit change giniever    if year==2000 & welfare_type=="consumption", lc("$color1") || ///
	lfit change giniever  	if year==2000 & welfare_type=="income", lp(shortdash) lc("$color6") ///
	yline(0, lp(dash) lc(gray)) ///
	ytitle("Annualized change in Gini index 2000--2022, %") xtitle("Initial Gini index") ///
	legend(pos(6) row(2) order(1 "Consumption" 2 "Income" 3 "Fitted line, consumption" 4 "Fitted line, income")) ///
	xsize(12) ysize(10)
	
graph export "${ch2_figure}Fig12_gini_correlation.png", replace	
graph export "${ch2_figure}Fig12_gini_correlation.eps", replace		


// save data 
keep  country_name welfare_time year welfare_type giniever change 
order country_name welfare_time year welfare_type giniever change
ren giniever gini

label var welfare_type 	"Welfare type, consumption or income"
label var gini			"Gini index"
label var change 		"Annualized change, %"

format gini change %5.2f
export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig12") sheetreplace firstrow(varlabel)