/*
figure 13: Share in High, moderate, low inequality over time.
*/

***************************************************
*** figure 13:  Inequality in a typical country ***
***************************************************

use "$ch2_input_processed/gini_intermediate_all.dta", clear
keep if gini!=.

keep if year>=2000
drop if year==2023

gen tinterval = int((year-2000)/5)+1											// 5-yr intervals 

tab tinterval, gen(waves_)

foreach v of varlist waves_* {													// tag if country has survey in each period
	egen t`v' = max(`v'), by(country_code)
}
drop waves_*

egen rsum = rowtotal(twaves_*)
gen balanced = rsum==5

unique country_code if balanced==1 												// ID for balanced sample
unique country_code if balanced==1 & welfare_type=="income"						

unique country_code if tinterval==1												// count the number of countries in each period
unique country_code if tinterval==2
unique country_code if tinterval==3
unique country_code if tinterval==4
unique country_code if tinterval==5

collapse (p50)gini (p50)population, by(country_code tinterval welfare_type balanced)

preserve
	gen countrycount_unbal = 1
	collapse (mean)unwt_unbal = gini (sum) countrycount_unbal, by(tinterval welfare_type)				// gini for all countries
	tempfile unwt_unbal
	save `unwt_unbal'
restore
	gen countrycount_bal = 1
	collapse (mean)unwt_bal = gini (sum) countrycount_bal if balanced==1, by(tinterval welfare_type)	// balanced sample only gini
	tempfile unwt_bal
	save `unwt_bal'


clear
use `unwt_unbal', clear

merge 1:1 tinterval welfare_type using `unwt_bal', nogen

local endash = ustrunescape("\u2013")
dis "`endash'"

lab def time 1 "2000`endash'04" 2 "2005`endash'09" 3 "2010`endash'14" 4 "2015`endash'19" 5 "2020`endash'22"
lab val tinterval time

two (connected unwt_unbal tinterval if welfare_type=="consumption", lcolor("$color2") xtitle("") ///
	xlab(,val ) ylab(30(4)42,format(%9.0g) ) ///
	ytitle("Average within-country Gini index")) ///
	(line unwt_bal tinterval if welfare_type=="consumption", lpattern(dash) lcolor("$color2")) ///
	(connected unwt_unbal tinterval if welfare_type=="income", lcolor("$color8") mc("$color8")) ///
	(line unwt_bal tinterval if welfare_type=="income", lpattern(dash) lcolor("$color8")), ///
	legend(ring(0) row(4) pos(7) order(1 "Consumption" 2 "Consumption, balanced" ///
		3 "Income" 4 "Income, balanced") ///
	size(small)) xsize(12) ysize(10) graphregion(margin(l=5 r=5)) 
	
graph export "${ch2_figure}Fig13_AvgGini_period_evolution.png", replace
graph export "${ch2_figure}Fig13_AvgGini_period_evolution.eps", replace


// save data
label var welfare_type 	"Income or consumption survey"
label var tinterval 	"Period"
label var unwt_unbal 	"Median Gini, all countries"
label var unwt_bal 		"Median Gini, balanced sample"
label var countrycount_unbal 	"Number of country, all country sample"
label var countrycount_bal 		"Number of country, balanced sample"	

keep welfare_type tinterval countrycount_bal unwt_bal countrycount_unbal unwt_unbal
order  welfare_type tinterval countrycount_bal unwt_bal countrycount_unbal unwt_unbal

format unwt* %5.2f

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig13") sheetreplace firstrow(varlabel)