/*
Figures 1: Regional/Global prosperity gap in 2024
*/

use "${ch2_input_processed}PG_1981_2024_3pr24.dta", clear

preserve							 									// global prosperity gap 
collapse pg (rawsum) pop [w=pop], by(year)
gen region_name = "World"
tempfile world 
save 	`world'
restore

collapse pg (rawsum) pop [w=pop], by(year region_name)					// regional prosperity gap

append using `world'

bys year:  gen pop2 	= pop if region_name=="World"
bys year: egen pop_wld 	= mean(pop2) 
bys year: egen pg2 		= mean(pg) if region_name=="World"
bys year: egen pg_wld 	= mean(pg2) 
drop pop2 pg2

gen double pop_reg_s 	= pop/pop_wld * 100								// generate regional contributions as share of global 
gen pg_reg_contribution = pg * pop_reg_s
gen pg_reg_con_share	= pg_reg_contribution/pg_wld


replace region_name = "Rest of the world" if region_name == "Other High Income Countries"

gen 	sortvar = 5 if region_name=="East Asia & Pacific"
replace sortvar = 1 if region_name=="Europe & Central Asia"
replace sortvar = 4 if region_name=="Latin America & Caribbean"
replace sortvar = 3 if region_name=="Middle East & North Africa"
replace sortvar = 6 if region_name=="South Asia"
replace sortvar = 7 if region_name=="Sub-Saharan Africa"
replace sortvar = 2 if region_name=="Rest of the world"
drop 				if region_name=="World"
sort sortvar 

label var region_name 		"Region"
label var pg_reg_con_share 	"Prosperity Gap share"
label var pop_reg_s 		"Population share"
label var pg 				"Prosperity Gap"
keep if year==2024
keep region_name pg pg_reg_con_share pop_reg_s
format pg pop_reg_s %5.1f
order region pg_reg_con_share pop_reg_s
export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig1") sheetreplace firstrow(varlabel)