/*
Figures 4: Regional/Global prosperity gap, long term trends
*/

use "${ch2_input_processed}PG_1981_2024_3pr24.dta", clear

keep if year>=1990

preserve							 									// global prosperity gap 
collapse pg (rawsum) pop [w=pop], by(year)
gen region_name = "World"
tempfile world 
save 	`world'
restore

collapse pg (rawsum) pop [w=pop], by(year region_name)					// regional prosperity gap

append using `world'

bys year:  gen pop2 	= pop if region_name=="World"
bys year: egen pop_wld 	= mean(pop2) 
bys year: egen pg2 		= mean(pg) if region_name=="World"
bys year: egen pg_wld 	= mean(pg2) 
drop pop2 pg2

gen double pop_reg_s 	= pop/pop_wld									// generate regional contributions as share of global 
gen pg_reg_contribution = pg * pop_reg_s
gen pg_reg_con_share	= pg_reg_contribution/pg_wld * 100

* Create breaks for regions without coverage
replace pg = . if year > 2001 & year < 2003 & region_name == "Middle East & North Africa"
replace pg = . if year > 1996 & year < 2002 & region_name == "South Asia"
	
preserve 
keep region year pg 
reshape wide pg, i(region) j(year)
gen id = "Prosperity Gap"
tempfile prosgap
save	`prosgap'
restore 

keep region year *share
ren pg* pg 
reshape wide pg, i(region) j(year)
gen id = "Contribution to Global Prosperity Gap %"

append using `prosgap'


replace region_name = "Rest of the world" if region_name == "Other High Income Countries"

gen 	sortvar = 1 if region_name=="East Asia & Pacific"
replace sortvar = 2 if region_name=="Europe & Central Asia"
replace sortvar = 3 if region_name=="Latin America & Caribbean"
replace sortvar = 4 if region_name=="Middle East & North Africa"
replace sortvar = 5 if region_name=="South Asia"
replace sortvar = 6 if region_name=="Sub-Saharan Africa"
replace sortvar = 7 if region_name=="Rest of the world"
replace sortvar = 8 if region_name=="World"

gen 	sortgrp = 1 if id == "Prosperity Gap"
replace sortgrp = 2 if id == "Contribution to Global Prosperity Gap %"

sort sortgrp sortvar 

label var region_name 		"Region"
foreach v of varlist pg* {
	local n = substr("`v'",3,.)
	label var `v' "`n'"
}

keep id region pg*
order id region pg*
format pg* %5.1f

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig4") sheetreplace firstrow(varlabel)
