/*
Figures 5: decomposition of the the growth in prosperity gap into
			mean and inequality growths
*/

use "${ch2_input_processed}PG_1981_2024_3pr24.dta", clear

gen  			w_i 	= pop/mean												// generate the weights for within/between decomposition
bys year: egen 	sum_w_i = total(w_i)
gen  			weight  = w_i/sum_w_i

gen				I_g = weight * i
bys year: egen 	w_I = total(I_g)

collapse pg mean w_I [w=pop], by(year)

gen i = pg*mean/25
gen b_I = i/w_I

keep if inlist(year,1990,2000,2010,2019,2024)
keep year pg i mean b_I w_I
sort year

foreach v of varlist pg i mean b_I w_I {										// growth rates
	gen g`v' = ln(`v'/`v'[_n-1])/(year - year[_n-1]) * 100
}															

replace gmean = -1 * gmean														// so that mean+inequality change = pg change

keep year g*
drop gi
drop if year==1990

tostring year, replace
replace year="1990-2000" if year=="2000"
replace year="2000-2010" if year=="2010"
replace year="2010-2019" if year=="2019"
replace year="2019-2024 (projected)" if year=="2024" 

label var gpg 	"Global Prosperity Gap growth rate"
label var gmean "Contribution of mean growth"
label var gb_I  "Contribution of between-country inequality"
label var gw_I  "Contribution of within-country inequality"

format g* %5.2f
export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig5") sheetreplace firstrow(varlabel)
