/* 
Fig 6: GROWTH NEEDED TO REACH PROSPERITY
*/

// prosperity gaps from surveys
use "${ch2_input_processed}PG_surveyestimates_20240802.dta" , clear
encode welfare_type, gen(type)
keep country_code year pg type
ren country_code code
ren type welfare_type
tempfile pg
save `pg'

// mean and gini from the surveys
use "${ch2_input_processed}pip_3pr2024_v20240802.dta", clear
keep if poverty_line==2.15
keep if reporting_level=="national" | country_code=="ARG"						// keep only national or Argentina which has only urban survey
bys country_code reporting_level year (welfare_type): gen type = _n 			// keep only one welfare type per country-year; preference for consumption
drop if type==2
bys country_code reporting_level (year): gen num = _n							// keep the latest survey year for each country
bys country_code reporting_level (year): keep if num == _N
ren country_code code
merge 1:1 code year welfare_type using `pg', keep(3) nogen
keep country_name code year pg region_code mean headcount gini pop welfare_time welfare_type
gen i = pg * mean/25


gen pg_benchmark_i = 25/mean * 1.2												// PG if inequality == 1.2 or lowest level of inequality in data (BLR 2020)

bys welfare_type (mean): gen rank = _n											// ranking countries by welfare type

graph hbar pg_benchmark_i pg if rank <=20 & welfare_type==1, ///
	over(country_name, sort(rank) label(labsize(vsmall))) ///
	blabel(bar, format(%5.2f) size(vsmall)) stack ///
	ytitle("Prosperity Gap", size(small)) ///
	legend(ring(1) pos(6) row(2) order(1 "Prosperity Gap with benchmark inequality" 2 "Excess gap due to current level of inequality") ///
		size(vsmall) ) ///
	name(fig6, replace)
	
graph combine fig6, xsize(10) ysize(13)
	
graph export "${ch2_figure}Fig6_InequalityPenalty.png", replace	
graph export "${ch2_figure}Fig6_InequalityPenalty.eps", replace

// figure data
keep if rank<=20 & welfare_type==1

decode welfare_type, gen(welf_type)
drop welfare_type

keep country_name mean welfare_time welf_type pg_benchmark_i pg
order country_name welfare_time welf_type mean pg_benchmark_i pg
gsort -mean

label var country_name 	"Economy"
label var welfare_time 	"Survey year"
label var welf_type 	"Welfare type"
label var mean 			"Mean household daily per capita consumption"
label var pg			"Prosperity gap with current level of inequality"	
label var pg_benchmark_i"Prosperity gap with benchmark inequality"

format mean* pg* %6.2f

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig6") sheetreplace firstrow(varlabel)