/* 
Fig 7: number of years required for UMICs to reach prosperity
*/

// income group
use "${ch2_input_processed}CLASS_FY24.dta", clear					
keep code year_data incgroup_historical
ren year_data year
tempfile incg 
save 	`incg'

// prosperity gaps
use "${ch2_input_processed}PG_1981_2024_3pr24.dta" , clear
keep if inrange(year,1990,2023)
keep country_code year reporting_level pg 
ren country_code code
duplicates drop
tempfile pg
save `pg'


// latest survey mean income
use "${ch2_input_processed}pip_3pr2024_v20240802.dta", clear
drop if year<1990
keep if reporting_level=="national" | country_code=="ARG"
ren country_code code
bys code (year): gen num = _n 											
bys code: keep if num==_N 										// keep the latest survey
keep country_name code year region* welfare_type welfare_time reporting_level headcount mean gini population 

merge 1:1 code year reporting_level using `pg', keep(1 3) nogen
merge m:1 code year 				using `incg', keep(1 3) nogen

replace incgroup_historical="Upper middle income" if inlist(code,"CRI","IDN","ECU")	// 2023 surveys so adding the 2022 income groups
replace incgroup_historical="High income" 		  if inlist(code,"PAN")


// keep only UMICs 
keep if incgroup=="Upper middle income"

// poverty rank
sort mean
gen rank = _n


// target mean and necessary growth to get a pg=1 (or reach $25/day)
gen i = pg * mean/25													// calculate the level of inequality

gen targetmean = 25 * i
gen targetgrow = (targetmean/mean - 1)*100


// number of years necessary to achieve the target growth
gen growth_equal2 = 2 													// each country has same growth, 2%
gen year_req_equal2 = targetgrow/growth_equal2	

gen growth_equal4 = 4 													// this is equivalent to 2% growth and 1/2 inequality
gen year_req_equal4 = targetgrow/growth_equal4	


graph hbar year_req_equal2 year_req_equal4 if ///
	inlist(code,"COL","PRY","SRB","BRA","ARG") | inlist(code,"CRI","TUR", "BGR", "MYS"), ///
	over(country_name, sort(rank) label(labsize(vsmall))) blabel(total,format(%5.0f) size(vsmall)) ///
	ytitle("Number of years required to reach $25 on average", size(small)) ///
	legend(ring(0) pos(5) row(2) order(1 "2% annual per capita growth" ///
		2 "4% annual per capita growth" "Or, 2% growth with half inequality") size(vsmall)) ///
	 ylab(0(25)200, labsize(small)) name(fig7, replace)	

graph combine fig7, xsize(10) ysize(10)
	
graph export "${ch2_figure}Fig7_umic_years.png", replace	
graph export "${ch2_figure}Fig7_umic_years.eps", replace

/*
graph hbar year_req_equal2 year_req_equal4 if ///
	inlist(code,"COL","PRY","SRB","BRA","ARG") | inlist(code,"CRI","TUR", "BGR", "MYS"), ///
	over(country_name, sort(rank) label(labsize(vsmall))) blabel(total,format(%5.0f) size(vsmall)) ///
	ytitle("Number of years required to achieve prosperity", size(small)) ///
	legend(ring(0) pos(5) row(2) order(1 "2% annual growth + current inequality" ///
		2 "2% annual growth + half current inequality") size(vsmall)) ///
	 ylab(0(25)200, labsize(small)) name(fig7, replace)	

graph combine fig7, xsize(10) ysize(10)
*/


// figure data
decode welfare_type, gen(welf_type)
drop welfare_type

keep if inlist(code,"COL","PRY","SRB","BRA","ARG") | inlist(code,"CRI","TUR", "BGR", "MYS")
gsort -rank
keep country_name welfare_time welf_type year_req_equal2 year_req_equal4 

label var country_name 		"Economy"	
label var welfare_time 		"Survey year"
label var welf_type			"Welfare type"	
label var year_req_equal2 	"2% annual growth + current inequality" 	
label var year_req_equal4 	"2% annual growth + half current inequality" 

format year* welfare_time %5.0f

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig7") sheetreplace firstrow(varlabel)