/*
Figure 8: Share of countries by income and FCV group (latest survey)
*/

use "$ch2_input_processed/gini_intermediate_latest.dta", clear
ren country_code code

gen 	ginigroup = 2 if giniever>40
replace ginigroup = 1 if inrange(giniever,30,40)
replace ginigroup = 0 if missing(ginigroup)
gen count = 1


preserve 
collapse (count) count, by(incgroup_current ginigroup)
ren incgroup_current name
gen group = "Income group FY24"
tempfile income 
save 	`income'
restore 

collapse (count) count , by(fcv_current ginigroup)
ren fcv_current name 
gen group = "FCV group FY24"
append using `income'

bys group name: egen total = total(count)
gen double share = count/total * 100 

reshape wide share count total, i(name group) j(ginigroup) 

replace name = "Low" 			if name=="LIC"
replace name = "Lower middle" 	if name=="LMIC"
replace name = "Upper middle" 	if name=="UMIC"
replace name = "High" 			if name=="HIC"

gen 	sort = 1 if name=="FCV"
replace sort = 2 if name=="Not FCV"
replace sort = 3 if name=="Low"
replace sort = 4 if name=="Lower middle"
replace sort = 5 if name=="Upper middle"
replace sort = 6 if name=="High"

sort sort
keep name group share*
order group name share*

label var name 	 ""
label var share0 "Low inequality"
label var share1 "Moderate inequality"
label var share2 "High inequality"

format share* %5.0f

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig8") sheetreplace firstrow(varlabel)