/*
figure 9a and 9b: High gini over time.
*/

*****************************************
*** figure 9a:  Inequality over time ***
*****************************************

use "$ch2_input_processed/gini_intermediate_all.dta", clear

gen 	ginigroup = 2 if giniever>40
replace ginigroup = 1 if inrange(giniever,30,40)
replace ginigroup = 0 if missing(ginigroup)
gen 	ginicount = 1

collapse (sum) ginicount, by(year ginigroup)

reshape wide ginicount, i(year) j(ginigroup)

graph bar ginicount0 ginicount1 ginicount2 if inrange(year,2000,2022), bar(1, color($color3)) bar(2, color($color2)) bar(3, color($color1)) ///
	stack over(year, label(angle(45) labsize(small))) blabel(bar, position(inside) color(black) size(small)) ///
	legend(pos(6) row(1) order(1 "Low inequality" 2 "Moderate inequality" 3 "High inequality") ///
		symxsize(*0.5) region(lcolor(white))) ///
	graphregion(color(white)) ylab(0(50)170)  ///
	ytitle("Number of countries") plotregion(margin(0 0 0 0)) name(Fig9a, replace)

graph combine Fig9a, xsize(12) ysize(10)

graph export "${ch2_figure}Fig9a.png", replace
graph export "${ch2_figure}Fig9a.eps", replace


// graph data
label var ginicount0 "Number of countries with low inequality"
label var ginicount1 "Number of countries with moderate inequality"
label var ginicount2 "Number of countries with high inequality"
export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig9a") sheetreplace firstrow(varlabel)

************************************************
*** figure 9b:  Inequality change over time ***
************************************************

use "$ch2_input_processed/gini_intermediate_all.dta", clear

gen ginihigh 	= giniever>40
collapse (sum) ginihigh,  by(country_code year)	

by country_code : gen 		high_ineq_change =  1 if ginihigh[_n] != ginihigh[_n - 1]  & year!=2000 & ginihigh == 1		// moving into high
by country_code : replace 	high_ineq_change = -1 if ginihigh[_n] != ginihigh[_n - 1]  & year!=2000 & ginihigh == 0		// moving out of high

gen high_ineq_change_pos =  1 if high_ineq_change ==  1
gen high_ineq_change_neg = -1 if high_ineq_change == -1

collapse (sum) high_ineq_change*, by(year)

twoway  bar high_ineq_change_pos high_ineq_change_neg year , barwidth(0.75 0.75) || ///
		lowess high_ineq_change year 					   , lpattern(dash) lc("$color6") ///
		legend(pos(6) row(1) symxsize(*0.5) region(lcolor(white))  ///
			order(1 "Switched to high" 2 "Switched to not-high" 3 "Fitted values")) ///
			graphregion(color(white)) ///
		xsize(13) ysize(7) ///
		xlab(2000(1)2022,angle(45)) ylab(-8(1)4) ///
		ytitle("Number of countries") xtitle("") plotregion(margin(0 0 0 0)) name(Fig9b, replace)

graph combine Fig9b, xsize(12) ysize(10)

graph export "${ch2_figure}Fig9b.png", replace
graph export "${ch2_figure}Fig9b.eps", replace


// graph data 
label var high_ineq_change 		"Net change in the number of countries switching"
label var high_ineq_change_pos 	"Number of countries moving to high inequality"
label var high_ineq_change_neg 	"Number of countries moving out of high inequality"

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig9b") sheetreplace firstrow(varlabel)