/* 
Figure 2A.1: comparing the growth in the B40 v the growth in prosperity gap
*/

// prosperity gap 
use "${ch2_input_processed}PG_surveyestimates_20240802.dta" , clear
gen 	welfaretype = 1 if welfare_type=="CON"
replace welfaretype = 2 if welfare_type=="INC"
drop welfare_type 
ren welfaretype welfare_type
ren country_code code
keep code year pg welfare_type survey_year
tempfile pg
save `pg'


// import gini
use "${ch2_input_processed}pip_3pr2024_v20240802.dta", clear
keep if reporting_level=="national" | country_code=="ARG" 
keep if poverty_line == 2.15
keep country_code year gini welfare_type welfare_time
ren country_code code
ren welfare_time survey_year
tempfile gini
save 	`gini'


// bottom 40 growth 
use "${ch2_input_processed}b40_growth_3PR.dta", clear
merge 1:1 code survey_year welfare_type using `pg', nogen keep(3)
merge 1:1 code survey_year welfare_type using `gini', nogen keep(3)


*** change in pg and gini ***

bys code (survey_year): gen gpg   = ((pg/pg[_n-1])^(1/(survey_year-survey_year[_n-1])) - 1) * 100
bys code (survey_year): gen ggini = ((gini/gini[_n-1])^(1/(survey_year-survey_year[_n-1])) - 1) * 100



**********************************
*** Fig 2A.1: bottom 40 growth ***
**********************************

gen 	line45 = -20 in 1/50
replace line45 = 20 if missing(line) 
gen 	negl45 = -1*line45

tw 	scatter growthb40 gpg, ms(oh) mc("$color1") || line line45 negl45, || ///
	scatter growthb40 gpg if inlist(code,"SVK"), mc(none) mlab(code) mlabc(black) mlabsize(vsmall) mlabpos(9) || ///
	scatter growthb40 gpg if inlist(code,"ROU"), mc(none) mlab(code) mlabc(black) mlabsize(vsmall) mlabpos(3) ///
	yline(0, lp(shortdash) lc(gray)) xline(0, lp(shortdash) lc(gray)) ///
	ytitle("Annual growth of bottom 40 mean,%") xtitle("Annual growth Prosperity Gap,%") ///
	legend(ring(0) pos(7) row(2) order(2 "45{char 176} line") size(tiny)) name(gpg, replace)
graph combine gpg, scale(*1.3) xsize(10) ysize(10)
graph export "${ch2_figure}Fig2A1_Growth in b40 and growth in pg.png", replace
graph export "${ch2_figure}Fig2A1_Growth in b40 and growth in pg.eps", replace


// save data 
preserve 
keep countryname code survey_year meanb40 growthb40 pg gpg 
label var countryname "Country"
label var code 		  "Country ISO code"
label var survey_year "Survey year"
label var meanb40	  "Mean of the bottom 40 percent"
label var growthb40   "Growth of the mean of the bottom 40 percent"
label var pg 		  "Prosperity gap"
label var gpg 		  "Growth in the prosperity gap"
order countryname code survey_year meanb40 growthb40 pg gpg
format meanb40 growthb40 pg gpg %5.1f 
export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("FigAnnex2A1") sheetreplace firstrow(varlabel)
restore


*******************************************
*** Fig 2A.2: shared prosperity premium ***
*******************************************

gen spp 		= growthb40 - growthtotal

cap drop line45 negl45
gen 	line45 = -6 in 1/50
replace line45 = 6 if missing(line) 
gen 	negl45 = -1*line45

tw 	scatter spp ggini , ms(oh) mc("$color1") || line line45 negl45,  ///
	yline(0, lp(shortdash) lc(gray)) xline(0, lp(shortdash) lc(gray)) ///
	ylab(-6(2)6) xlab(-6(2)6) ///
	ytitle("Shared prosperity premium," "annual pct. points") xtitle("Annual change in Gini, %") ///
	legend(ring(0) pos(7) row(2) order(2 "45{char 176} line") size(tiny)) name(spp,replace)
graph combine spp, scale(*1.3) xsize(10) ysize(10)	
graph export "${ch2_figure}Fig2A2_SPP v gini change.png", replace
graph export "${ch2_figure}Fig2A2_SPP v gini change.eps", replace

// save data 
keep countryname code survey_year meanb40 growthb40 growthtotal spp gini ggini 
replace gini = gini*100
label var countryname "Country"
label var code 		  "Country ISO code"
label var survey_year "Survey year"
label var meanb40	  "Mean of the bottom 40 percent"
label var growthb40   "Growth of the mean of the bottom 40 percent"
label var growthtotal "Growth of the mean of the distribution"
label var spp 		  "Shared prosperity premium"
label var gini 		  "Gini index, 0-100"
label var ggini 	  "Growth in the Gini index"
order countryname code survey_year meanb40 growthb40 growthtotal spp gini ggini 
format meanb40 growthb40 growthtotal spp gini ggini %5.1f
export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("FigAnnex2A2") sheetreplace firstrow(varlabel)
