/*
Figure 2C.1: correlation between pg with and without bottom code.
*/

use "$ch2_input_processed/PG_bottomcoding_paper.dta", clear

bys code (year): keep if _n==_N
keep if year>=2000																	// keep if latest survey is after 2000

gsort -w
gen r = _n
gsort -w25
gen r25 = _n

tw 	scatter r25 r if !inlist(code,"NOR","EGY","ESP"), ms(th) mc("$color5")  || ///
	scatter r25 r if inlist(code,"NOR","EGY","ESP"), ms(th) mc("$color1") mlab(country_name) mlabc("$color1") mlabsize(small) || ///
	lfit r25 r25, lc(gray) lp(line) ///
	ytitle("Prosperity Gap rank, bottom coded at $0.25" "<------ Lower rank         Higher rank ----->") ///
	xtitle("Prosperity Gap rank, not bottom coded" "<------ Lower rank         Higher rank ----->") ///
	legend(ring(0) pos(5) order(3 "45{c 176} line") size(small)) xsize(10) ysize(10) 
	
graph export "${ch2_figure}Fig2C1_pg_bottomcode.png", replace
graph export "${ch2_figure}Fig2C1_pg_bottomcode.eps", replace	

// save data 
keep country_name code ref_year w w25 r r25
label var country_name  "Country"
label var code 			"Country ISO code"
label var ref_year		"Survey year"
label var w 			"Prosperity gap without bottom code"
label var w25 			"Prosperity gap with $0.25/day bottom code"
label var r 			"Prosperity gap ranking without bottom code"
label var r25 			"Prosperity gap ranking with $0.25/day bottom code"

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("FigAnnex2C1") sheetreplace firstrow(varlabel)