/*
Annex Figure 2D1: correlation between income and consumption gini
*/

use "${ch2_input_processed}pip_3pr2024_v20240802", clear
keep if poverty_line == 2.15
keep if inlist(reporting_level,"national") | inlist(country_code,"ARG")
bys country_code year: gen num = _N												// keep countries with both income and cosumption survey in a given year
keep if num==2
keep country* welfare_type welfare_time year gini 
replace gini = gini * 100
format gini %5.0f
reshape wide gini, i(country* year welfare_time) j(welfare_type)

gen 	line45 = 20 in 1/50
replace line45 = 60 if missing(line)

tw 	scatter gini2 gini1, ms(oh) || line line45 line45, lc(gray) lp(shortdash) || lfit gini2 gini1, ///
	xtitle("Consumption Gini index") ytitle("Income Gini index") xsize(10) ysize(10) ///
	text(44 36 "linear fit", size(small) color("$color3")) text(43 48 "45{char 176} line", size(small) color(grap)) ///
	legend(off) name(corr, replace)
graph combine corr, scale(*1.3) xsize(10) ysize(10)	
graph export "${ch2_figure}Fig2D1_income_consumption_gini_corr.png", replace	
graph export "${ch2_figure}Fig2D1_income_consumption_gini_corr.eps", replace	

// save data 
keep country_name welfare_time gini1 gini2 
label var country_name 	"Economy"	
label var welfare_time 	"Survey year"
label var gini1 		"Consumption gini" 	
label var gini2 		"Income gini" 

format welfare_time* gini* %5.0f
export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("FigAnnex2D1") sheetreplace firstrow(varlabel)