/*
Figure 2F.1: Share of high, moderate, low gini over time; number of countries and share of population.
*/

use "$ch2_input_processed/gini_intermediate_all.dta", clear

gen 	ginigroup = 2 if giniever>40
replace ginigroup = 1 if inrange(giniever,30,40)
replace ginigroup = 0 if missing(ginigroup)
gen 	ginicount = 1

collapse (sum) ginicount (sum) population, by(year ginigroup)


bysort year: egen pop_total = sum(population)
gen pop_share = population/pop_total * 100

bysort year: egen count_total = sum(ginicount)
gen num_share = ginicount/count_total * 100

drop population pop_total ginicount count_total

reshape wide *_share, i(year) j(ginigroup)

ren *_share0 share0* 
ren *_share1 share1* 
ren *_share2 share2*

reshape long share0 share1 share2, i(year) j(type) string

encode type, gen(t)
label define typelab 1 "(a) Share of countries" 2 " (b) Share of population"
label values t typelab 

keep if year>=2013

graph bar share0 share1 share2, by(t,legend(pos(6) row(1)) note("")) over(year, label(labsize(small))) ///
	bar(1, color($color3)) bar(2, color($color2)) bar(3, color($color1)) ///
	stack blabel(bar, position(inside) color(black) size(small) format(%5.0f)) ///
	legend(pos(6) row(1) order(1 "Low inequality" 2 "Moderate inequality" 3 "High inequality") ///
		symxsize(*0.5) region(lcolor(white))) ///
	graphregion(color(white)) ylab(0(20)100)  ///
	ytitle("Share, percent") plotregion(margin(0 0 0 0)) name(fig10alt, replace)

graph export "${ch2_figure}Fig2F1_Share of countries and population by inequality groups.png", replace
graph export "${ch2_figure}Fig2F1_Share of countries and population by inequality groups.eps", replace

// save data 
keep year t share* 
ren t type
order year type share*
label var share0 "Share with low inequality, percent"
label var share1 "Share with moderate inequality, percent"
label var share2 "Share with high inequality, percent"
label var type   "Country or population"

format share* %5.1f
export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("FigAnnex2F1") sheetreplace firstrow(varlabel)
	
