/*
Figure 8: Gini map data
*/

use "$ch2_input_processed/pip_3pr2024_v20240802", clear										// there are four countries with survey in 2023, which is not in Gini dataset so add those countries
keep if poverty_line==2.15
drop if reporting_level!="national" & inlist(country_code,"CHN","IND")
keep country_code country_name region_name welfare_time welfare_type gini 
decode welfare_type, gen(welft) 
drop welfare_type
ren welft welfare_type
replace gini = gini * 100

merge 1:1 country_code welfare_time welfare_type using "$ch2_input_processed/gini_intermediate_latest.dta"
bys country_code welfare_type (welfare_time): gen num = _n						// identify the four countries and keep the 2023 data	
gen num_ginidata = num if _merge==3
bysort country_code welfare_type: egen maxdummy=max(num_ginidata)
drop if maxdummy==.
drop if num < maxdummy 
bys country_code welfare_type (welfare_time): gen ct = _N
drop if ct==2 & _merge==3

gen 	indicator = "high"		if gini>40
replace indicator = "moderate"	if inrange(gini,30,40) 
replace indicator = "low"		if gini<30  

gen 	sortvar = 1 if indicator=="high"
replace sortvar = 2 if indicator=="moderate"
replace sortvar = 3 if indicator=="low"

sort sortvar country_name 

keep  country_name region_name welfare_time welfare_type gini indicator
order country_name region_name welfare_time welfare_type gini indicator

label var country_name 		"Economy"
label var region_name 		"Region"	
label var welfare_time 		"Survey year"
label var welfare_type		"Welfare type"	
label var gini 	 			"Gini index"
label var indicator 		"Inequality group"

format welfare_time gini %5.2f

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Map1") sheetreplace firstrow(varlabel)

