/*
Annex Table 2D: Statistics of Gini indexes in the Poverty and Inequality Platform (post-2000)
*/



* Aggregate
use "$ch2_input_processed/gini_intermediate_all.dta", clear
gen lic_lmic = inlist(incgroup_current,"LIC","LMIC")
gen 	survey = !missing(welfare_time)					// tag and keep surveys
keep if survey==1
bys country_code: gen unique = _n==_N 					// keep only 1 survey per country (most recent)
collapse (count) survey (sum) unique (mean) gini
gen welfare_type = "Total"
tempfile agg
save	`agg'

* By LICs/LMICs
use "$ch2_input_processed/gini_intermediate_latest.dta", clear
gen lic_lmic = inlist(incgroup_current,"LIC","LMIC")
preserve
bys lic_lmic: egen total = total(lic_lmic)
gen total_lic_lmic = total/_N
collapse total_lic_lmic, by(lic_lmic)
keep if lic_lmic==1
drop lic_lmic 
gen welfare_type = "Total"
ren total_lic_lmic lic_lmic
tempfile total_lic_lmic
save 	`total_lic_lmic'
restore 
collapse (mean) lic_lmic, by(welfare_type)
append using `total_lic_lmic'
format lic_lmic %5.2f
ren lic_lmic lic_lmic_share
tempfile lic_lmic
save 	`lic_lmic'


* By welfare type
use "$ch2_input_processed/gini_intermediate_all.dta", clear
gen lic_lmic = inlist(incgroup_current,"LIC","LMIC")
gen 	survey = !missing(welfare_time)					// tag and keep surveys
keep if survey==1
bys country_code: gen unique = _n==_N 					// keep only 1 survey per country (most recent)
collapse (count) survey (sum) unique (mean) gini, by(welfare_type)

append using `agg'
merge 1:1 welfare_type using `lic_lmic', nogen

gen 	sort = 1 if welfare_type=="income"
replace sort = 2 if welfare_type=="consumption"
replace sort = 3 if welfare_type=="Total"

sort sort 
drop sort

order welfare_type unique survey lic_lmic_share gini

label var welfare_type 	"Welfare type"
label var survey 		"Economy count"
label var unique 		"Survey count"
label var lic_lmic_share "Share of LICs and LMICs"
label var gini 			"Average Gini"
export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Tab2D.1") sheetreplace firstrow(varlabel)