/*
Annex Table 2E: Regional/Global prosperity gap estimates
*/

use "${ch2_input_processed}PG_1981_2024_3pr24.dta", clear

merge m:1 country_code using "${ch2_input_processed}piptables_country_list.dta", nogen

keep if inlist(year,1990,1995,2000,2005,2010,2015,2019,2020,2021,2022,2023,2024)

preserve							 									// global prosperity gap 
collapse pg [w=pop], by(year)
gen region_name = "World"
tempfile world 
save 	`world'
restore

preserve							 									// afw/afe prosperity gap 
keep if !missing(africa_split_code)
collapse pg [w=pop], by(year africa_split)
ren africa_split region_name
tempfile afr 
save 	`afr'
restore

collapse pg [w=pop], by(year region_name)					// regional prosperity gap

append using `world'
append using `afr'

reshape wide pg, i(region_name) j(year)

replace region_name = "Rest of the world" if region_name == "Other High Income Countries"

gen 	sortvar = 1 if region_name=="East Asia & Pacific"
replace sortvar = 2 if region_name=="Europe & Central Asia"
replace sortvar = 3 if region_name=="Latin America & Caribbean"
replace sortvar = 4 if region_name=="Middle East & North Africa"
replace sortvar = 5 if region_name=="South Asia"
replace sortvar = 6 if region_name=="Sub-Saharan Africa"
replace sortvar = 7 if region_name=="Eastern and Southern Africa"
replace sortvar = 8 if region_name=="Western and Central Africa"
replace sortvar = 9 if region_name=="Rest of the world"
replace sortvar = 10 if region_name=="World"

sort sortvar 
keep region pg*
order region pg*
format pg* %5.2f

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Tab2E.1") sheetreplace firstrow(varlabel)