/*******************************************************************************
	- Part 1: Import EDGAR emission data
	- Part 2: Import historical GHG emissions 
	
	Written by: Henry Stemmler
	Last modified 03 July 2024
*******************************************************************************/


********************************************************************************
*  Part 1: Import EDGAR emission data   
********************************************************************************

********************************************************************************
* 1) National  data
import excel "$ch3_data_raw/emissions/edgar/CSC-GHG_emissions-2024.03.29b.xlsx", clear firstrow sheet("C total subs & gas (V8+Grassi)")
* Cleaning
rename *, lower
drop edgarcountrycode incomegroup lendingcategory region
* convert years to variables
foreach v of varlist k-ag {
   local x : variable label `v'
   rename `v' emissions`x'
}
* clean subsector names
gen subsector_edit = cscsubsector
replace subsector_edit = subinstr(subsector_edit, "EN - ", "",.)
replace subsector_edit = subinstr(subsector_edit, "AG - ", "",.)				// Keep crop and livestock separate
*replace subsector_edit = "Agriculture" if inlist(subsector_edit, "AG - Livestock", "AG - Crops") 
replace subsector_edit = "LULUCF" if inlist(subsector_edit, "LULUCF - Deforestation", "LULUCF - Forest Land", "LULUCF - Organic Soil", "LULUCF - Other Land") 
replace subsector_edit = "Waste" if inlist(subsector_edit, "Waste - Solid Waste", "Waste - Wastewater Treatment") 
replace subsector_edit = "Industrial Processes" if inlist(subsector_edit, "IN - Industrial Processes") 
label	var subsector_edit "Subsector"
* Aggregate everything to code sector subsector gas units level
collapse (sum) emissions*, by(code country cscsector subsector_edit gas units)
reshape long emissions, i(code country cscsector subsector_edit gas units) j(year)
label  var emissions "Emissions (megatons CO2e)"
drop   unit
* Merge in country information
merge m:1 code using "$ch3_data_processed/countrycodes_current.dta", keep(3) nogen				// drop small states not in World Bank data
save "$ch3_data_processed/emissions_edgar_national.dta", replace

* 2) Global  data
import excel "$ch3_data_raw/emissions/edgar/CSC-GHG_emissions-2024.03.29b.xlsx", clear firstrow sheet("Global sector & gas (EDGAR)")
* Cleaning
rename *, lower
drop if edgarsector == ""
* convert years to variables
foreach v of varlist f-al {
   local x : variable label `v'
   rename `v' emissions`x'
}
reshape long emissions, i(cscsector cscsubsector gas units) j(year)
label  var emissions "Emissions (megatons CO2e)"
drop   unit
save "$ch3_data_processed/emissions_edgar_global.dta", replace

* 3) LULUCF 
import excel "$ch3_data_raw/emissions/edgar/CSC-GHG_emissions-2024.03.29b.xlsx", /// // Import raw EDGAR data (which has all LULUCF sectors)
	clear firstrow sheet("C total subs & gas (V8+Grassi)")
* Cleaning
rename 	*, lower
drop 	edgarcountrycode incomegroup lendingcategory region
* convert years to variables
foreach v of varlist k-ag {
   local x : variable label `v'
   rename `v' emissions`x'
}
* Keep only LULUCF related to forest
keep if cscsector == "Land Use, Land Use Change, and Forestry" 
replace cscsubsector = subinstr(cscsubsector, "LULUCF - ", "",.)
drop 	emissions2000 - emissions2021
save "$ch3_data_processed/emissions_edgar_lulucf.dta", replace

********************************************************************************
*   Part 2: Import Historical emission data (Climate Watch / PIK)
********************************************************************************
import delimited "$ch3_data_raw/emissions/historical_ghg-emissions_cw_pik.csv", clear varnames(1)
drop   country unit
rename iso code
* Clean
foreach v of varlist v* {
   local x : variable label `v'
   rename `v' emissions`x'
}
reshape  long emissions, i(code) j(year)
replace  emissions = "" if emissions == "FALSE"
destring emissions, replace
* Merge in country information
merge m:1 code using "$ch3_data_processed/countrycodes_current.dta", keep(3) nogen				 		// drop small states not in World Bank data
save "$ch3_data_processed/emissions_historical_pik.dta", replace
