/*******************************************************************************
	Written by: Henry Stemmler
	Last modified 23 July 2024
*******************************************************************************/

********************************************************************************
*   Import EMDAT data   
********************************************************************************
* Number of events
import excel "$ch3_data_raw/other/emdat.xlsx", clear firstrow
gen event = 1
collapse (sum) event, by(StartYear DisasterType)
rename (StartYear DisasterType) (year type)
drop if year == 2024
drop if type == "Earthquake"
gen period = 5 * floor(year/5)
collapse (mean) event, by(period type)
encode 	type, gen(type_l) label(type_l) 
drop 	type
* Keep labels of types
levelsof type_l, local(l) 
foreach i of local l {
	local d`i'  `: label type_l `i''
}
* Get in Excel format
reshape wide event, i(period) j(type_l)
foreach i of local l {
	label var event`i' "`d`i''"
}

foreach var of varlist event* {
	replace `var' = 0 if `var' == .
}
save "$ch3_data_processed/extreme_events.dta", replace

* Damages
import excel "$ch3_data_raw/other/emdat.xlsx", clear firstrow
rename (ISO StartYear DisasterType) (code year type)
keep if year > 1999
* Readjust damages to 2015 CPI
gen 	cpi15 		= CPI if year == 2015
egen 	cpi_15		= mean(cpi15)
gen 	cpi_15_adj 	= cpi_15 / CPI
gen 	damages_ppp = TotalDamage000US * cpi_15_adj * 1000
gen 	damages_nom = TotalDamage000US *  1000
keep	code year type damages_ppp damages_nom
collapse (sum) damages_ppp damages_nom, by(code year)
save "$ch3_data_processed/extreme_events_damages.dta", replace
