
********************************************************************************
* Figure 15. Primary energy and electricity production from fossils need to decline massively to reach net-zero by 2050, particularly in high-income and upper-middle-income countries
********************************************************************************
*************************
* a)  Primary energy
*************************
use "$ch3_data_processed/ngfs_primenergy_projections.dta", clear
collapse (sum) ind*, by(incgroup_current variable)
reshape long ind, i(incgroup_current variable) j(year)
reshape wide ind, i(incgroup_current year) j(variable) string
* Generate stacks for figure
gen energy1 = indFossil
gen energy2 = indFossil + indNuclear
gen energy3 = indFossil + indNuclear + indRenewable
* Generate figure
levelsof incgroup_current, local(inc)
local n = 1
foreach i of local inc {
twoway area energy1 year if incgroup_current == "`i'"							///
			, fcolor("$color1") lcolor("$color1") ||							///
	   rarea energy1 energy2 year if incgroup_current == "`i'"					///
			, fcolor("$color3") lcolor("$color3") ||							///
	   rarea energy2 energy3 year if incgroup_current == "`i'"					///
			, fcolor("$color6") lcolor("$color6") ||							///
	   , 	legend(order(1 "Fossil" 2 "Nuclear" 								///
					3 "Renewables") 											///
			row(1) pos(6)) xlabel(2020(10)2050)									///
			ytitle("Exajoules") xtitle("") 										///
			name(g`n', replace) 												///
			title("`i'", size(14pt))
local n = `n' + 1
}
grc1leg2 g1 g4 g3 g2, lrows(1) rows(2) labsize(11pt) ///
						ytsize(11pt) xsize(5) ytol1title
graph export "$ch3_output/ch3_fig15a.png", replace
graph export "$ch3_output/ch3_fig15a.eps", replace		

export excel "$ch3_output/chapter3.xlsx", sheet("fig15a", modify) firstrow(varlabels)
	
*************************
* b)  Electricity generation 
*************************
use "$ch3_data_processed/ngfs_electricity_projections.dta", clear
collapse (sum) ind*, by(incgroup_current variable)
reshape long ind, i(incgroup_current variable) j(year)
encode variable, gen(group) label(group_l) 
drop 	 variable
levelsof group, local(l) 
foreach i of local l {
	local d`i'  `: label group_l `i''
}
reshape wide ind, i(incgroup_current year) j(group)
foreach i of local l {
	label var ind`i' "`d`i''"
}

* Generate stacks for figure
gen electricity1 = ind2
gen electricity2 = ind2 + ind1
gen electricity3 = ind2 + ind1 + ind3
* Generate figure
levelsof incgroup_current, local(inc)
local n = 1
foreach i of local inc {
twoway area electricity1 year if incgroup_current == "`i'"							///
			, fcolor("$color1") lcolor("$color1") ||							///
	   rarea electricity1 electricity2 year if incgroup_current == "`i'"					///
			, fcolor("$color3") lcolor("$color3") ||							///
	   rarea electricity2 electricity3 year if incgroup_current == "`i'"					///
			, fcolor("$color6") lcolor("$color6") ||							///
	   , 	legend(order(1 "Fossil" 2 "Nuclear" 								///
					3 "Renewables") 											///
			row(1) pos(6)) xlabel(2020(10)2050)									///
			ytitle("Exajoules") xtitle("") 										///
			name(g`n', replace) 												///
			title("`i'", size(14pt))
local n = `n' + 1
}
grc1leg2 g1 g4 g3 g2, lrows(1) rows(2) labsize(11pt) ///
						ytsize(11pt) xsize(5) ytol1title
graph export "$ch3_output/ch3_fig15b.png", replace
graph export "$ch3_output/ch3_fig15b.eps", replace			

export excel "$ch3_output/chapter3.xlsx", sheet("fig15b", modify) firstrow(varlabels)
