
********************************************************************************
* Figure 3. South Asia and lower-middle income countries are most exposed to extreme weather hazards
********************************************************************************
use "$ch3_data_processed/exposure_vulnerability_2021.dta", clear
* Aggregate to region  level
preserve
collapse (sum) exp_any exp_cyclone exp_drought exp_flood exp_heat totalpop, by(region)
insobs 1			// Add world aggregate
replace region = "World" if region == ""

foreach var of varlist exp* totalpop {
	egen 	tot_`var' = sum(`var')
	replace `var' = tot_`var' if region == "World"
	drop tot_`var'
}
foreach var in any flood drought heat cyclone {
	gen 	share_exp_`var' = exp_`var' / totalpop
}
drop exp* totalpop
rename region unit
tempfile reg 
save `reg'
restore

* Aggregate to income  level
collapse (sum) exp_any exp_cyclone exp_drought exp_flood exp_heat totalpop, by(incgroup_current)
foreach var in any flood drought heat cyclone {
	gen 	share_exp_`var' = exp_`var' / totalpop
}
drop exp* totalpop
rename incgroup_current unit
* Combine and export
append using `reg'
* Make graph in Stata
encode unit, gen(unit_num)
levelsof unit_num, local(u)
foreach i of local u {
	graph bar share_exp_* if unit_num == `i',  ///
	bar(1, fcolor($color1)) bar(2, fcolor($color2)) bar(3, fcolor($color3)) bar(4, fcolor($color4)) bar(5, fcolor($color5)) ///
	title("`: label unit_num `i''", size(14pt)) ytitle("Share of population exposed") name(g`i', replace) ///
	legend(label(1 "Any") label(2 "Flood") label(3 "Drought") label(4 "Heat") label(5 "Cyclone")) 		  ///
	blabel(bar, format(%9.2f) gap(0.2)) ylabel(0 "0" .2 "20%" .4 "40%" .6 "60%" .8 "80%")
}
grc1leg2 g12 g1 g2 g4 g7 g8 g9 g10 g5 g6 g11 g3, ycommon lrows(1) rows(4) labsize(8pt) ytol1title ytsize(8pt) ysize(5)
graph export "$ch3_output/ch3_fig3.png", replace
graph export "$ch3_output/ch3_fig3.eps", replace
drop unit_num
export excel "$ch3_output/chapter3.xlsx", sheet("fig3", modify) firstrow(varlabels)
