
********************************************************************************
* Figure 6. GHG emissions have grown over the past two decades, but economic activity is becoming less emission intensive
********************************************************************************

*************************
* a) GHG emissions by region
*************************
use	"$ch3_data_processed/emissions_edgar_national.dta", clear
* Collapse to region level
collapse (sum) emissions, by(region year)
replace emissions = emissions / 1000				// megatons to gigatons
label var emissions "Total emissions (gt CO2eq)"

encode 	region, gen(region_l) label(reg_l) 
drop 	region
* Keep labels of regions
levelsof region_l, local(l) 
foreach i of local l {
	local d`i'  `: label reg_l `i''
}
* Get in Excel format
reshape wide emissions, i(year) j(region_l)
foreach i of local l {
	label var emissions`i' "`d`i''"
}
* Export
export excel "$ch3_output/chapter3.xlsx", sheet("fig6a", modify) firstrow(varlabels)

*************************
* b) GHG emissions by income group
*************************
use	"$ch3_data_processed/emissions_edgar_national.dta", clear
* Collapse to region level
collapse (sum) emissions, by(incgroup_current year)
replace emissions = emissions / 1000				// megatons to gigatons
label var emissions "Total emissions (gt CO2eq)"

encode 	incgroup_current, gen(incg) label(incg_l) 
drop 	incgroup_current
* Keep labels of regions
levelsof incg, local(l) 
foreach i of local l {
	local d`i'  `: label incg_l `i''
}
* Get in Excel format
reshape wide emissions, i(year) j(incg)
foreach i of local l {
	label var emissions`i' "`d`i''"
}
order year emissions1 emissions4 emissions3 emissions2
* Export
export excel "$ch3_output/chapter3.xlsx", sheet("fig6b", modify) firstrow(varlabels)

*************************
* c) GHG emissions per capita
*************************
use	"$ch3_data_processed/emissions_edgar_national.dta", clear
* Country level
collapse (sum) emissions, by(code region year)
* Merge in population
rename code country_code
merge m:1 country_code year using "$ch3_data_processed/pop", keep(3) nogen
* Collapse to region level
collapse (sum) emissions pop, by(region year)
gen		emissions_pc = emissions / pop * 1000000	// megatons to tons
label var emissions_pc "GG emissions p.c. (t CO2eq)"
encode 	region, gen(region_l) label(reg_l) 
keep	region_l emissions_pc year
* Keep labels of regions
levelsof region_l, local(l) 
foreach i of local l {
	local d`i'  `: label reg_l `i''
}
* Get in Excel format
reshape wide emissions_pc, i(year) j(region)
foreach i of local l {
	label var emissions_pc`i' "`d`i''"
}
* Export
export excel "$ch3_output/chapter3.xlsx", sheet("fig6c", modify) firstrow(varlabels)

** Add World 
use	"$ch3_data_processed/emissions_edgar_national.dta", clear
* Country level
collapse (sum) emissions, by(code year)
* Merge in population
rename code country_code
merge m:1 country_code year using "$ch3_data_processed/pop", keep(3) nogen
* Collapse to world level
collapse (sum) emissions pop, by(year)
gen		  emissions_pc = emissions / pop * 1000000	// megatons to tons
label var emissions_pc "World"
keep	  emissions_pc
* Export
export excel "$ch3_output/chapter3.xlsx", sheet("fig6c", modify) firstrow(varlabels) cell(I1)

*************************
* d) GHG emissions per unit of GDP
*************************

* Get emissions
use	"$ch3_data_processed/emissions_edgar_national.dta", clear
* Country level
collapse (sum) emissions, by(code region year)
merge 1:1 code year using "$ch3_data_processed/gdp.dta", keep(3)
replace emissions = . if gdp == .												// Only use emissions from countries with GDP data
collapse (sum) emissions gdp, by(region year)
gen 	  emissions_gdp = emissions / (gdp / 1000000) * 1000 
label var emissions_gdp "GG emissions intensity (kt per GDP in million US$)"
encode 	region, gen(region_l) label(reg_l) 
keep	region_l emissions_gdp year
* Keep labels of regions
levelsof region_l, local(l) 
foreach i of local l {
	local d`i'  `: label reg_l `i''
}
* Get in Excel format
reshape wide emissions_gdp, i(year) j(region)
foreach i of local l {
	label var emissions_gdp`i' "`d`i''"
}
* Export
export excel "$ch3_output/chapter3.xlsx", sheet("fig6d", modify) firstrow(varlabels)

** Add World 
use	"$ch3_data_processed/emissions_edgar_national.dta", clear
* Country level
collapse (sum) emissions, by(code year)
merge 1:1 code year using "$ch3_data_processed/gdp.dta", keep(3)
replace emissions = . if gdp == .												// Only use emissions from countries with GDP data
* Collapse to world level
collapse (sum) emissions gdp, by(year)
gen 	  emissions_gdp = emissions / (gdp / 1000000) * 1000 
label var emissions_gdp "World"
keep	  emissions_gdp
* Export
export excel "$ch3_output/chapter3.xlsx", sheet("fig6d", modify) firstrow(varlabels) cell(I1)
