
********************************************************************************
* Figure 9. Energy production mix by income group in 1990 and 2022
********************************************************************************	
use "$ch3_data_processed/energy.dta", clear											// Import energy data
* Merge with country classifications
merge m:1 code using "$ch3_data_processed/countrycodes_current.dta", keep(3) nogen
collapse (sum) energy, by(incgroup_current sector year)
keep if year == 1990 | year == 2022
drop if sector == "Total"
bys 	incgroup_current year: egen total_energy = sum(energy)
gen 	share_energy = energy / total_energy
drop 	energy total_energy
*Keep labels of sectors
encode 	sector, gen(sector_l) label(sector_l) 
drop 	sector
levelsof sector_l, local(l) 
foreach i of local l {
	local d`i'  `: label sector_l `i''
}
reshape wide share_energy, i(incgroup_current year) j(sector_l)
foreach i of local l {
	label var share_energy`i' "`d`i''"
}
gen 	incg = 1 if incgroup_current == "Low-income" 							// Numeric for order
replace incg = 2 if incgroup_current == "Lower-middle-income" 
replace incg = 3 if incgroup_current == "Upper-middle-income" 
replace incg = 4 if incgroup_current == "High-income"
label 	define incg 4 "Low-income" 3 "Lower-middle-income" 2 "Upper-middle-income" 1 "High-income" 
label 	values incg incg
sort	year incg
order 	year incg
drop	incgroup_current
export excel "$ch3_output/chapter3.xlsx", sheet("fig9", modify) firstrow(varlabels)

