
/*******************************************************************************
	Download datasets for PPPR 24 Chapter 4

	Written by: Henry Stemmler
	Last date modified: 12 July 2024     
*******************************************************************************/


use "$ch4_data_raw/classifications/CLASS.dta", clear
label 	var economy "Country Name"
* Correct country name
replace economy = "Czechia" if economy == "Czech Republic"
* Generate FCS variable fixed at 2022
gen 	fcv2022 = 1 if fcv_historical == "Yes" & year_data == 2022
bys 	code: egen fcv_2022 = max(fcv2022)
replace	fcv_2022 = 0 if fcv_2022 == .
label 	def yesno 1 "Yes" 0 "No"
label	values fcv_2022 yesno
label 	variable fcv_2022 "FCV status - 2022"
drop	fcv2022
* PIP Region names
gen 	region_pip_name="East Asia and Pacific"				if region_pip=="EAP"
replace region_pip_name="Europe and Central Asia" 			if region_pip=="ECA"
replace region_pip_name="Latin America and the Caribbean"	if region_pip=="LAC"
replace region_pip_name="Middle East and North Africa" 		if region_pip=="MNA"
replace region_pip_name="Rest of the world" 				if region_pip=="OHI"
replace region_pip_name="South Asia" 						if region_pip=="SAS"
replace region_pip_name="Sub-Saharan Africa"				if region_pip=="SSA"
* Add hyphens to income group names
replace incgroup_current = "Low-income" 					if incgroup_current == "Low income" 											// Numeric for order
replace incgroup_current = "Lower-middle-income" 			if incgroup_current == "Lower middle income" 
replace incgroup_current = "Upper-middle-income" 			if incgroup_current == "Upper middle income" 
replace incgroup_current = "High-income" 		 			if incgroup_current == "High income"
replace incgroup_historical = "Low-income" 					if incgroup_historical == "Low income" 											// Numeric for order
replace incgroup_historical = "Lower-middle-income" 		if incgroup_historical == "Lower middle income" 
replace incgroup_historical = "Upper-middle-income"		 	if incgroup_historical == "Upper middle income" 
replace incgroup_historical = "High-income" 				if incgroup_historical == "High income"
gen 	ida_group_current = "IDA" if ida_current == "IDA" | ida_current == "Blend"
replace ida_group_current = "Other" if ida_group_current == ""
label var ida_group_current "IDA countries"																							// Put together Blend and IDA
* Add data for 2023 and 2024 
preserve 
keep if year_data == 2022
drop year_fiscal year_release
expand 2
bys code: replace year = 2023 if _n == 1
bys code: replace year = 2024 if _n == 2
tempfile f
save `f'
restore 
append using `f'
* Save
order 	code economy year_fiscal year_release year_data region_pip region_pip_name region ida_group_current ///
		region_SSA incgroup_historical incgroup_current ida_historical ida_current fcv_historical fcv_current fcv_2022
save "$ch4_data_processed/countrycodes_yearly.dta", replace
* Keep a version only for current year
keep 	if year_data == 2022

* Add small states
preserve  
	import excel "$ch4_data_raw/FY25 small states.xlsx", sheet("composition") firstrow clear
	keep if WB_Group_Code=="SST"
	keep WB_Group_Code WB_Country_Code
	rename WB_Group_Code small_state
	replace small_state = "Yes"
	rename WB_Country_Code code

	tempfile sst 
	save `sst'
restore 
merge 1:1 code using `sst', nogen
replace small_state = "No" if small_state==""
keep 	code economy region region_pip region_pip_name region_SSA incgroup_current fcv_current fcv_2022 ida_group_current small_state
save "$ch4_data_processed/countrycodes_current.dta", replace


********************************************************************************
*   Part 2: Population and country lists        
*********************************
/* Code to retrieve data from PIP, uncomment to get raw data
* National population
pip tables, clear table(pop) ${pipoptions}
keep if data_level == "national"
rename value pop
keep country_code year pop
save "$ch4_data_processed/pop", replace
* With rural and urban
pip tables, clear table(pop) ${pipoptions}
rename data_level reporting_level
rename value pop
keep country_code year pop reporting_level
save "$ch4_data_processed/pop_reportinglevel", replace
* Country lists
pip tables, table(country_list) clear ${pipoptions}
save "$ch4_data_processed/countrylist", replace
*/
