/*******************************************************************************

	Chapter 4 - SSP Data 
	*******************

	
	Written by: Henry Stemmler
	Last date modified: 15 May 2024     
	
*******************************************************************************/

*** Import SSP 
import excel "$ch4_data_raw/ssp_global_gdp_pop.xlsx", clear firstrow
* Clean
rename *, lower																		// Lowercase
qui ds
loc last: word `c(k)' of `r(varlist)'										
foreach v of varlist f - `last' {													// Rename year variables
   local x : variable label `v'
   rename `v' ind`x'
}
* Rename and clean-up variables
replace variable = "gdp" if variable != "Population"
replace variable = "pop" if variable == "Population"
drop unit region
* Reshaping
reshape long ind, i(model scenario variable) j(year)								// First to long format to extract year
* Reshape to wide format (population and GDP)
reshape wide ind, i(model scenario year) j(variable, string)						// Now separate GDP and Population
bys year scenario: egen pop = mean(indpop)											// Get population data to all GDP projections
rename  indgdp gdp
drop 	indpop
drop	if model == "IIASA-WiC POP 2023"											// Don't need separate population anymore
* GDP per capita
gen gdp_pc = gdp / pop * 1000
* Clean up
drop  gdp pop 			
gen 	scenario_model = "Cuaresma: " + scenario if model == "IIASA GDP 2023"			// Variable that shows model and SSP
replace scenario_model = "Dellink: "  + scenario if model == "OECD ENV-Growth 2023"
order  model scenario scenario_model gdp

* Labeling
label var model 	  "Model"
label var scenario 	  "Policy scenario"

egen group = group(model scenario)
keep group year gdp_pc
reshape wide gdp_pc, i(year) j(group)

save "$ch4_data_processed/ssp_data.dta", replace
