/*
Figure 4: Comparing income and consumption ginis
*/

***********************************
*** consumption v income gini ***
***********************************

use "$ch4_data_processed/poverty_country_survey.dta", clear
keep if poverty_line == 2.15
keep if reporting_level=="national" | country_code=="ARG"

bys country_code year (welfare_type): gen num = _N								// keep those with both income and consumption in a year
keep if num==2

keep if inrange(year,2015,2021)
gen time = abs(2021 - year)
bys country_code welfare_type (time): gen year2 = _n
keep if year2==1

keep country_name welfare_time welfare_type gini 

replace gini = gini * 100
format %5.0f gini

sum gini if country=="Albania" & welfare_type==1
local alb1 = `r(mean)'
sum gini if country=="Albania" & welfare_type==2
local alb2 = `r(mean)'
sum gini if country=="Philippines" & welfare_type==1
local phl1 = `r(mean)'
sum gini if country=="Philippines" & welfare_type==2
local phl2 = `r(mean)'
sum gini if country=="Poland" & welfare_type==1
local pol1 = `r(mean)'
sum gini if country=="Poland" & welfare_type==2
local pol2 = `r(mean)'
sum gini if country=="Romania" & welfare_type==1
local rom1 = `r(mean)'
sum gini if country=="Romania" & welfare_type==2
local rom2 = `r(mean)'
sum gini if country=="Russian Federation" & welfare_type==1
local rus1 = `r(mean)'
sum gini if country=="Russian Federation" & welfare_type==2
local rus2 = `r(mean)'
sum gini if country=="Serbia" & welfare_type==1
local srb1 = `r(mean)'
sum gini if country=="Serbia" & welfare_type==2
local srb2 = `r(mean)'
sum gini if country=="St. Lucia" & welfare_type==1
local lcu1 = `r(mean)'
sum gini if country=="St. Lucia" & welfare_type==2
local lcu2 = `r(mean)'
sum gini if country=="Turkiye" & welfare_type==1
local tur1 = `r(mean)'
sum gini if country=="Turkiye" & welfare_type==2
local tur2 = `r(mean)'


twoway (line gini welfare_type if country == "Albania", color("$color1")) ///
       (line gini welfare_type if country == "Philippines", color("$color2")) ///
	   (line gini welfare_type if country == "Poland", color("$color3")) ///
	   (line gini welfare_type if country == "Romania", color("$color4")) ///
	   (line gini welfare_type if country == "Russian Federation", color("$color5")) ///
	   (line gini welfare_type if country == "Serbia", color("$color6")) ///
	   (line gini welfare_type if country == "St. Lucia", yaxis(1) lc(none)) ///
	   (line gini welfare_type if country == "St. Lucia", yaxis(2) color("$color7")) ///
	   (line gini welfare_type if country == "Turkiye", color("$color8")), ///
	   text(`alb1' 1 "Albania", placement(west) color("$color1") size(vsmall) xoffset(-2)) ///
	   text(`alb2' 2 "Albania", placement(east) color("$color1") size(vsmall) xoffset(+2)) ///
	   text(`phl1' 1 "Philippines", placement(west) color("$color2") size(vsmall) xoffset(-2)) ///
	   text(`phl2' 2 "Philippines", placement(east) color("$color2") size(vsmall) xoffset(+2)) ///
	   text(`pol1' 1 "Poland", placement(west) color("$color3") size(vsmall) xoffset(-2)) ///
	   text(`pol2' 2 "Poland", placement(east) color("$color3") size(vsmall) xoffset(+2)) ///
	   text(`rom1' 1 "Romania", placement(west) color("$color4") size(vsmall) xoffset(-2)) ///
	   text(`rom2' 2 "Romania", placement(east) color("$color4") size(vsmall) xoffset(+2)) ///
	   text(`rus1' 1 "Russian Federation", placement(west) color("$color5") size(vsmall) xoffset(-2)) ///
	   text(`rus2' 2 "Russian Federation", placement(east) color("$color5") size(vsmall) xoffset(+2)) ///
	   text(`srb1' 1 "Serbia", placement(west) color("$color6") size(vsmall) xoffset(-2)) ///
	   text(`srb2' 2 "Serbia", placement(east) color("$color6") size(vsmall) xoffset(+2)) ///
	   text(`lcu1' 1 "St. Lucia", placement(west) color("$color7") size(vsmall) xoffset(-2)) ///
	   text(`lcu2' 2 "St. Lucia", placement(east) color("$color7") size(vsmall) xoffset(+2)) ///
	   text(`tur1' 1 "Turkiye", placement(west) color("$color8") size(vsmall) xoffset(-2)) ///
	   text(`tur2' 2 "Turkiye", placement(east) color("$color8") size(vsmall) xoffset(+2)) ///
       ytitle("Gini index of consumption", axis(1) xoffset(-5) yoffset(+10)) ///
	   ytitle("Gini index of income", axis(2) xoffset(+5) yoffset(+10)) ///
	   ylab(28 " " 33 "33" 40 "40" 45 "45" 50 "50", axis(1) nogrid) ///
	   ylab(28 "28" 33 "33" 38 "38" 45 "45" 50 "50", axis(2) nogrid) xtitle("") ///
	   legend(off) xscale(lstyle(none)) xlabel(, nogrid nolabels  tlength(0)) ///
	   graphregion(margin( l=10 r=10)) name(fig3a, replace) xsize(10) ysize(10)
	
graph combine fig3a, xsize(10) ysize(10)	
graph export "$ch4_output/ch4_fig4a_income_consumption_gini_levels.png", replace	
graph export "$ch4_output/ch4_fig4a_income_consumption_gini_levels.eps", replace		
	
// save data 
label var country_name 	"Economy"
label var welfare_time 	"Survey year"
label var welfare_type 	"Income or consumption welfare measure"
label var gini 			"Gini index, 0-100"

format gini %5.2f
export excel using "$ch4_output/chapter4.xlsx", cell(A1) sheet("fig4a") sheetreplace firstrow(varlabel)	

************************************************
*** (b): change in consumption v income gini ***
************************************************	   
	   
use "$ch4_data_processed/poverty_country_survey.dta", clear
keep if poverty_line == 2.15
keep if reporting_level=="national" | country_code=="ARG"

bys country_code year (welfare_type): gen num = _N								// keep those with both income and consumption in a year
keep if num==2

gen start = inrange(year,2004,2012)
gen end   = inrange(year,2014,2022)
keep if start==1 | end==1

gen timestart = abs(2008 - year)												// keep the closest year to reference
gen timeend   = abs(2018 - year)
bys country_code welfare_type (timestart): gen yearstart = _n						
bys country_code welfare_type (timeend)	 : gen yearend   = _n	
keep if (yearstart==1 & start==1) | (yearend==1 & end==1)

bys country_code welfare_type (year): gen 		comparable_check =  survey_comparability - survey_comparability[_n-1]
bys country_code welfare_type (year): replace 	comparable_check = comparable_check[_n+1] if missing(comparable_check)
drop if comparable_check!=0

bys country_code: gen countrycount = _N
drop if countrycount!=4																// keep those with survey in each period

bys country_code welfare_type (year): gen change = ((gini/gini[_n-1])^(1/(welfare_time-welfare_time[_n-1])) - 1) * 100
keep if !missing(change)

keep country_name welfare_type welfare_time change
reshape wide change, i(country welfare_time) j(welfare_type) 

graph hbar change1 change2, over(country) ///
	legend(ring(1) pos(6) row(2) order(1 "Change in consumption-based Gini" ///
		2 "Change in income-based Gini") xoffset(-5)) ///
	name(fig3b, replace) xsize(10) ysize(10)  ///
	ytitle("Annual change (percent)", yoffset(-2))

graph combine fig3b, xsize(10) ysize(10)	
graph export "$ch4_output/ch4_fig4b_income_consumption_gini_change.png", replace	
graph export "$ch4_output/ch4_fig4b_income_consumption_gini_change.eps", replace		


// save data 
label var country_name 	"Economy"
label var welfare_time 	"Survey year"
label var change1 		"Change in consumption-based Gini, %"
label var change2 		"Change in income-based Gini, %"

format change* %5.2f
export excel using "$ch4_output/chapter4.xlsx", cell(A1) sheet("fig4b") sheetreplace firstrow(varlabel)



