/*
Figure 6: Comparing Ginis and Top 10% share between PIP and WID
*/

use "$ch4_data_processed/gini_intermediate_all.dta", clear								// from chapter 2 input
keep country_name welfare_type country_code year gini
ren gini ginipip
merge 1:1 country_code year using "$ch4_data_processed/wid_data_all.dta", keep(3) nogen

drop if missing(ginipip) | missing(giniwid)
drop if welfare_type=="consumption"

bys country_code: gen diffpip = (ginipip - ginipip[_n-1])^(1/(year - year[_n-1])) - 1	// First difference	
bys country_code: gen diffwid = (giniwid - giniwid[_n-1])^(1/(year - year[_n-1])) - 1

encode country_name, gen(cntr)

preserve
keep country_name cntr 
duplicates drop
tempfile countrylist 
save 	`countrylist'
restore

sum cntr 
mat A = J(r(max),4,.)

sum cntr
forval i = 1/`r(max)' {
	ttest diffpip==diffwid if cntr==`i'
	mat A[`i',1] = `i'
	mat A[`i',2] = `r(mu_1)'
	mat A[`i',3] = `r(mu_2)'
	mat A[`i',4] = `r(se)'
}

clear 
svmat A
ren A1 cntr
ren A2 meanpip
ren A3 meanwid 
ren A4 se

merge 1:1 cntr using `countrylist', nogen 
drop cntr 
encode country_name, gen(cntr)

gen meandiff = meanpip - meanwid
gen lb = meandiff + invnormal(0.025) * se
gen ub = meandiff + invnormal(0.975) * se

tw 	 scatter cntr meandiff || rcap lb ub cntr , horizontal yscale(reverse) ///
	xline(0, lp(dash) lc(gray)) ///
	ylab(1(1)33, valuelabel nogrid labsize(small)) xlabel(, nogrid) ///
	ytitle("") xtitle("PIP - WID difference" "of the average year-over-year changes") ///
	legend(off)  xsize(10) ysize(10) 
graph export "$ch4_output/ch4_fig6_pip_wid_gini_difference.png", replace	
graph export "$ch4_output/ch4_fig6_pip_wid_gini_difference.eps", replace	
	
// save data 
export excel using "$ch4_output/chapter4.xlsx", cell(A1) sheet("fig6") sheetreplace firstrow(varlabel)	
