
/*******************************************************************************
	Prepare poverty data from PIP for PPPR 24 Overview

	Written by: Henry Stemmler
	Last date modified: 23 July 2024     
*******************************************************************************/
* Install PIP

// capture ssc uninstall pip  // uninstalls PIP
// capture ssc install   pip 
// github install worldbank/pip, version(0.10.8.9001) // installs a specified version

********************************************************************************
*	Global and regional poverty 
********************************************************************************
*pip wb, povline(2.15 3.65 6.85 25) clear nowcasts ${pipoptions} 
use "$overview_data_raw/pip/pip_data_aggregate_202408.dta", clear 
drop poverty_gap poverty_severity watts											// Drop variables not needed
save "$overview_data_processed/poverty_aggregates.dta", replace

********************************************************************************
*	Country lineup 
********************************************************************************
*pip, povline(2.15 3.65 6.85 25) clear nowcasts ${pipoptions}
use "$overview_data_raw/pip/pip_data_lineup_202408.dta", clear
drop poverty_gap poverty_severity watts											// Drop variables not needed
save "$overview_data_processed/poverty_country_lineup.dta", replace

********************************************************************************
*	Country survey 
********************************************************************************
*pip, povline(2.15 3.65 6.85 25) clear ${pipoptions}
use "$overview_data_raw/pip/pip_data_survey_202408.dta", clear
keep if poverty_line==2.15
drop if reporting_level!="national" & inlist(country_code,"CHN","IND")
drop poverty_gap poverty_severity watts											// Drop variables not needed
save "$overview_data_processed/poverty_country_survey.dta", replace

********************************************************************************
*	Income distribution 
********************************************************************************
/* Code to retrieve data from PIP, uncomment to get raw data
pip, clear povline(0.001 0.01 0.5 1 1.5 2 2.5 3 3.5 4 4.5 5 5.5 6 6.5 7 7.5 8 8.5 9 ///
					9.5 10 10.5 11 11.5 12 12.5 13 13.5 14 14.5 15 15.5 16 ///
					16.5 17 17.5 18 18.5 19 19.5 20 20.5 21 21.5 22 22.5 23 ///
					23.5 24 24.5 25) nowcasts year(1990 2024)  ${pipoptions}
keep country_code reporting_level headcount year population poverty_line
save "$overview_data_processed/country_income_distribution.dta", replace
*/

********************************************************************************
*	Prosperity Gap
********************************************************************************
/* 
pip, $pipoptions nowcasts clear
* Merge in missing countries and population
merge 1:1 country_code reporting_level year using "$overview_data_processed/pop_reportinglevel", nogen
* Merge country classifications
rename 	country_code code
keep code year welfare_type population pg i pop reporting_level
merge 	m:1 code using "$overview_data_processed/countrycodes_current.dta", 			///	
				 keepusing(region_pip region_pip_name economy) nogen
rename region_pip_name region_name
keep if reporting_level=="national" | inlist(code,"ARG") 										// Drop urban and rural for all but Argentina
drop if inlist(code,"ARG") & reporting_level=="national" 										// Drop national for Argentina	* Calculate regional 
drop if year < 1990
* Calculate regional poverty to fill in missing numbers
bysort region_pip year: egen avg_pg = wtmean(pg),weight(population)
* Fill in missing values
replace population = pop if population == . 													// Get population
replace pg  	   = avg_pg if pg == . 	
rename (code) (country_code)
* Get mean welfare
merge 	1:1 country_code year reporting_level using "$overview_data_raw/other/mean_bottomcode.dta", nogen
gen i 			   = mean * pg/25																// mean ratio deviation (inequality)
save "$overview_data_processed/PG_1981_2024_3pr24.dta", replace
*/