
********************************************************************************
*	Figure 13. Poverty is increasingly concentrated in SSA and FCS
********************************************************************************

use "$overview_data_processed/projections_country_2030.dta", clear
keep	if povertyline == 2.15
drop	povertyline
* Generate FCS SSA groups
gen ssafcv = "Rest of the world"  	if region_pip != "SSA" & fcvFY24 == "No"
replace ssafcv = "FCS outside SSA"  if region_pip != "SSA" & fcvFY24 == "Yes"
replace ssafcv = "Non-FCS in SSA"  	if region_pip == "SSA" & fcvFY24 == "No"
replace ssafcv = "FCS in SSA"  		if region_pip == "SSA" & fcvFY24 == "Yes"
encode 	ssafcv, gen(sfcg) label(sfcg_l) 
* Keep labels 
levelsof sfcg, local(l) 
foreach i of local l {
	local d`i'  `: label sfcg_l `i''
}
* Get in Excel format
collapse (sum) pop_in_poverty population, by(year sfcg)
bys year: egen global_poor = sum(pop_in_poverty)
gen share_poor = pop_in_poverty / global_poor * 100
keep sfcg year share_poor
reshape wide share_poor, i(year) j(sfcg)
tempfile proj
save `proj'


use "$overview_data_processed/poverty_country_lineup.dta", clear
keep if poverty_line == 2.15
keep if year>1999
* Merge in missing countries and population
merge 1:1 country_code reporting_level year using "$overview_data_processed/pop_reportinglevel"
drop 	_merge
rename 	country_code code
rename	year year_data
* Merge country classifications
merge 	m:1 code year_data using "$overview_data_processed/countrycodes_yearly.dta", ///
						   keepusing(region_pip_name incgroup_current fcv_historical) 
rename	year_data year
keep if year > 1999
* Clean up 
keep if reporting_level=="national" | inlist(code,"ARG") 										// Drop urban and rural for all but Argentina
drop if inlist(code,"ARG") & reporting_level=="national" 										// Drop nationall for Argentina	* Calculate regional poverty to fill in missing numbers
* Calculate regional poverty to fill in missing numbers
bysort region_pip_name year: egen avg_pov = wtmean(headcount),weight(population)
* Fill in missing values
replace population = pop if population == . 													// Get population
replace headcount  = avg_pov if headcount == . 	
gen 	pop_in_poverty = headcount * population
* Generate FCS SSA groups
gen		ssafcv = "Rest of the world" 										///
		if region_pip_name != "Sub-Saharan Africa" & fcv_historical == "No"
replace ssafcv = "FCS outside SSA"   										///
		if region_pip_name != "Sub-Saharan Africa" & fcv_historical == "Yes"
replace ssafcv = "Non-FCS in SSA"  	 										///
		if region_pip_name == "Sub-Saharan Africa" & fcv_historical == "No"
replace ssafcv = "FCS in SSA"		 										///
		if region_pip_name == "Sub-Saharan Africa" & fcv_historical == "Yes"
encode 	ssafcv, gen(sfcg) label(sfcg_l) 
* Keep labels 
levelsof sfcg, local(l) 
foreach i of local l {
	local d`i'  `: label sfcg_l `i''
}
* Clean up
collapse (sum) pop_in_poverty population, by(year sfcg)
bys year: egen global_poor = sum(pop_in_poverty)
gen share_poor = pop_in_poverty / global_poor
keep sfcg year share_poor
replace share_poor = share_poor * 100
reshape wide share_poor, i(year) j(sfcg)
* Add forecasts
append using `proj'
* Label variables
foreach i of local l {
	label var share_poor`i' "`d`i''"
}

********** Create graph in Stata 
gen stack_pop_share_welf3 = share_poor3								if year<2023
gen stack_pop_share_welf1 = stack_pop_share_welf3 + share_poor1		if year<2023
gen stack_pop_share_welf2 = stack_pop_share_welf1 + share_poor2		if year<2023
gen stack_pop_share_welf4 = stack_pop_share_welf2 + share_poor4		if year<2023
gen stack_pop_share_welf3_f = share_poor3							if year>2021
gen stack_pop_share_welf1_f = stack_pop_share_welf3_f + share_poor1	if year>2021
gen stack_pop_share_welf2_f = stack_pop_share_welf1_f + share_poor2	if year>2021
gen stack_pop_share_welf4_f = stack_pop_share_welf2_f + share_poor4	if year>2021

twoway area stack_pop_share_welf3 year 											///
			, fcolor("$color2") lcolor("$color2") ||							///
	   rarea stack_pop_share_welf3 stack_pop_share_welf1 year 					///
			, fcolor("$color7") lcolor("$color7") ||							///
	   rarea stack_pop_share_welf1 stack_pop_share_welf2 year 					///
			, fcolor("$color6") lcolor("$color6") ||							///
	   rarea stack_pop_share_welf2 stack_pop_share_welf4 year 					///
			, fcolor("$color3") lcolor("$color3") ||							///
 		area stack_pop_share_welf3_f year 										///
			, fcolor("$color2 %80") lcolor("$color2 %0") ||						///
	   rarea stack_pop_share_welf3_f stack_pop_share_welf1_f year 				///
			, fcolor("$color7 %80") lcolor("$color7 %0") ||						///
	   rarea stack_pop_share_welf1_f stack_pop_share_welf2_f year 				///
			, fcolor("$color6 %80") lcolor("$color6 %0") ||						///
	   rarea stack_pop_share_welf2_f stack_pop_share_welf4_f year 				///
			, fcolor("$color3 %80") lcolor("$color3 %0") ||						///	
	   (scatteri 0 2022 100 2022, 												///
				recast(line) lcolor("$color8")),								///
			legend(order(1 "Non-FCS in SSA" 2 "FCS in SSA" 						///
					3 "FCS outside SSA" 4 "Rest of the world") 					///
			  row(2) pos(6) size(12pt)) 										///
			  ytitle("Share of global poor at $`line' (%)",						///
			  size(12pt)) xlabel(2000(2)2030, angle(90) labsize(12pt))			///
			  ylabel(,  labsize(12pt)) text(95 2026 "Projections", size(12pt))	
graph export "$overview_output/overview_fig13.png", replace
graph export "$overview_output/overview_fig13.eps", replace	
export excel "$overview_output/overview.xlsx", sheet("fig13", modify) firstrow(varlabels) cell(A1)

