
********************************************************************************
* figure 15. There is a positive relationship between income levels and GHG emissions
********************************************************************************
*************************
* a) Ten countries produce two-thirds of global GHG emissions 
*************************
use "$overview_data_processed/emissions_edgar_national.dta", clear 
keep 	if year == 2022
collapse (sum) emissions, by(code year)
* Merge with population data 
rename code country_code
merge m:1 country_code year using "$overview_data_processed/pop", keep(3) nogen
gen		emissions_pc = emissions / pop * 1000000	// megatons to tons
* Create top 10 emitter variable
sort 	emissions
egen 	tot = sum(emissions)
gen 	share = emissions / tot
gen 	cum_share = sum(share)
replace cum_share = 1-cum_share
drop 	tot share
gen  	top10 = "66% of global emissions" if _N-_n < 10
replace top10 = "34% of global emissions" 	 if _N-_n > 9
order 	top10 country 
bys		top10: replace top10 = "" if _n!=1
keep country emissions pop emissions_pc cum_share top10
* Generate population shares
egen tot_pop = sum(pop)
gen  pop_share = pop / tot_pop
drop tot_pop
export excel "$overview_output/overview.xlsx", sheet("fig15a", modify) firstrow(varlabels)

*************************
* b) Emissions per capita are converging between UMICs and HICs
*************************
use	"$overview_data_processed/emissions_edgar_national.dta", clear
* Country level
collapse (sum) emissions, by(code incgroup_current year)
* Merge in population
rename code country_code
merge m:1 country_code year using "$overview_data_processed/pop", keep(3) nogen
* Collapse to income group level
collapse (sum) emissions pop, by(incgroup_current year)
gen		emissions_pc = emissions / pop * 1000000	// megatons to tons
label var emissions_pc "GG emissions p.c. (t CO2eq)"
encode 	incgroup_current, gen(incg) label(incg_l) 
keep	incg emissions_pc year
* Keep labels of regions
levelsof incg, local(l) 
foreach i of local l {
	local d`i'  `: label incg_l `i''
}
* Get in Excel format
reshape wide emissions_pc, i(year) j(incg)
foreach i of local l {
	label var emissions_pc`i' "`d`i''"
}
order year emissions_pc1 emissions_pc4 emissions_pc3 emissions_pc2
export excel "$overview_output/overview.xlsx", sheet("fig15b", modify) firstrow(varlabels)

*************************
* c) Historical emissions
*************************
use	"$overview_data_processed/emissions_historical_pik.dta", clear
collapse (sum) emissions, by(incgroup_current year)
bys 	incgroup_current (year): gen cumulative_emissions = sum(emissions) / 1000	// megatons to gigatons
encode  incgroup_current, gen(incg)
drop 	incgroup_current emissions
reshape wide cumulative_emissions, i(year) j(incg)
label var cumulative_emissions1 "High-income" 
label var cumulative_emissions2 "Low-income"
label var cumulative_emissions3 "Lower-middle-income"
label var cumulative_emissions4 "Upper-middle-income"
drop if year < 1850
export excel "$overview_output/overview.xlsx", sheet("fig15c", modify) firstrow(varlabels)
