/*
Figure 6: Share of countries by income and FCV group (latest survey)
*/

use "$overview_data_processed/gini_intermediate_latest.dta", clear
ren country_code code

gen 	ginigroup = 2 if giniever>40
replace ginigroup = 1 if inrange(giniever,30,40)
replace ginigroup = 0 if missing(ginigroup)
gen count = 1

merge 1:1 code using "$overview_data_processed/countrycodes_current.dta", keep(3)

preserve 
collapse (count) count, by(incgroup_current ginigroup)
ren incgroup_current name
gen group = "Income group FY24"
tempfile income 
save 	`income'
restore 

collapse (count) count , by(fcv_current ginigroup)
ren fcv_current name 
gen group = "FCV group FY24"
append using `income'

bys group name: egen total = total(count)
gen double share = count/total * 100 

reshape wide share count total, i(name group) j(ginigroup) 

gen 	sort = 1 if name=="Yes"
replace sort = 2 if name=="No"
replace sort = 3 if name=="Low-income"
replace sort = 4 if name=="Lower-middle-income"
replace sort = 5 if name=="Upper-middle-income"
replace sort = 6 if name=="High-income"


order group name share*
sort sort
keep name group share*
label var name 	 ""
label var share0 "Low inequality"
label var share1 "Moderate inequality"
label var share2 "High inequality"

replace name = "FCS" if name == "Yes"
replace name = "Non-FCS" if name == "No"
format share* %5.2f

export excel "$overview_output/overview.xlsx", sheet("fig6", modify) firstrow(varlabels)
