
/*******************************************************************************

	Poverty, Prosperity and Planet Report 2024
	*****************************************

	Master do-file

	- Part 1: Folder paths
	- Part 2: Package installation
	- Part 3: Color scheme
	- Part 4: Replication code
	
	Written by: Henry Stemmler
	Last date modified: 05 September 2024     
	Stata Version: Stata 18.0
	
*******************************************************************************/
clear 	 all
set more off
set varabbrev on
version  18.0
set		 maxvar 32000
********************************************************************************
* Part 1: Folder paths 
********************************************************************************

* Change this directory to the Replication folder on your device 
global user	"C:/Users/wb558768/Downloads/FR_WLD_2024_198/Replication"

sysdir set PLUS "${user}/ado"

********************************************************************************
* Part 2: Package installation 
********************************************************************************
/* 
***NOTE*** 
All the necessary packages are already installed in the "ado" folder, so there is no need to reinstall them. The following lines 
are included for documentation purposes only.
*/

/* 
Install relevant packages
local   packages pip apoverty egenmore wbopendata schemepack grstyle ///
	    palettes sankey unique carryforward sencode stripplot kountry ///
		colrspace _gwtmean
foreach package in `packages' {
	    capture which `package'
		if _rc == 111 {
		ssc install `package', replace
	}
}

* Other packages
net 	install grc1leg2, from(http://digital.cgdev.org/doc/stata/MO/Misc)	// For combined graph with one legend

* For PIP:
capture ssc uninstall pip  							// uninstalls PIP

net install github, from("https://haghish.github.io/github/") //Installs github
github 	install worldbank/pip, version(0.10.9.9001) // installs correct version for the report
*/

global 	pipoptions = "version(20240627_2017_01_02_PROD)"		

********************************************************************************
* Part 3: Define colors
********************************************************************************

// Set colors as default for figures
grstyle init
grstyle set color #ED342E #FF8133 #FFD589 #99F5FF #51E5FF ///
				  #3ABECB #0E64A9 #474748 #616163 #A3A3A3						// Sets the correct colors for figures
grstyle set size 10pt: heading subheading body small_body ///					// Font size for figures
					   text_option axist_title
grstyle set legend, nobox														// No box on legend
grstyle set plain, horizontal compact nogrid									// Remove background color and grid

// Save each color as a macro to select specific ones
global color1 237 52 46															
global color2 255 129 51
global color3 255 213 137
global color4 153 245 255
global color5 81 229 255
global color6 58 190 203
global color7 14 100 169
global color8 71 71 72
global color9 97 97 99
global color10 163 163 163

********************************************************************************
* Part 4: Replication code
********************************************************************************

* Toggle between internal and external package
global internal            0													// Change to 1 for internal version, 0 for external version


* Main Messages
do "$user/Summary/0-code/summary_0_master.do"
* Overview
do "$user/Overview/0-code/overview_0_master.do"
* Chapter 1
do "$user/Chapter 1/0-code/ch1_0_master.do"
* Chapter 2
do "$user/Chapter 2/0-code/ch2_0_master.do"
* Chapter 3
do "$user/Chapter 3/0-code/ch3_0_master.do"
* Chapter 4
do "$user/Chapter 4/0-code/ch4_0_master.do"


