
/*******************************************************************************

	Poverty, Prosperity and Planet Report 2024
	Main messages
	*****************************************

	Master do-file

	- Part 1: Folder paths
	- Part 2: Replication code
	
	Written by: Henry Stemmler
	Last date modified: 12 July 2024     
	Stata Version: Stata 18.0
	
*******************************************************************************/

********************************************************************************
* Part 1: Folder paths 
********************************************************************************
*global user	///  // Adjust this path if the main master file is not used
//"C:/Users/`c(username)'/OneDrive - WBG/General - 2024 Poverty and Shared Prosperity Report - WB Group/PPPR_reproducibility/"

global summary_data 			"$user/Summary/1-data"								
global summary_data_raw 		"$summary_data/raw"
global summary_data_processed 	"$summary_data/processed"
global summary_output 			"$user/Summary/2-output"
global summary_code 			"$user/Summary/0-code/"


********************************************************************************
* Part 2: Replication code
********************************************************************************
* List for full code
local flist : dir "$summary_code" files "*.do", respectcase
local master "summary_0_master.do"
local flist : list flist - master												// No need to run master file again

* List for processed code
local p_flist: dir "$summary_code" files "summary_2*.do", respectcase
	
// Run all code if global is set to 1
if ${internal} == 1 {
    foreach fname of local flist {
        do "$summary_code/`fname'"
    }
}

// Run processed code if global is set to 1
if ${internal} == 0 {
    foreach p_fname of local p_flist {
        do "$summary_code/`p_fname'"
    }
}

	