
/*******************************************************************************
	Get poverty data for PPPR 24 summary

	Written by: Henry Stemmler
	Last date modified: 23 July 2024     
*******************************************************************************/

********************************************************************************
*	Global and regional poverty 
********************************************************************************
*pip wb, povline(2.15 3.65 6.85 25) clear nowcasts ${pipoptions} 
use "$summary_data_raw/poverty/pip_data_aggregate_202408.dta", clear 
drop poverty_gap poverty_severity watts											// Drop variables not needed
save "$summary_data_processed/poverty_aggregates.dta", replace

********************************************************************************
*	Country lineup 
********************************************************************************
*pip, povline(2.15 3.65 6.85 25) clear nowcasts ${pipoptions}
use "$summary_data_raw/poverty/pip_data_lineup_202408.dta", clear
drop poverty_gap poverty_severity watts											// Drop variables not needed
save "$summary_data_processed/poverty_country_lineup.dta", replace

********************************************************************************
*	Global projections
********************************************************************************
use "$summary_data_raw/poverty/FGTglobal_1990_2050_3pr24.dta", clear
keep year povertyline fgt0 scenario poorpop
rename (fgt0 poorpop) (headcount pop_in_poverty)
save "$summary_data_processed/projections_global_2050.dta", replace

********************************************************************************
*	Prosperity Gap
********************************************************************************
/* 
pip, $pipoptions nowcasts clear
* Merge in missing countries and population
merge 1:1 country_code reporting_level year using "$summary_data_processed/pop_reportinglevel", nogen
* Merge country classifications
rename 	country_code code
keep code year welfare_type population pg i pop reporting_level region_name
merge 	m:1 code using "$summary_data_processed/countrycodes_current.dta", 			///	
				 keepusing(region_pip economy) nogen
keep if reporting_level=="national" | inlist(code,"ARG") 										// Drop urban and rural for all but Argentina
drop if inlist(code,"ARG") & reporting_level=="national" 										// Drop national for Argentina	* Calculate regional 
drop if year < 1990
* Calculate regional poverty to fill in missing numbers
bysort region_pip year: egen avg_pg = wtmean(pg),weight(population)
* Fill in missing values
replace population = pop if population == . 													// Get population
replace pg  	   = avg_pg if pg == . 	
rename (code) (country_code)
* Get mean welfare
merge 	1:1 country_code year reporting_level using "$summary_data_raw/other/mean_bottomcode.dta", nogen
gen i 			   = mean * pg/25																// mean ratio deviation (inequality)
save "$summary_data_processed/PG_1981_2024_3pr24.dta", replace
*/