
/*******************************************************************************
	Import exposure and vulnerability data
	
	Written by: Henry Stemmler
	Last modified 28 March 2024
*******************************************************************************/
use "$summary_data_raw/vulnerability/Exp_vul_rai_2021_raw.dta", clear
* Remove conflicted areas 
drop if geo_code2_new=="RUS_2015_GADM1_UKR_UKR.20_1"
drop if geo_code2_new=="RUS_2015_GADM1_UKR_UKR.4_1"
drop if geo_code2_new=="MAR_2015_DKx_268_1"
drop if geo_code2_new=="MAR_2015_DKx_268_2"
* Keep only 100-year return-period
keep if scenario == "RP100*"
* Exposed and vulnerable (both HH vulnerable and spatial vulnerable)
foreach var of varlist multvul_215 all2vul_215 multvul_685 all2vul_685 {
	gen double `var'_exp = exprai_ + (exp_ - exprai_)*`var'	
}
* Exposed and vulnerable (both HH vulnerable and spatial vulnerable)
foreach var of varlist poor215_ln poor685_ln dep_educ_com dep_infra_elec dep_infra_impw dep_sp dep_fin {
	gen double `var'_exp =  (exp_) * `var'	
}
* Aggregate to country-hazard level
collapse (sum) multvul_215_exp totalpop exp_ poor215_ln_exp poor685_ln_exp dep_educ_com_exp dep_infra_elec_exp dep_infra_impw_exp dep_sp_exp dep_fin_exp exprai_, by(hazard code)
* Clean up
rename multvul_215_exp risk_
rename poor215_ln_exp poor215_
rename poor685_ln_exp poor685_
reshape wide exp_ risk_ poor215_ poor685_ exprai_ dep_*, i(code) j(hazard) string
* Merge in other country information
merge 1:1 code using "$summary_data_processed/countrycodes_current.dta"
assert 	_merge != 1
keep if _merge == 3 
drop 	_merge
save "$summary_data_processed/exposure_vulnerability_2021.dta", replace
