/*******************************************************************************
	- Import EDGAR emission data
	
	Written by: Henry Stemmler
	Last modified 03 July 2024
*******************************************************************************/

********************************************************************************
* 1) National  data
import excel "$summary_data_raw/emissions/edgar/CSC-GHG_emissions-2024.03.29b.xlsx", clear firstrow sheet("C total subs & gas (V8+Grassi)")
* Cleaning
rename *, lower
drop edgarcountrycode incomegroup lendingcategory region
* convert years to variables
foreach v of varlist k-ag {
   local x : variable label `v'
   rename `v' emissions`x'
}
* clean subsector names
gen subsector_edit = cscsubsector
replace subsector_edit = subinstr(subsector_edit, "EN - ", "",.)
replace subsector_edit = subinstr(subsector_edit, "AG - ", "",.)				// Keep crop and livestock separate
*replace subsector_edit = "Agriculture" if inlist(subsector_edit, "AG - Livestock", "AG - Crops") 
replace subsector_edit = "LULUCF" if inlist(subsector_edit, "LULUCF - Deforestation", "LULUCF - Forest Land", "LULUCF - Organic Soil", "LULUCF - Other Land") 
replace subsector_edit = "Waste" if inlist(subsector_edit, "Waste - Solid Waste", "Waste - Wastewater Treatment") 
replace subsector_edit = "Industrial Processes" if inlist(subsector_edit, "IN - Industrial Processes") 
label	var subsector_edit "Subsector"
* Aggregate everything to code sector subsector gas units level
collapse (sum) emissions*, by(code country cscsector subsector_edit gas units)
reshape long emissions, i(code country cscsector subsector_edit gas units) j(year)
label  var emissions "Emissions (megatons CO2e)"
drop   unit
* Merge in country information
merge m:1 code using "$summary_data_processed/countrycodes_current.dta", keep(3) nogen				// drop small states not in World Bank data
save "$summary_data_processed/emissions_edgar_national.dta", replace
