
********************************************************************************
*	Figure 1ab. Poverty between 1990 and 2030, $2.15, $3.65, and $6.85 
********************************************************************************
use "$summary_data_processed/poverty_aggregates.dta", clear
drop	if poverty_line == 25
drop	if year < 1990
keep	if region_name == "World"
keep	year poverty_line headcount pop_in_poverty
replace poverty_line = poverty_line * 100
replace pop_in_poverty = pop_in_poverty / 1000000
reshape wide headcount pop_in_poverty, i(year) j(poverty_line)
label var headcount215 "Poverty rate at $2.15"
label var headcount365 "Poverty rate at $3.65"
label var headcount685 "Poverty rate at $6.85"
label var pop_in_poverty215 "Millions of poor at $2.15"
label var pop_in_poverty365 "Millions of poor at $3.65"
label var pop_in_poverty685 "Millions of poor at $6.85"
* Add forecasts to 2030
preserve
	use "$summary_data_processed/projections_global_2050.dta", clear
	keep if year > 2024 & year < 2031
	keep if scenario == "current_forecast"
	gen poverty_line = povertyline * 100
	keep	year poverty_line headcount pop_in_poverty
	replace headcount = headcount / 100
	reshape wide headcount pop_in_poverty, i(year) j(poverty_line)
	tempfile proj
	save `proj' 
restore
append using `proj'
* Generate separate forecast variable for Excel 
foreach var of varlist headcount* pop* {
	gen `var'_forecast = `var' if year > 2021
	replace `var'	   = .	   if year > 2022
}
gen line3pct 	 = 0.03
//gen millions_2030 = pop_in_poverty215_forecast * 0.03 if year == 2030
gen millions3pct2030 = 256

export excel "$summary_output/summary.xlsx", sheet("fig1ab", modify) firstrow(varlabels) cell(A1)
