/*
Figures 2a: decomposition of the the growth in prosperity gap into
			mean and inequality growths
*/

use "$summary_data_processed/PG_1981_2024_3pr24.dta", clear

gen  			w_i 	= pop/mean												// generate the weights for within/between decomposition
bys year: egen 	sum_w_i = total(w_i)
gen  			weight  = w_i/sum_w_i

gen				I_g = weight * i
bys year: egen 	w_I = total(I_g)

collapse pg mean w_I [w=pop], by(year)

gen i = pg*mean/25
gen b_I = i/w_I

keep if inlist(year,1990,2000,2010,2019,2024)
keep year pg i mean b_I w_I
sort year

foreach v of varlist pg i mean b_I w_I {										// growth rates
	gen g`v' = ln(`v'/`v'[_n-1])/(year - year[_n-1]) * 100
}															

replace gmean = -1 * gmean														// so that mean+inequality change = pg change

keep year g*
drop if year==1990

tostring year, replace
replace year="1990-2000" if year=="2000"
replace year="2000-2010" if year=="2010"
replace year="2010-2019" if year=="2019"
replace year="2019-2024" if year=="2024" 

label var gpg 	"Growth of Global Prosperity Gap"
label var gi  	"Change in total inequality"
label var gmean "Growth of the mean"
label var gb_I  "Change in between-country inequality"
label var gw_I  "Change in within-country inequality"

format g* %5.2f

* Messaging
export excel "$summary_output/summary.xlsx", sheet("fig2a", modify) firstrow(varlabels)

