/*
Figure 2b: Share of countries by region (latest survey)
*/

use "$summary_data_processed/gini_intermediate_latest.dta", clear
ren country_code code

gen 	ginigroup = 2 if giniever>40
replace ginigroup = 1 if inrange(giniever,30,40)
replace ginigroup = 0 if missing(ginigroup)
gen count = 1

preserve 
collapse (count) count, by(ginigroup)
gen region_code = "WLD"
tempfile wld
save 	`wld'
restore 

collapse (count) count, by(region_code ginigroup)
append using `wld'
bys region : egen total = total(count)
gen double share = count/total * 100 

reshape wide share count total, i(region) j(ginigroup) 
keep region share*

label var share0 "Low inequality"
label var share1 "Moderate inequality"
label var share2 "High inequality"
gen 	sort = 0

replace region_code = "ROW" if region_code == "OHI"
replace region_code = "SAR" if region_code == "SAS"
replace sort = 1 if region_code == "ROW"
replace sort = 2 if region_code == "WLD"
sort sort region_code
drop sort 

format share* %5.2f

export excel using "$summary_output/summary.xlsx", sheet("fig2b", modify) sheetreplace firstrow(varlabel)
