********************************************************************************
/*
Bottom 40 mean and SPP for the GDSP 13th ed. set of countries 
	using Fall 2024 (3PR) vintage.
*/
********************************************************************************
global path "C:\Users\wb562356\WBG\2024 Poverty and Shared Prosperity Report - WB Group - General\Chapter 2\"

global input "${path}01-input\"
global output "${path}02-output\"
********************************************************************************

import excel using "${input}GDSP-and-Median-Income-2016-2021-SM24.xlsx", clear cellrange(A2) first
drop in 1/4
drop in 89
gen 	welfare_type = 1 if inlist(type,"C","c")
replace welfare_type = 2 if inlist(type,"I","i")
keep countryname code welfare_type SurveyT1 SurveyT2 growthb40 growthtotal meanb40* meantotal* 
reshape long SurveyT meanb40 meantotal, i(countryname code welfare_type growthb40 growthtotal) j(time) string
drop time 
destring SurveyT, replace 
ren SurveyT 	ref_year
ren meanb40 	meanb40_old
ren meantotal 	meantotal_old
ren growthb40 	growthb40_old
ren growthtotal growthtotal_old
tempfile gdsplist 
save 	`gdsplist'

use "C:\Users\wb562356\OneDrive - WBG\Documents\Research\BottomCensoring\02-rawdata\GMD_all_2017.dta", clear 
gen 	welfare_type = 1 if inlist(datatype,"C","c")
replace welfare_type = 2 if inlist(datatype,"I","i")

merge m:1 code ref_year welfare_type using  `gdsplist', keep(3) nogen				// keep only the necessary surveys

drop if welfare_dec < 0 														// creating an equivalent welfare variable as in PIP
gen 	welf_adj = welfare_dec
replace welf_adj = 0.25 if welfare_dec<0.25                                        

egen pct = xtile(welf_adj), nq(5) weight(weight) by(countryname code ref_year)
gen  b40 = inrange(pct,1,2)

preserve 
	collapse welf_adj [w=weight], by(countryname code ref_year *_old)
	ren welf_adj meantotal
	tempfile totalmean 
	save 	`totalmean'
restore 

keep if b40 == 1
collapse welf_adj [w=weight], by(countryname code ref_year welfare_type *_old)
ren welf_adj meanb40

merge 1:1 code ref_year using `totalmean', nogen 
ren ref_year survey_year

bys code (survey_year): gen growthb40   = ((meanb40/meanb40[_n-1])^(1/(survey_year-survey_year[_n-1])) - 1) * 100
bys code (survey_year): gen growthtotal = ((meantotal/meantotal[_n-1])^(1/(survey_year-survey_year[_n-1])) - 1) * 100


/*
***Check difference from old vintage***
destring *_old, replace 
gen diffb40 = round(abs(growthb40 - growthb40_old), 0.001)
gen difftotal = round(abs(growthtotal - growthtotal_old), 0.001)
sum diff*
*/


keep countryname code growthb40 growthtotal survey_year meanb40 meantotal welfare_type

save "${input}b40_growth_3PR.dta", replace