*! version 0.1.10  9/27/2024
*! Copyright (C) World Bank 2023 - D4G (Data for Goals)/GMI
*! Minh Cong Nguyen - mnguyen3@worldbank.org
*! Haoyu Wu         - hwu4@worldbank.org

* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.

* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.

* You should have received a copy of the GNU General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.

********************** NOTE TO USERS ********************
* This is the dofile to replicate the Multidimensional Poverty Measure (MPM) produced by the D4G team.
* User will need to provide the World Bank's 3-letter country code, have access to 
* Bank intranet and be registered to the Datalibweb system to query household survey data
* For more details on MPM method: please see Chapter 4 of PSPR2018 (Piecing together the Poverty Puzzle)

* There are some external programs that users need to install before
* datalibweb

********************** GMI NOTE *************************
* This is a part of GMI (Global Monitoring Indicators) database.
* GMI is the survey-based indicators calulated from the Global Monitoring Database.
* The purpose of GMI is (1) to faciliate users on ready-made and correct indicators 
* without accessing household surveys data and analyzing/coding on those data; 
* (2) to provide users technical knowledge on how to use GMD to calcuate those basic 
* indicators. Each theme or topic will be provided with such simple code to run such as this one below.
*********************************************************


********************** CHANGE BY USER ********************
global ctry "BWA"		//eg. FSM AUT BGR; enter one country per time
global year 2015		//please enter one year per time
global sub	    	    //please enter subnational variable (leave it blank if you dont want to do subnational MPM)
global icpyr 2017

********************************************************************************
*!!!!!!!!!!!!!!!!!!!!! USER DONT NEED TO EDIT THE CODE BELOW !!!!!!!!!!!!!!!!!!!
********************************************************************************
qui{	
	********************** GENERAL SETTING ******************
	clear all
	set more off
	set matsize 5000	
	mat drop _all
	tempfile mpm
	save `mpm', empty replace

	********************** SETTING BY ROUND ******************
	global rnd AM24         
	global pfw_ser Support_2005_CPI_v11_M
	global reop_rd AM24
	global repo_ser Support_2005_CPI_v11_M

	gen keep = . 
	
	if $icpyr == 2011{
		glo pov1 1.90
	}
	else if $icpyr == 2017{
		glo pov1 2.15
	}
	else{
		di in r "you need to specify a correct icp (2011 or 2017) to get poverty line."
		error 2000
	}

	********************** PRELOAD THE DATA ******************
	clear
	tempfile alldata
	save `alldata', replace emptyok
	//datatype
	cap dlw, country(Support) year(2005) type(GMDRAW) filename(Survey_price_framework.dta) surveyid(${pfw_ser}) clear
	if (_rc){
		noi di in r "datalibweb issue, please contact D4G team"
		error 1	
	}

	*replace year = rep_year if year!=rep_year   //SILC ans MYS
	keep code year survname datatype rep_year
	ren code countrycode

	replace datatype = "CONS" if datatype == "C" |  datatype == "c"
	replace datatype = "INC" if datatype == "I" | datatype == "i"
	tostring year rep_year, replace
	tempfile pfw
	save `pfw', replace

	********************** MAIN ******************
	cap dlw, country(Support) year(2005) type(GMDRAW) filename(repo_${reop_rd}all.dta) surveyid(${repo_ser}) clear nometa
	if (_rc){
		noi di in r "datalibweb issue, please contact D4G team"
		error 1	
	}
	ren (country years) (countrycode year)
	tostring year, replace
	merge m:1 countrycode year survname using `pfw', keep(3) nogen
	gen keep = . 
	replace keep = 1 if countrycode == upper("$ctry") & rep_year == "$year"
	count if countrycode == upper("$ctry") & rep_year == "$year"
	if r(N) == 0 {
		loc nond4g = 1
		noi di in r "The MPM for $ctry-$year is NEVER caulcuated by D4G team."
		noi di in r "Please contact D4G team for more details"
	}
	else loc nond4g = 0

	keep if keep == 1
	
	keep countrycode year survname filename
	tempfile repo
	save `repo', replace

	noi di in y "This dofile will calculate the MPM for the country-year listed below:"
	if `nond4g' == 1 {
		di "$ctry $year"
	}
	else{
		noi list countrycode year
	}
		
	// main //

	if `nond4g' == 1 {
		loc c = "$ctry"
		loc y = "$year"
	}
	else{
		use `repo', clear
		local surv = survname[1]
		local filename_all = filename[1]
		local filename_wash = filename[1]
		local c = countrycode[1]
		local y = year[1]
	}
	noi dis in y "`c'-`y'-`surv'"
	
	***************************************************
	//load age structure from UNESCO database
	***************************************************
	cap dlw, country(Support) year(2005) type(GMDRAW) filename(UNESCO.dta) surveyid(${repo_ser})  clear nometa
	keep if code=="`c'" & year==`y'
	if "`=off_pri_age[1]'"~="." {
		global lbage `=off_pri_age[1]'
		global ubage `=`=off_pri_age[1]'+8'
	}
	else if "`c'" == "NRU"{
		global lbage 6
		global ubage 14
	}
	else {
		dis in r "no off_pri_age in UNESCO"
		continue
	}

	***************************************************
	//Loading WASH approved variabels only
	***************************************************
	noi di in g "WASH"
	*di in y "cap dlw, coun(`c') y(`y') type(gmd) filename(`filename_wash')  clear nocpi"
	if `nond4g' == 1 { 
		cap dlw, coun(`c') y(`y') type(gmd) mod(all)  clear nocpi
	}
	else{
		cap dlw, coun(`c') y(`y') type(gmd) filename(`filename_wash')  clear nocpi
	}
	
	if _rc == 0 {//wash_repo
		local filename_wash = r(filename)
		
		//sim
		cap des sim
		if (_rc) gen sim = 1
		
		//sub
		if "$sub" == ""{
			gen sub = "all"
			glo sub sub
		}
	
		//adjust countrycode year
		cap drop countrycode
		cap gen countrycode = "`=upper("`c'")'"
		cap drop year
		cap gen year = `y'

		//adjust hhid
		cap tostring hhid, replace force format(%19.0f)
		cap tostring pid, replace force format(%19.0f)
		
		//wash variabe
		loc varlist
		foreach var in imp_san_rec imp_wat_rec{
			cap des `var' 
			if (_rc==0) local varlist "`varlist' `var'"
		}
		keep hhid pid `varlist' sim $sub
		cap tostring hhid pid, replace force format(%19.0f)
		tempfile wash
		cap save `wash', replace
		if _rc==0 `noi' di in w "WASH done"
		
		***************************************************
		//Loading ALL module
		***************************************************	
		//ALL
		noi di in g "ALL"
		if `nond4g' == 1 { 
			cap dlw, coun(`c') y(`y') type(gmd) mod(all)  clear nocpi
		}
		else{
		*di "cap dlw, coun(`c') y(`y') type(gmd) filename(`filename_all')  clear nocpi"
			cap dlw, coun(`c') y(`y') type(gmd) filename(`filename_all') clear nocpi
		}
		if _rc == 0 { //all_repo
			local filename_all = r(filename)
			
			//sim
			cap des sim
			if (_rc) gen sim = 1	
			
			//adjust countrycode year
			cap drop countrycode
			cap gen countrycode = "`=upper("`c'")'"
			cap drop year
			cap gen year = `y'
			
			cap tostring hhid, replace force format(%19.0f)
			cap tostring pid, replace force format(%19.0f)

			cap drop imp_wat_rec 
			cap drop imp_san_rec
			cap merge 1:1 hhid pid sim using `wash', keep(3) nogen
			if _rc== 0 {
				****************************************************
				**Dimension 1: education (needs to define age groups)
				****************************************************
				**1a) Indicator: have no one with primary completion (completed 15+)
				//All adults
				local eduflag = 0
				
				if "`c'" == "NRU" & `y' == 2012{ //2/13/2020
					sort agecat
					cap drop age
					gen age = .
					replace age = 1 if agecat == "0-4 years"
					replace age = 2 if agecat == "5-9 years"
					replace age = 3 if agecat == "10-14 years"
					replace age = 4 if agecat == "15-19 years"
					replace age = 5 if agecat == "20-24 years"
					replace age = 6 if agecat == "25-29 years"
					replace age = 7 if agecat == "30-34 years"
					replace age = 8 if age == .
					global eduage 3.5	
				}
				else if "`c'" == "UKR" & `y' == 2014{
					cap su agecat
					if (r(N)> 0 & _rc==0) {
						drop age
						rename agecat age
						global eduage 5
					}
					else {
						noi di in r "No agecat available"
					}
				}
				else if ("`c'" == "UKR" & `y' == 2019) |("`c'" == "UKR" & `y' == 2020) {
					cap drop age
					gen age = substr(agecat,1,1)
					destring age, replace
					global eduage 1.5
				}
				else {	
					cap su age
					if (r(N)> 0 & _rc==0) di in g "age is ok"
					else {
						noi di in r "No age available"
					}
					global eduage 15
				}
				
				cap su educat7
				if r(N)> 0 & _rc==0 {
					gen temp2 = 1 if age>=$eduage & age~=. & educat7>=3 & educat7~=.
					gen temp2c = 1 if age>=$eduage & age~=. & (educat7>=3 | educat7==.)
				}
				else { //educat5
					cap su educat5
					if r(N)> 0 & _rc==0{
						gen temp2 = 1 if age>=$eduage & age~=. & educat5>=3 & educat5~=.
						gen temp2c = 1 if age>=$eduage & age~=. & (educat5>=3 | educat5==.)
					}
					else {	//educat4
						cap su educat4
						if r(N)> 0 & _rc==0 {
							gen temp2 = 1 if age>=$eduage & age~=. & educat4>=2 & educat4~=.
							gen temp2c = 1 if age>=$eduage & age~=. & (educat4>=2 | educat4==.)
						}
						else { //no education available	
							local eduflag = 1
							noi di in r "No education available"
						}
					}
				}
				
				if `eduflag'==0 {			
					gen temp2a = 1 if age>=$eduage & age~=.
					bys hhid: egen educ_com_size = sum(temp2a)
					bys hhid: egen temp3 = sum(temp2)
					bys hhid: egen temp3c = sum(temp2c)
					gen dep_educ_com = 0
					replace dep_educ_com = 1 if temp3==0
					gen dep_educ_com_lb = 0
					replace dep_educ_com_lb = 1 if temp3c==0
					ren temp3 educ_com_sum
					ren temp3c educ_com_sum_lb
					drop temp2 temp2a temp2c
				}
				else {
					gen dep_educ_com = .
					gen dep_educ_com_lb = .
					gen educ_com_sum = .
					gen educ_com_sum_lb = .
					gen educ_com_size = .			
				}
				gen educ_com_appl = 1
				replace educ_com_appl = 0 if (educ_com_size==0 | educ_com_size==.)
				gen temp2b = 1 if age>=$eduage & age~=. & `eduflag' == 1
				bys hhid: egen educ_com_mis = sum(temp2b)
				drop temp2b
				gen educ_com_appl_miss = educ_com_appl == 1 & educ_com_mis>0 & educ_com_mis~=.
										
				la var dep_educ_com "Deprived if Households with NO adults $eduage+ with no primary completion"
				la var dep_educ_com_lb "Deprived if Households with NO adults $eduage+ with no or missing primary completion"

				****************************************************
				**1b) Indicator: school-age children current not enroll in school
				if "`c'" == "NRU" { //6-14
					global lbage = 1.5
					global ubage = 3.5
				}
				if "`c'" == "UKR" { //special case for UKR as there is only categorial age in the data
					global lbage = 2.5
					global ubage = 4.5
				}
				gen tempx = 1 if age>=$lbage & age<=$ubage
				bys hhid sim: egen nchildren = sum(tempx)
				
				if "`c'" == "MKD" { 
					drop school
				}

				cap su school
				if (_rc==0 & r(N)>0) {				
					gen temp2a = 1 if age>=$lbage & age<=$ubage
					bys hhid: egen educ_enr_size = sum(temp2a)
					gen temp2 = 1 if age>=$lbage & age<=$ubage & school==0 //depr when school==0
					gen temp2c = 1 if age>=$lbage & age<=$ubage & (school==0 |school==.) //depr when school==0 or missing
					gen temp2b = 1 if age>=$lbage & age<=$ubage & school==.
					bys hhid: egen temp4 = sum(temp2b)
					bys hhid: egen temp3 = sum(temp2)
					bys hhid: egen temp3c = sum(temp2c)
					
					gen dep_educ_enr = 0
					replace dep_educ_enr = 1 if temp3>0 & temp3~=.		
					gen dep_educ_enr_ub = 0
					replace dep_educ_enr_ub = 1 if temp3c>0 & temp3c~=.	
					
					ren temp3 educ_enr_sum
					ren temp3c educ_enr_sum_ub
					ren temp4 educ_enr_mis
					drop temp2 temp2a temp2b				
				}
				else { //not available
					gen dep_educ_enr = .
					gen dep_educ_enr_ub = .
					gen educ_enr_size = .
					gen educ_enr_sum = .
					gen educ_enr_sum_ub = .
					gen educ_enr_mis = .
					noi di in r "No school available"
				}
				
				
				la var dep_educ_enr "Deprived if Households has at least one school-aged child not enrolling in school"
				la var dep_educ_enr_ub "Deprived if Households has at least one school-aged child no or missing enrollment in school"

				****************************************************
				**Dimension 2: Access to infrastructure 
				****************************************************

				****************************************************
				//Indicator: Electricity
				cap sum electricity
				if (r(N)> 0 & _rc==0) gen dep_infra_elec = electricity==0 if electricity~=.
				else{
					gen dep_infra_elec = .
					noi di in r "No electricity available"
				}
				la var dep_infra_elec "Deprived if HH has No access to electricity"
				
				****************************************************		
				//Indicator: Sanitation 			
				cap su imp_san_rec
				if (r(N)> 0 & _rc==0) gen dep_infra_imps = imp_san_rec==0 if imp_san_rec~=.		
				else{
					gen dep_infra_imps = .
					noi di in r "Nosanitation available"
				}
				la var dep_infra_imps "Deprived if HH has No access to improved sanitation"
				
				****************************************************		
				//Indicator: Water 				
				cap su imp_wat_rec
				if (r(N)> 0 & _rc==0) gen dep_infra_impw = imp_wat_rec==0 if imp_wat_rec~=.
				else{
					gen dep_infra_impw = . 
					noi di in r "No water available"
				}      
				la var dep_infra_impw "Deprived if HH has No access to improved drinking water"
				
				****************************************************

				//Additional check
				local varcheck educat4 educat5 educat7 school 
				local addvar
				foreach var of local varcheck {
					cap des `var'
					if _rc==0 local addvar "`addvar' `var'"
				}
				
				local psuok = 0
				local varcheck psu strata subnatid subnatid1 subnatid2 subnatid3
				local addvar1
				foreach var of local varcheck {
					cap des `var'
					if _rc==0 local addvar1 "`addvar1' `var'"
				}
				if "`addvar1'"~="" local psuok = 1

				keep hhid pid code year dep_educ*  educ_com_* educ_enr_* dep_infra* age* /*male urban*/ `addvar' `addvar1' sim weight* $sub
					
				//hhid update
				/*if "`c'" == "GHA"{
					replace hhid = subinstr(hhid,"/","",.)
				}*/
				
				tempfile data01
				save `data01', replace
				
				****************************************************
				**Dimension 3: Monetary 
				****************************************************
				noi di in g "GPWG"
				if `nond4g' == 1 { 
					cap dlw, coun(`c') y(`y') type(gmd) mod(gpwg) clear
				}
				else{
					cap dlw, coun(`c') y(`y') type(gmd) module(gpwg) survey(`surv') clear
				}	
				if _rc==0 {//gpwg_repo
					local filename_gpwg = r(filename)
					
					//sim
					cap des sim
					if (_rc) gen sim = 1
					
					//adjust countrycode year
					cap drop countrycode
					cap gen countrycode = "`=upper("`c'")'"
					cap drop year
					cap gen year = `y'
					
					cap tostring hhid, replace force format(%19.0f)
					cap tostring pid, replace force format(%19.0f)
						
					//some special adjustment just in case for old database
					if "`ccc'"=="FJI" | "`ccc'"=="FSM" | "`ccc'"=="IDN" | "`ccc'"=="KHM" | "`ccc'"=="KIR" | "`ccc'"=="LAO" | "`ccc'"=="MNG" | "`ccc'"=="PNG" | "`ccc'"=="TLS" | "`ccc'"=="TON" | "`ccc'"=="TUV" | "`ccc'"=="VNM" | "`ccc'"=="WSM"  | "`ccc'"=="VUT" {			
						cap des pcexp
						if _rc==0 gen  welfareused = pcexp 
						else      gen  welfareused = welfare
						drop welfare
						ren welfareused welfare
					}			
					if "`c'"=="PHL" {
						cap des pcinc
						if _rc==0 {
							gen  welfareused = pcinc
							local welfarevar = "pcinc"
						}
						else      gen  welfareused = welfare
						drop welfare
						ren welfareused welfare
					}
					
					//POP WEIGHT at HH level - to convert all data to HH level as data comes in as either individual or HH level data
					set varabbrev off			
					cap isid hhid
					if _rc==0 {
						cap des weight_p
						if _rc==0 gen double popw = weight_p
						else gen double popw = weight
					}
					else {
						cap des weight_p
						if _rc==0 {
							drop if welfare==. 
							drop if weight_p==.						
							bys hhid: egen double popw = total(weight_p)						
						}
						else {
							drop if welfare==. 
							drop if weight==.						
							bys hhid: egen double popw = total(weight)
						}							
						duplicates drop hhid, force
					}
					set varabbrev on

					cap drop age*
					cap drop male
					
					if `psuok'==1 {
						local varcheck psu strata subnatid1 subnatid2 subnatid3 subnatid 
						foreach var of local varcheck {
							cap drop `var'
						}
					}
					isid hhid
					tempfile gpwg
					cap save `gpwg', replace
					if _rc==0 noi di in w "GPWG done"

					//MERGE WITH ALL DATA
					use `data01',clear
					cap drop _m
					merge m:1 hhid sim using `gpwg', gen(_gmdwash)
					
					if `psuok'==0 {
						local varcheck psu strata subnatid1 subnatid2 subnatid3 subnatid
						local addvar1
						foreach var of local varcheck {
							cap des `var'
							if _rc==0 local addvar1 "`addvar1' `var'"
						}
					}
					
					keep hhid pid code year dep_educ* educ_com_* educ_enr_* dep_infra* welfare* cpi* icp* popw age `addvar' `addvar1' sim weight* $sub
					cap sum sim
					if r(mean)!=1{
						ren weight_p kkkkk
						bys sim hhid: gen hhnew = _N
						drop weight*
						ren kkkkk weight
					}
					else{
						cap drop weight*
						bys hhid: gen hhnew = _N
						gen double weight = popw/hhnew
					}
					
					qui replace welfare = . if welfare < 0									
					gen double welfare_ppp = welfare/cpi${icpyr}/icp${icpyr}/365
					replace welfare_ppp = 0.25 if welfare_ppp <0.25 // set a welfare floor at 25cents (2017 PPP)
					
					gen dep_poor1 = welfare_ppp< $pov1 if welfare_ppp~=.
					la var dep_poor1 "Poor household at $${pov1}"
					
					drop if welfare==.
					drop if weight==.
					count
					sort hhid pid
					//show if pid is missing
					cap confirm string variable pid
					if _rc==0 {
						count if pid==""
						replace pid="999" if pid==""				
					}
					else {
						count if pid==.
						replace pid=999 if pid==.
					}
					isid hhid pid				
					order code year hhid pid `addvar1' `addvar' hhnew welfare icp${icpyr} cpi${icpyr} popw weight
					gen file = "`c'_`y'_`surv'"
					qui compress
					
					***************************************************
					***               MPM Calculation               ***
					***************************************************
					tempfile a
					save `a',replace
					
					levelsof $sub, loc(sub)
					levelsof sim, local(sim) 
					
					foreach k of local sub{ //sub
						foreach s of local sim{ //sim
							use `a', clear
							keep if sim == `s' & $sub == "`k'"
							//create fake hhid pid
							cap tostring hhid, replace force format(%19.0f)
							cap tostring pid, replace force format(%19.0f)
							
							//select water access	
							cap des dep_infra_impw 
							if _rc==0 {
								su dep_infra_impw, meanonly
								if r(N)>0 {
									gen double dep_infra_impw2 = dep_infra_impw
								}
								else { //rN==0
									gen double dep_infra_impw2 = .
								}
							}
							else {		
								gen double dep_infra_impw2 = .	
							}
							cap des dep_infra_impw2
							if _rc~=0 gen double dep_infra_impw2 = .
							
											
							//Impute electricity for some countries (universal coverage - 0 deprived - based on 99.9% coverage using WDI indicator)
							//AUT BEL CHE CYP DEU DNK ESP FIN FRA GBR GRC IRL ISL ITA LUX MLT NLD NOR PRT SWE
							cap gen elec_flag = .
							local elec_list MKD BGR EST HRV HUN LTU LVA UKR POL ROU TUR ARG BEL CHE CYP DEU DNK ESP FIN FRA GBR GRC IRL ISL ITA LUX MLT NLD NOR PRT SWE SRB AUT CZE SVK SVN
							foreach c of local elec_list {
								replace dep_infra_elec = 0 if code=="`c'" & dep_infra_elec==.
								replace elec_flag = 1 if code=="`c'"
							}
							
							//Impute water for some countries (universal coverage - 0 deprived - based on 99.9% coverage using WDI indicator)
							cap gen water_flag = .
							local water_list BGR CZE EST HRV HUN LVA SVK SVN AUT BEL CHE CYP DEU DNK ESP FIN FRA GBR GRC ISL ITA LUX MLT NLD NOR PRT SWE //LTU:96 PAN 94 UKR 96 IRL 97.8
							foreach c of local water_list {
								replace dep_infra_impw2 = 0 if code=="UKR" //UKR special
								replace dep_infra_impw2 = 0 if code=="`c'" & dep_infra_impw==.
								replace water_flag = 2 if code=="`c'"
							}

							//Impute sanitation for some countries (universal coverage - 0 deprived - based on 99.9% coverage using WDI indicator)
							cap gen sani_flag = .
							local sani_flag //MDA 76; MNE 95
							foreach c of local sani_flag {
								replace dep_infra_imps = 0 if code=="MDA" //MDA special
								replace dep_infra_imps = 0 if code=="`c'" & dep_infra_imps==.
								replace sani_flag = 2 if code=="`c'"
							}
							
							//Education for some countries (universal coverage - 0 deprived - based on 99.9% coverage using WDI indicator)
							cap gen enroll_flag = .
							local enroll_list 
							*BGR CZE EST HRV HUN LTU LVA SVK SVN AUT BEL CHE CYP DEU DNK ESP FIN FRA GBR GRC IRL ISL ITA LUX MLT NLD NOR PRT SWE 
							foreach c of local enroll_list {		
								replace dep_educ_enr = 0 if code=="`c'" & dep_educ_enr==.
								replace enroll_flag = 2 if code=="`c'"
							}

							//missing obs for some HHs	
							gen touse = dep_educ_com*dep_educ_enr*dep_infra_elec*dep_infra_impw*dep_infra_imps*dep_poor1~=.
							ta touse,m
							
							local indlist dep_educ_com dep_educ_enr dep_infra_elec dep_infra_impw dep_infra_imps dep_poor1
							
							//Indicator - deprived in all indicators
							gen dep_all_inds = dep_educ_com*dep_educ_enr*dep_infra_elec*dep_infra_impw*dep_infra_imps*dep_poor1
							
							//Dimensions and indicators setup	
							local edu		dep_educ_com dep_educ_enr
							local infra		dep_infra_elec dep_infra_imps dep_infra_impw
							local pov		dep_poor1
							local dims edu infra pov
							
							//deprived in all dimensions
							foreach dim of local dims {
								egen tmp_`dim' = rowtotal(``dim''), missing
								gen dim_`dim' =  (tmp_`dim'>=1) if tmp_`dim'~=.	
								drop tmp_`dim'
							}
							
							//Indicator - deprived in all dimensions
							egen c_all_dims = rowtotal(dim_edu dim_infra dim_pov), missing
							gen dep_1_dims = c_all_dims>=1 if c_all_dims~=.
							gen dep_2_dims = c_all_dims>=2 if c_all_dims~=.
							gen dep_3_dims = c_all_dims==3 if c_all_dims~=.
							
							//MPI - equal weight for each dimension, and indicators within each dimension	
							local pov welfare_ppp
							local ndim = "`=wordcount("`dims'")'"
							foreach dim of local dims {
								local nvar = "`=wordcount("``dim''")'"
								foreach var in ``dim'' {
									gen ww_`var' = 1/`nvar'
									gen w_`var' = 1/(`ndim'*`nvar')
								}
							}
							
							//Weight adjustment - Education - dep_educ_com dep_educ_enr				
							// 1 0
							replace w_dep_educ_com = 1/3 if dep_educ_com~=. & dep_educ_enr==.
							replace w_dep_educ_enr = 0   if dep_educ_com~=. & dep_educ_enr==.
							replace touse = 1            if dep_educ_com~=. & dep_educ_enr==.
							// 0 1
							replace w_dep_educ_enr = 1/3 if dep_educ_com==. & dep_educ_enr~=.
							replace w_dep_educ_com = 0   if dep_educ_com==. & dep_educ_enr~=.
							replace touse = 1            if dep_educ_com==. & dep_educ_enr~=.
							
							//Weight adjustment - Infrastructure - dep_infra_elec dep_infra_imps dep_infra_impw
							//0 1 1
							replace w_dep_infra_elec  = 0                  if dep_infra_elec==. & dep_infra_imps~=. & dep_infra_impw~=.
							replace w_dep_infra_imps  = (1/9) + 0.5*(1/9)  if dep_infra_elec==. & dep_infra_imps~=. & dep_infra_impw~=.
							replace w_dep_infra_impw  = (1/9) + 0.5*(1/9)  if dep_infra_elec==. & dep_infra_imps~=. & dep_infra_impw~=.
							replace touse = 1                              if dep_infra_elec==. & dep_infra_imps~=. & dep_infra_impw~=.
							
							//1 0 1
							replace w_dep_infra_elec  = (1/9) + 0.5*(1/9)  if dep_infra_elec~=. & dep_infra_imps==. & dep_infra_impw~=.
							replace w_dep_infra_imps  = 0                  if dep_infra_elec~=. & dep_infra_imps==. & dep_infra_impw~=.
							replace w_dep_infra_impw  = (1/9) + 0.5*(1/9)  if dep_infra_elec~=. & dep_infra_imps==. & dep_infra_impw~=.
							replace touse = 1                              if dep_infra_elec~=. & dep_infra_imps==. & dep_infra_impw~=.
							
							//1 1 0
							replace w_dep_infra_elec  = (1/9) + 0.5*(1/9)  if dep_infra_elec~=. & dep_infra_imps~=. & dep_infra_impw==.
							replace w_dep_infra_imps  = (1/9) + 0.5*(1/9)  if dep_infra_elec~=. & dep_infra_imps~=. & dep_infra_impw==.
							replace w_dep_infra_impw  = 0                  if dep_infra_elec~=. & dep_infra_imps~=. & dep_infra_impw==.
							replace touse = 1                              if dep_infra_elec~=. & dep_infra_imps~=. & dep_infra_impw==.
							
							//1 0 0
							replace w_dep_infra_elec  = (1/9) + 2*(1/9)    if dep_infra_elec~=. & dep_infra_imps==. & dep_infra_impw==.
							replace w_dep_infra_imps  = 0                  if dep_infra_elec~=. & dep_infra_imps==. & dep_infra_impw==.
							replace w_dep_infra_impw  = 0                  if dep_infra_elec~=. & dep_infra_imps==. & dep_infra_impw==.
							replace touse = 1                              if dep_infra_elec~=. & dep_infra_imps==. & dep_infra_impw==.
							
							//0 0 1
							replace w_dep_infra_elec  = 0                  if dep_infra_elec==. & dep_infra_imps==. & dep_infra_impw~=.
							replace w_dep_infra_imps  = 0                  if dep_infra_elec==. & dep_infra_imps==. & dep_infra_impw~=.
							replace w_dep_infra_impw  = (1/9) + 2*(1/9)    if dep_infra_elec==. & dep_infra_imps==. & dep_infra_impw~=.
							replace touse = 1                              if dep_infra_elec==. & dep_infra_imps==. & dep_infra_impw~=.
							
							//0 1 0
							replace w_dep_infra_elec  = 0                  if dep_infra_elec==. & dep_infra_imps~=. & dep_infra_impw==.
							replace w_dep_infra_imps  = (1/9) + 2*(1/9)    if dep_infra_elec==. & dep_infra_imps~=. & dep_infra_impw==.
							replace w_dep_infra_impw  = 0                  if dep_infra_elec==. & dep_infra_imps~=. & dep_infra_impw==.
							replace touse = 1                              if dep_infra_elec==. & dep_infra_imps~=. & dep_infra_impw==.
							
							ta touse,m
							su w_*
							
							//matrix g_ij indicator
							//reverse dummy because it is already deprived
							foreach var of varlist dep_educ_com dep_educ_enr dep_infra_elec dep_infra_imps dep_infra_impw {
								replace `var' = 1 - `var'
							}
							local pline $pov1
							local depr  dep_educ_com dep_educ_enr dep_infra_elec dep_infra_imps dep_infra_impw welfare_ppp
							local zline 1            1            1              1              1               `pline'	
							
							tokenize `zline'
							local c = 1
							foreach ind of local depr {
								forv alpha=0(1)2 {
									gen g_i_`alpha'_`ind' = ((1- `ind'/``c'')^`alpha') * (`ind'<``c'')
									gen wg_i_`alpha'_`ind' = g_i_`alpha'_`ind'*w_`ind'
								}
								local c = `c' + 1
							}
							egen wci_0 = rowtotal(wg_i_0_*)
							egen wci_1 = rowtotal(wg_i_1_*)
							egen wci_2 = rowtotal(wg_i_2_*)
							
							//matrix dimension
							replace dim_edu = 1 - dim_edu
							replace dim_infra = 1 - dim_infra
							local pline $pov1
							local depr2 dim_edu dim_infra welfare_ppp
							local zline 1       1         `pline'	
							tokenize `zline'
							local c = 1
							foreach ind of local depr2 {
								forv alpha=0(1)2 {
									gen g_d_`alpha'_`ind' = ((1- `ind'/``c'')^`alpha') * (`ind'<``c'')
									gen wg_d_`alpha'_`ind' = g_d_`alpha'_`ind'*(1/3)
								}
								local c = `c' + 1
							}
							egen wcd_0 = rowtotal(wg_d_0_*)
							egen wcd_1 = rowtotal(wg_d_1_*)
							egen wcd_2 = rowtotal(wg_d_2_*)
							
								
							//AF 2011 measure using indicator/dimensions (equal weight per dimension)
							gen mdpoor_i1 = (wci_0>=1/3) if wci_0~=. //Change the number of weighted deprivations
							gen mdpoor_i2 = (wci_0>=2/3) if wci_0~=.
							gen af_i_m0_1 = mdpoor_i1*wci_0 
							gen af_i_m0_2 = mdpoor_i2*wci_0 
							
							//AF 2011 measure using dimension only (union within dimension)
							gen mdpoor_d1 = (wcd_0>=1/3) if wcd_0~=. //Change the number of weighted deprivations
							gen mdpoor_d2 = (wcd_0>=2/3) if wcd_0~=.
							gen af_d_m0_1 = mdpoor_d1*wcd_0 
							gen af_d_m0_2 = mdpoor_d2*wcd_0
								
							//Datt2006 
							//e.g.: beta = 1 - there is no complementarity across deprivations, beta = 2 - there is complementarity across deprivations
							//equal weight per dimension
							local alpha = 1
							local beta = 2
							egen datt_i_a`alpha'_b`beta' = rowtotal(wg_i_`alpha'_*), missing
							replace datt_i_a`alpha'_b`beta' = datt_i_a`alpha'_b`beta'^(`beta')
							
							local alpha = 0
							local beta = 1
							egen datt_i_a`alpha'_b`beta' = rowtotal(wg_i_`alpha'_*), missing
							replace datt_i_a`alpha'_b`beta' = datt_i_a`alpha'_b`beta'^(`beta')
							
							local alpha = 0
							local beta = 2
							egen datt_i_a`alpha'_b`beta' = rowtotal(wg_i_`alpha'_*), missing
							replace datt_i_a`alpha'_b`beta' = datt_i_a`alpha'_b`beta'^(`beta')
							
							local alpha = 2
							local beta = 2
							egen datt_i_a`alpha'_b`beta' = rowtotal(wg_i_`alpha'_*), missing
							replace datt_i_a`alpha'_b`beta' = datt_i_a`alpha'_b`beta'^(`beta')
							
							//union within dimension
							local alpha = 1
							local beta = 2
							egen datt_d_a`alpha'_b`beta' = rowtotal(wg_d_`alpha'_*), missing
							replace datt_d_a`alpha'_b`beta' = datt_d_a`alpha'_b`beta'^(`beta')
							
							local alpha = 0
							local beta = 1
							egen datt_d_a`alpha'_b`beta' = rowtotal(wg_d_`alpha'_*), missing
							replace datt_d_a`alpha'_b`beta' = datt_d_a`alpha'_b`beta'^(`beta')
							
							local alpha = 0
							local beta = 2
							egen datt_d_a`alpha'_b`beta' = rowtotal(wg_d_`alpha'_*), missing
							replace datt_d_a`alpha'_b`beta' = datt_d_a`alpha'_b`beta'^(`beta')
							
							local alpha = 2
							local beta = 2
							egen datt_d_a`alpha'_b`beta' = rowtotal(wg_d_`alpha'_*), missing
							replace datt_d_a`alpha'_b`beta' = datt_d_a`alpha'_b`beta'^(`beta')
							
							//reverse for summary statistics
							foreach var of varlist dep_educ_com dep_educ_enr dep_infra_elec dep_infra_imps dep_infra_impw {
								replace `var' = 1 - `var'
							}
							replace dim_edu = 1 - dim_edu
							replace dim_infra = 1 - dim_infra
							
							//missing observations
							gen educ_com_underage = educ_com_size ==0 //hh with underage individuals, therefore automatically count as deprived in education completion
							gen educ_enr_overage = educ_enr_size == 0  //hh with overage individuals, noone belongs to the enrolling age cohorts, therefore automatically count as non-deprived in enrollment
							
							keep file hhid pid code year popw weight educ_com_* educ_enr_* dep_educ_com dep_educ_enr dep_infra_elec dep_infra_impw dep_infra_impw2 dep_infra_imps dep_poor1 welfare_ppp dep_all_inds *_all_dims dep_*_dims af_* datt_* touse /* g_* ci */ wg_* wcd* wci* mdpoor* age /*urban male*/	*_flag $sub

							//caculation
							preserve
								collapse (sum) touse educ_com_underage educ_enr_overage (count) welfare_ppp dep_poor1 dep_educ_com dep_educ_enr dep_infra_elec dep_infra_imps dep_infra_impw2, by(file)
								ren * c_*
								ren c_file file
								tempfile temp3
								save `temp3', replace
							restore
							
							collapse (mean) dep_poor1 dep_educ_com dep_educ_enr dep_infra_elec dep_infra_imps dep_infra_impw2 dep_all_inds dep_1_dims dep_2_dims dep_3_dims af_* datt_* mdpoor* *_flag [aw=weight] if touse==1, by(file)
							merge 1:1 file using `temp3'
							ren _m _merge1
							gen file_all = "`filename_all'"
							gen file_wash = "`filename_wash'"
							gen file_gpwg = "`filename_gpwg'"
							
							gen sim = `s'
							gen $sub = "`k'"
							append using `alldata', force
							save `alldata', replace			
						} //sim
					} //sub
					// mean of the simulations
					use `alldata', clear
					collapse (mean) dep_poor1 dep_educ_com dep_educ_enr dep_infra_elec dep_infra_imps dep_infra_impw2 dep_all_inds dep_1_dims dep_2_dims dep_3_dims af_* datt_* mdpoor* *_flag c_*, by(file file_all file_wash file_gpwg $sub)
					
					if `nond4g' == 1 {
						split file_all, parse("_")
						ren file_all1 countrycode
						ren file_all2 year
						ren file_all3 survname
					}
					else{
						split file, parse("_")
						ren file1 countrycode
						ren file2 year
						ren file3 survname
					}
					
					order countrycode survname year
					cap drop if inlist(countrycode `countrylist')
					merge m:1 countrycode survname year using `pfw', keep(3) nogen
					la var datatype "welfare type"
					replace year = rep_year if year != rep_year
					drop rep_year
																				
					order countrycode survname year datatype dep_poor1 dep_educ_com dep_educ_enr dep_infra_elec dep_infra_imps dep_infra_impw mdpoor_i1
					la var countrycode "3-letter Country code"
					la var survname "survey name"				
					la var year "year"
					la var datatype "welfare type"
					la var file "datafile"
					la var dep_poor1 "Deprived if HH is poor at $${pov1}"
					la var dep_educ_com "Deprived if Household with NO adults 13+ with no primary completion"
					la var dep_educ_enr "Deprived if Household has at least one school-aged child not enrolling in school"
					la var dep_infra_elec "Deprived if HH has No access to electricity"
					la var dep_infra_imps "Deprived if HH has No access to improved sanitation"
					la var dep_infra_impw "Deprived if HH has No access to improved drinking water"
					la var dep_all_inds "Deprived in all indicators"
					la var dep_1_dims "Deprived in at least 1 dimension"
					la var dep_2_dims "Deprived in at least 2 dimensions"
					la var dep_3_dims "Deprived in all 3 dimensions"
					la var mdpoor_i1 "multidimensional headcount rate(H)(equal weight, k=1/3)"
					la var mdpoor_i2 "multidimensional headcount rate(H)(equal weight, k=2/3)"
					la var mdpoor_d1 "multidimensional headcount rate(H)(union within dimension, k=1/3)"
					la var mdpoor_d2 "multidimensional headcount rate(H)(union within dimension, k=2/3)"
					la var af_i_m0_1 "AF measure M0 (equal weight, k=1/3)"
					la var af_i_m0_2 "AF measure M0 (equal weight, k=2/3)"
					la var af_d_m0_1 "AF measure M0 (union within dimension, k=1/3)"
					la var af_d_m0_2 "AF measure M0 (union within dimension, k=2/3)"
					la var datt_i_a1_b2 "Datt alpha =1, beta=2, equal weight"
					la var datt_i_a0_b1 "Datt alpha =0, beta=1, equal weight"
					la var datt_i_a2_b2 "Datt alpha =2, beta=2, equal weight"
					la var datt_d_a1_b2 "Datt alpha =1, beta=2, union within dimension"
					la var datt_d_a0_b1 "Datt alpha =0, beta=1, union within dimension"
					la var datt_d_a2_b2 "Datt alpha =2, beta=2, union within dimension"
					la var water_flag "Flag if imputation is used"
					la var elec_flag "Flag if imputation is used"
					la var sani_flag "Flag if imputation is used"
					la var enroll_flag "Flag if imputation is used"
					la var c_touse "touse sample of non-missing obs"
					la var c_welfare_ppp "non-missing welfare"
					la var c_dep_poor1 "non-missing welfare"
					la var c_dep_educ_com "non-missing adult education"
					la var c_dep_educ_enr "non-missing schooling"
					la var c_dep_infra_elec "non-missing electricity"
					la var c_dep_infra_imps "non-missing improved sanitation"
					la var c_dep_infra_impw "non-missing improved water2"
					la var c_educ_enr_overage "number of HH with overage individuals for enrollment"
					la var c_educ_com_underage "number of HH with underage individuals for completion"
																						
					local surv
					local filename_all 
					local filename_wash
					local c 
					local y
				} //dlw load GPWG
				else {
					noi dis in r "Failed to load the latest GPWG module: GMD GPWG module: `c'-`y'-`surv'"
					break
				}
			} //merge with washdata
			else {
				noi dis in r "Failed to merge the latest ALL and WASH module: GMD ALL/WASH module: `c'-`y'-`surv'"
				break
			}
		} //load ALL module
		else {
			noi dis in r "Failed to load the latest ALL module: GMD ALL module: `c'-`y'-`surv'"
			break
		}
	} //wash_repo
	else { 
		noi dis in r "Failed to load the WASH approved database: GMD ALL module: `c'-`y'-`surv'"
		break
	}
	cap drop elec_flag - _merge1
	noi list countrycode survname year datatype dep_poor1 dep_educ_com dep_educ_enr dep_infra_elec dep_infra_imps dep_infra_impw mdpoor_i1 $sub
	noi dis "The results are loaded in Stata memory, you can check it now."

	if `nond4g' == 1 {
		noi di in r "this dofile CANNOT calculate the MPM for the selected countries. Please check the availability list in the dataset."
		*cap dlw, country(WLD) year(2021) type(GMI) filename(WLD_2021_ALL_v01_M_v01_A_GMI_MPM.dta)
		*keep code year survey
		br
	}
} //qui

