********************************************************************************
/*
*** Date: 		05/09/2024
*** Author: 	Nishant Yonzan
*** Purpose: 	PIP countries with survey information from latest year to use for projection.
*/
********************************************************************************

// list of all countries
use "${rawpath}piptables_country_list.dta", clear
keep country_code country_name region_code
tempfile countryname
save 	`countryname'


// get list of lineups and keep the latest lineup to use for nowcasts
use "${rawpath}pip_lineup_v20240802.dta", clear
keep if poverty_line==2.15
keep country_code welfare_type reporting_level year
merge m:1 country_code using `countryname', nogen
bys country_code (year): gen lastyear = year[_N]
keep if year==lastyear
drop year lastyear

drop if reporting_level!="national" & inlist(country_code,"CHN","IDN","IND") 	// keep only national obs for these countries


// gen inPIP variable
gen 	inPIP = "Yes" if !missing(reporting_level)
replace inPIP = "No"  if missing(inPIP) 

// Venezuela special case
replace welfare_type = . 	 if country_code == "VEN"
replace reporting_level = "" if country_code == "VEN"
replace inPIP = "No"  		 if country_code == "VEN"

ren country_name country
ren country_code code
ren region_code region_pip
ren reporting_level coverage

order country code region_pip inPIP coverage welfare_type

label var inPIP "Survey in PIP in last lineup year?"

save "${intermediatepath}PIP_countries_202409.dta", replace

********************************************************************************
exit