********************************************************************************
/*
*** Date: 		05/09/2024
*** Author: 	Nishant Yonzan
*** Purpose: 	Population data.
*/
********************************************************************************

***********************************************
*** UN population 1950-2050 (national only) ***
***********************************************
*https://population.un.org/wpp/Download/Standard/CSV/
import excel "${rawpath}Population_UN_WPP2022.xlsx", sheet("Estimates") cellrange(A17) firstrow clear 
ren ISO3Alphacode code
merge m:1 code using "${intermediatepath}PIP_countries_202409.dta", keep(3) nogen keepusing(code country)
drop if missing(code)
destring TotalPopulationasof1July, replace
gen  	  unpop = TotalPopulationasof1July/1000
label var unpop "Population in millions"
ren Year year 
keep country code unpop year
tempfile unpop1950_2021
save 	`unpop1950_2021', replace

import excel "${rawpath}Population_UN_WPP2022.xlsx", sheet("Medium variant") cellrange(A17) firstrow clear 
ren ISO3Alphacode code
merge m:1 code using "${intermediatepath}PIP_countries_202409.dta", keep(3) nogen keepusing(code country)
drop if missing(code)
destring TotalPopulationasof1July, replace
gen  	  unpop = TotalPopulationasof1July/1000
label var unpop "Population in millions"
ren Year year 
keep country code unpop year

append using `unpop1950_2021'

sort code year
gen coverage="national"

save "${intermediatepath}UNpop1950-2100_MediumJuly2022.dta", replace 

** CHI, Channel Islands is missing UNpop **


********************************
*** WDI population 2019-2030 ***
********************************
wbopendata , indicator(sp.pop.totl; sp.urb.totl; sp.rur.totl) clear long projection
ren countrycode code
merge m:1 code using "${intermediatepath}PIP_countries_202409.dta", keep(3) nogen keepusing(code country)
ren sp_pop_totl wdipopnational
ren sp_urb_totl wdipopurban
ren sp_rur_totl wdipoprural
keep country code year wdipop*
reshape long wdipop, i(code year) j(coverage) string
replace 	wdipop = wdipop/1000000
label var 	wdipop "Population in millions"
save "${intermediatepath}WDIpop1960-2050_202409.dta", replace 

** TWN, Taiwan is missing WDI pop **

****************************************************************************
*** Population from PIP for period 1977 to 2020 (Rural, Urban, National) ***
****************************************************************************
use "${rawpath}piptables_population.dta", clear
destring value, ignore("NA") replace 
ren country_code code
ren data_level coverage
ren value pop
replace pop = pop/1000000
label var pop "Population in millions"
save "${intermediatepath}PIPpop1977-2021_202409.dta", replace 

************************
*** COMBINE AND SAVE ***
************************
use "${intermediatepath}PIPpop1977-2021_202409.dta", clear
merge 1:1 code coverage year using "${intermediatepath}WDIpop1960-2050_202409.dta", nogen keepusing(wdipop)
merge 1:1 code coverage year using "${intermediatepath}UNpop1950-2100_MediumJuly2022.dta", nogen keepusing(unpop)
replace pop = wdipop if missing(pop)
replace pop = unpop if missing(pop)
drop unpop wdipop

preserve																		// Missing projection post 2050 and pre 1960 for CHI in UN pop
keep if code=="CHI" & coverage=="national"
local num = _N+50																// replace post 2050 population with 2050 population 
set obs `num'
replace code	="CHI" if missing(code)
replace coverage="national" if missing(coverage)
bys code (year): replace year = year[_n-1]+1 if missing(year)
bys code (year): replace pop = pop[_n-1] if missing(pop)						
local num = _N+10																// keep the pre 1960 population missing
set obs `num'
sort code year
replace code	="CHI" if missing(code)
replace coverage="national" if missing(coverage)
forval i = 1/10 {
	replace year = year[_n+1]-1 if missing(year)
}							
keep if year>2050 | year<1960
tempfile chi
save 	`chi'
restore

append using `chi'

format pop* %6.2f
order code coverage year pop

label var coverage  "Area coverage"
label var pop 		"Population in millions"
compress
save 	"${intermediatepath}Population_202409.dta", replace

********************************************************************************
exit