*********************************************************************************
// This do file queries PIP to get the poverty rates of all countries (including missing) in PIP. 
*********************************************************************************

*********************************************************************************
// Get Population for all countries: including missing data
*********************************************************************************
use "${rawpath}piptables_country_list.dta", clear								// get pip regions
keep country_name country_code pcn_region_code
ren pcn_region region_code
duplicates drop
tempfile regions
save 	`regions'


use "${rawpath}piptables_population.dta", clear
destring value, replace ignore("NA")
ren value pop
ren data_level reporting_level
keep if reporting_level=="national" | inlist(country_code,"IND", "IDN", "CHN", "ARG")  //exceptions for which we don't use national coverage in line-up
drop if reporting_level=="national" & inlist(country_code,/*"IND", "IDN", "CHN",*/ "ARG")
keep if year>1980 & year<=2024
merge m:1 country_code using `regions', nogen
isid country_code reporting_level year
tempfile pop_all
save 	`pop_all'

*********************************************************************************
// Query lined-up estimates
*********************************************************************************

pip, nowcasts povline(2.15 3.65 6.85 25) clear $pipoptions
keep country_name country_code year reporting_level poverty_line welfare_type headcount poverty_gap poverty_severity 

// change the povertyline values for easy reshaping
replace poverty_line = poverty_line * 100
tostring poverty_line, replace force
cap duplicates drop country_name country_code year reporting_level welfare_type poverty_line, force  	// preliminary data has IDN repeated for years 1991-92
reshape wide headcount poverty_gap poverty_severity, i(country_name country_code year reporting_level welfare_type) j(poverty_line) string

// Drop national for IDN/IND/CHN
//drop if reporting_level=="national" & inlist(country_code,"CHN", "IND", "IDN") 

//population data for missing countries
merge m:1 country_code reporting_level year using `pop_all'
gen byte missingdata=_merge==2 													//variable identifying countries without line-up estimate (microdata not in PIP)
drop _merge	

reshape long headcount poverty_gap poverty_severity, i(country_name country_code year reporting_level welfare_type pop missingdata) j(poverty_line) 
recast double poverty_line
replace poverty_line = poverty_line/100

//substitute regional headcount if missing headcount
keep if reporting_level=="national"  | inlist(country_code,"ARG")
bys region_code year poverty_line: egen avg_headcount=wtmean(headcount), weight(pop)
bys region_code year poverty_line: egen avg_povertygap=wtmean(poverty_gap), weight(pop)
bys region_code year poverty_line: egen avg_povertysev=wtmean(poverty_severity), weight(pop)

replace headcount 			= avg_headcount  if headcount==.
replace poverty_gap 		= avg_povertygap if poverty_gap==.
replace poverty_severity 	= avg_povertysev if poverty_severity==.
gen double poorpop=(headcount*pop/1000000)

bys region_code year poverty_line: egen reg_pop=sum(pop)
replace pop 	= pop/1000000
replace reg_pop = reg_pop/1000000

keep  country_name country_code region_code year reporting_level welfare_type missingdata poverty_line pop reg_pop headcount poverty_gap poverty_severity poorpop  
order country_name country_code region_code year reporting_level welfare_type missingdata poverty_line pop reg_pop headcount poverty_gap poverty_severity poorpop 

label var pop 		  		"Population in million"
label var missingdata 		"No lineup in PIP"
label var region_code 		"PIP regions"	 
label var reg_pop	  		"Regional population"
label var headcount   		"Poverty headcount rate"
label var poverty_gap   	"Poverty gap"
label var poverty_severity  "Poverty severity"
label var poorpop 	  		"Millions of poor"	

compress 

save "${intermediatepath}lineup_allcountries_PIP_202409.dta", replace 

*********************************************************************************

exit


