********************************************************************************
/*
***Global 1000 binned distribution projections from 2025-2050.
*/
********************************************************************************

use "${rawpath}GlobalDist1000bins_1990_2024_3pr24.dta", clear					// Source: https://datacatalog.worldbank.org/search/dataset/0064304/1000_binned_global_distribution
keep if year==2024
keep code region_pip quantile pop welf 
ren welf welf2024
ren pop pop2024


// add growth rates up to 2050
// pass-through
preserve
use "${intermediatepath}GDP_GEP202406.dta", clear
merge m:1 code using "${intermediatepath}PIP_countries_202409.dta", keep(1 3) keepusing(country welfare_type inPIP) nogen
foreach v of varlist gbaseline* gprecovid* {
	replace `v' = `v' * 0.7 if inlist(welfare_type,1) // consumption gets 0.7; welfare_type==2 gets pass-through of 1
}
keep if inrange(year,2025,2050)
keep country code year inPIP gbaseline* gprecovid*
reshape wide g*, i(code) j(year)
tempfile grrates
save `grrates', replace
restore

preserve
use "${intermediatepath}Population_202409", clear
keep if coverage=="national"
keep code year pop
replace pop = pop/1000															// population per 1000 bin
keep if inrange(year,2025,2050)
reshape wide pop, i(code) j(year)
tempfile popu
save 	`popu', replace
restore


merge m:1 code using `grrates', nogen keepusing(country inPIP gbaseline*)
merge m:1 code using `popu'	  , nogen


// predicted welfare 2025 to 2050
forval yr = 2025/2050 {
	local lagyr = `yr' - 1
	gen welf`yr' = welf`lagyr' * (1 + gbaseline`yr')	
}
drop gbaseline*

// replace welfare with regional average for countries not in pip (and missing precovid and welfare values)
// replace missing values with regional average
foreach v of varlist welf2025-welf2050 {
	local yr = substr("`v'",-4,.)
	replace `v' = . if inPIP=="No"
	
	preserve																	// 1000 regional bins to calculate average per regional bin
	drop quantile
	egen id = group(region_pip)												
	egen quantile = xtile(`v'), nq(1000) by(id) weight(pop`yr')
	collapse `v' [aw=pop`yr'], by(region_pip quantile)
	drop if missing(`v')
	ren `v' `v'_m
	tempfile regional_average
	save 	`regional_average'
	restore

	merge m:1 region_pip quantile using `regional_average', nogen

	bys region_pip (quantile): replace `v'_m = `v'_m[_n-1] if missing(`v'_m)	// same average so missing quantile value using xtile
	replace `v' = `v'_m if missing(`v')											// replace missing values by regional average for each bin
	drop `v'_m
}

reshape long pop welf, i(country code region inPIP quantile) j(year)
drop if year==2024

label var year 			"Year"
label var country		"Country names"
label var code 			"Country ISO3c code"
label var region_pip 	"PIP regions"
label var inPIP 		"Microdata support available in PIP in 2022?"
label var quantile 		"Bin number"
label var pop 			"Population of bin in millions"
label var welf			"Average daily per capita welfare of bin in 2017 PPP USD, historical country 2010-19 growth"

keep if inrange(year, 2025, 2050)
order country code region_pip inPIP year quantile pop welf*
sort  code year quantile 
compress

save "${outputpath}GlobalDist1000bins_2025_2050_3pr24.dta", replace


// Save 1990-2050 data
use "${outputpath}GlobalDist1000bins_1981_2024_3pr24.dta", clear
local vint = pipvintage[1]
merge m:1 code using "${intermediatepath}PIP_countries_202409.dta", nogen keepusing(country inPIP)
append using "${outputpath}GlobalDist1000bins_2025_2050_3pr24.dta"
replace pipvintage = "`vint'" if missing(pipvintage)
order country code region_pip inPIP year quantile pop welf*
sort  code year quantile
keep if inrange(year,1990,2050)
compress
save "${outputpath}GlobalDist1000bins_1990_2050_3pr24.dta", replace


********************************************************************************

exit