********************************************************************************
/*
*** Global 1000 binned distribution projections from 2025-2050.
*** Constant growth rates assumed, 2%, 4%, 6%, 8%
*/
********************************************************************************

use "${rawpath}GlobalDist1000bins_1990_2024_3pr24.dta", clear
keep if year==2024
keep code region_pip quantile welf 
ren welf welf2024


// pass-through
preserve
use "${intermediatepath}PIP_countries_202409.dta", clear 
keep country code welfare_type inPIP
duplicates drop
tempfile passthr
save `passthr', replace
restore

preserve
use "${intermediatepath}Population_202409", clear
keep if coverage=="national"
keep code year pop
replace pop = pop/1000															// population per 1000 bin
keep if inrange(year,2025,2050)
reshape wide pop, i(code) j(year)
tempfile popu
save 	`popu', replace
restore


merge m:1 code using `passthr', nogen keepusing(country inPIP welfare_type)
merge m:1 code using `popu'	  , nogen

gen grate2 = 0.02
gen grate4 = 0.04
gen grate6 = 0.06
gen grate8 = 0.08

foreach v of varlist grate* {
	replace `v' = `v' * 0.7 if inlist(welfare_type,1) // consumption gets 0.7; welfare_type==2 gets pass-through of 1
}

// predicted welfare 2025 to 2050
gen welf_2pct2025 = welf2024 * (1+grate2)
gen welf_4pct2025 = welf2024 * (1+grate4)
gen welf_6pct2025 = welf2024 * (1+grate6)
gen welf_8pct2025 = welf2024 * (1+grate8)

forval yr = 2026/2050 {
	local lagyr = `yr' - 1
	gen welf_2pct`yr' = welf_2pct`lagyr' * (1 + grate2)
	gen welf_4pct`yr' = welf_4pct`lagyr' * (1 + grate4)
	gen welf_6pct`yr' = welf_6pct`lagyr' * (1 + grate6)
	gen welf_8pct`yr' = welf_8pct`lagyr' * (1 + grate8)
}
drop grate* welf2024 welfare_type

// replace welfare with regional average for countries not in pip (and missing precovid and welfare values)
// replace missing values with regional average
foreach v of varlist welf_* {
	local yr = substr("`v'",-4,.)
	replace `v' = . if inPIP=="No"
	
	preserve																	// 1000 regional bins to calculate average per regional bin
	drop quantile
	egen id = group(region_pip)												
	egen quantile = xtile(`v'), nq(1000) by(id) weight(pop`yr')
	collapse `v' [aw=pop`yr'], by(region_pip quantile)
	drop if missing(`v')
	ren `v' `v'_m
	tempfile regional_average
	save 	`regional_average'
	restore

	merge m:1 region_pip quantile using `regional_average', nogen

	bys region_pip (quantile): replace `v'_m = `v'_m[_n-1] if missing(`v'_m)	// same average so missing quantile value using xtile
	replace `v' = `v'_m if missing(`v')											// replace missing values by regional average for each bin
	drop `v'_m
}

reshape long pop welf_2pct welf_4pct welf_6pct welf_8pct, i(country code region inPIP quantile) j(year)
reshape long welf_, i(country code region inPIP quantile year pop) j(scenario) string
ren welf_ welf

label var year 			"Year"
label var country		"Country names"
label var code 			"Country ISO3c code"
label var region_pip 	"PIP regions"
label var inPIP 		"Microdata support available in PIP in 2022?"
label var quantile 		"Bin number"
label var pop 			"Population of bin in millions"
label var scenario		"Growth scenario"		
label var welf			"Average daily per capita welfare of bin in 2017 PPP USD, historical country 2010-19 growth"

keep if inrange(year, 2025, 2050)
order country code region_pip inPIP year quantile scenario pop welf*
sort  code year quantile 
compress

save "${outputpath}GlobalDist1000bins_2025_2050_3pr24_constantgrowth.dta", replace


********************************************************************************

exit