

/*******************************************************************************
	Figure 1b1: Plot change in extreme poverty during the pandemic by poverty report 

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 6 August 2024     
*******************************************************************************/

// Program set-up
clear all
set more off

// Load data
use "$ch1_data_processed/poverty_aggregates.dta", clear
keep region_code region_name 
duplicates drop
tempfile wb 
save `wb'

use "$ch1_data_processed/poverty_aggregates.dta", clear
keep if poverty_line<3
drop if inlist(region_code,"AFE","AFW")
keep region_code year headcount 
keep if inrange(year,2019,2021)
replace headcount = 100*headcount 
gen type = "PSPR2024"

tempfile df 
save `df'

use "$ch1_data_processed/previous_nowcasts.dta", clear
replace region = "WLD" if region=="global"

append using `df'

bysort type region_code (year) : gen double d_hc = headcount[_n] - headcount[_n-1]
keep if !missing(d_hc)
drop headcount 
sort region_code year type

bysort region_code year (type): gen j = _n
rename d_hc y 
reshape wide y, i(region_code year type) j(j)
collapse y1 y2 y3, by(region_code year)
merge m:1 region_code using `wb', nogen keep(match)
drop if region_code=="MNA"
replace region_code = "TOHI" if region_code=="OHI"
sort region_code 
gen sorting_var = _n
replace region_name = "Rest of the World" if region_code=="TOHI"
gen type = "type"

replace region_name="Middle East and North Africa" if region_code=="MNA"
replace region_name = "East Asia and Pacific" if region_code=="EAP"
replace region_name = "Latin America and the Caribbean" if region_code=="LAC"
replace region_name = "Europe and Central Asia" if region_code=="ECA"
replace region_name = "Sub-Saharan Africa*" if region_code=="SSA"
graph hbar y1 y2 y3, over(year) over(region_name, sort(sorting_var)) ///
	bar(1, lwidth(medium) lpattern(solid) lcolor(rgb("255 213 137"))  fcolor(rgb("255 213 137"))) ///
	bar(2, lwidth(medium) lpattern(solid) lcolor(rgb("255 129 51"))  fcolor(rgb("255 129 51"))) ///
	bar(3, lwidth(medium) lpattern(solid) lcolor(rgb("58 190 203"))  fcolor(rgb("58 190 203"))) ///
	ytitle("Change in poverty rate relative to previous year (percentage point)") ///
	legend(order(1 "PSPR 2020" 2 "PSPR 2022" 3 "PPPR 2024") ///
		row(1) symxsize(*.5) symysize(*.8) size(medium)) ///
		ysize(6) xsize(9)  ///
		by(type, graphregion(color(white)) row(2) legend(pos(5)) ///
		style(compact) note("") iscale(*0.8)) scheme(sj) ///
		subtitle("", fcolor(none) lstyle(none))

/* Manually move legend a bit to the right using the graph editor */ 

graph export "$ch1_output/ch1_fig1b1.eps", as(eps) replace
graph export "$ch1_output/ch1_fig1b1.png", as(png) replace

lab var y1 "Change in extreme poverty poverty, pp (PSPR 2020)"
lab var y2 "Change in extreme poverty poverty, pp (PSPR 2022)"
lab var y3 "Change in extreme poverty poverty, pp (PPPR 2024)"
lab var region_code "Region code"
lab var region_name "Region name"
lab var year "Year"
drop sorting_var type region_code

export excel "$ch1_output/chapter1.xlsx", sheet("fig1b1", modify) firstrow(varlabels) cell(A1)
