/*
figure 14: Changes in the Gini index before and after Covid19.
*/

*********************************************
*** figure 14:  Changes in the Gini index ***
*********************************************

use "$ch2_input_processed/gini_intermediate_all.dta", clear
drop if year == 2023

//keep on survey years
drop if gini==.

//Last year of survey
bys country_code (year): gen tlasty = year if _n==_N
egen lastyear = max(tlasty), by(country_code)

//keep only those countries that have survey 2021 and after
drop if lastyear<=2020
drop tlasty

//what is the last survey before 2020?
gen tag = year-2020 if year<2020
egen ttag = max(tag), by(country_code)
gen keepobs = 1 if ttag==tag
drop tag ttag
//what is the last survey after 2020?
gen tag = year-2020 if year>2020
egen ttag = max(tag), by(country_code)
replace keepobs = 1 if ttag==tag & keepobs==.
drop tag ttag

//keep last survey year after 2020 and first year before 2020
keep if keepobs==1

//check that most countries have 2 observations -- keep only countries with 2 datapoints
bys country_code: gen num = _N
drop if num!=2
drop num


//generate a comparability flag
gen c_startyear = substr(comparable_spell,1,strpos(comparable_spell,"-")-1)
replace c_startyear = comparable_spell if c_startyear == ""
destring c_startyear, replace

gen c_endyear = substr(comparable_spell,strpos(comparable_spell,"-")+1, .)
destring c_endyear, replace

egen precovyear = min(year), by(country_code)
egen postcovyear = max(year), by(country_code)

gen comparable = inrange(precovyear,c_startyear,c_endyear) & ///
				 inrange(postcovyear,c_startyear,c_endyear)

keep if comparable==1															// keep only comparable cases
				 

// precovid gini 
gen precovidgini = gini if year==precovyear
bys country_code (year): replace precovidgini = precovidgini[_n-1] if missing(precovidgini) 


// change in gini
bys country_code (year): gen 	 changepts = gini - gini[_n-1]
bys country_code (year): replace changepts = changepts[_n+1] if missing(changepts)
bys country_code (year): gen 	 changepct = ( (gini/gini[_n-1])^(1/(year-year[_n-1])) - 1 ) * 100
bys country_code (year): replace changepct = changepct[_n+1] if missing(changepct)


tw 	scatter changepct precovidgini  if incgroup_current=="LIC", ms(Oh) mc("$color3") || ///
	scatter changepct precovidgini  if incgroup_current=="LMIC", ms(Oh) mc("$color2") || ///
	scatter changepct precovidgini  if incgroup_current=="UMIC", ms(Oh) mc("$color4") || ///
	scatter changepct precovidgini  if incgroup_current=="HIC", ms(Oh) mc("$color7") || ///
	lfit 	changepct precovid 		, lp(solid) lc("$color1") ///
	yline(0, lp(dash) lc(gray)) yline(1 -1, lp(dash) lc(gs13)) ///
	ytitle("Annualized changes in Gini index:" "before and after COVID-19, %") xtitle("Pre-COVID-19 Gini index") ///
	legend(pos(6) col(5) order(1 "LIC" 2 "LMIC" 3 "UMIC" 4 "HIC" 5 "fitted line") size(small)) ///
	xsize(12) ysize(10)

graph export "${ch2_figure}Fig14_covid_Gini_correlation_comparable.png", replace	
graph export "${ch2_figure}Fig14_covid_Gini_correlation_comparable.eps", replace


// save data 
keep country_name region_name incgroup_current welfare_time gini precovidgini changepts changepct
order country_name region_name incgroup_current welfare_time gini precovidgini changepts changepct

replace incgroup_current = "Low income" 			if incgroup_current=="LIC"
replace incgroup_current = "Lower middle income" 	if incgroup_current=="LMIC"
replace incgroup_current = "Upper middle income" 	if incgroup_current=="UMIC"
replace incgroup_current = "High income" 			if incgroup_current=="HIC"

label var country_name 		"Economy"
label var welfare_time 		"Survey year"
label var incgroup_current 	"Income group FY24"
label var region_name		"Region, PIP"
label var gini 				"Gini index"
label var precovidgini		"Gini pre-2020"
label var changepts			"Total change in gini index before and after Covid19, points"
label var changepct			"Annualized change in gini index before and after Covid19, %"

format welfare_time gini precovidgini change* %5.2f

export excel using "${ch2_output}Chapter2_data.xlsx", cell(A1) sheet("Fig14") sheetreplace firstrow(varlabel)
